@@ -1,42 +1,38 @@
 /*-----------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2015, Southern Methodist University and 
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Southern Methodist University and Lawrence Livermore 
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence 
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  *---------------------------------------------------------------
  * Example problem:
- * 
- * The following is a simple example problem with analytical 
+ *
+ * The following is a simple example problem with analytical
  * solution,
  *    dy/dt = A*y
- * where A = V*D*Vi, 
+ * where A = V*D*Vi,
  *      V = [1 -1 1; -1 2 1; 0 -1 2];
  *      Vi = 0.25*[5 1 -3; 2 2 -2; 1 1 1];
  *      D = [-0.5 0 0; 0 -0.1 0; 0 0 lam];
  * where lam is a large negative number. The analytical solution to
- * this problem is 
+ * this problem is
  *   Y(t) = V*exp(D*t)*Vi*Y0
- * for t in the interval [0.0, 0.05], with initial condition: 
+ * for t in the interval [0.0, 0.05], with initial condition:
  * y(0) = [1,1,1]'.
- * 
- * The stiffness of the problem is directly proportional to the 
- * value of "lamda".  The value of lamda should be negative to 
+ *
+ * The stiffness of the problem is directly proportional to the
+ * value of "lamda".  The value of lamda should be negative to
  * result in a well-posed ODE; for values with magnitude larger than
  * 100 the problem becomes quite stiff.
- * 
+ *
  * In this example, we choose lamda = -100.
- * 
+ *
  * This program solves the problem with the DIRK method,
  * Newton iteration with the dense linear solver, and a
  * user-supplied Jacobian routine.
@@ -49,11 +45,10 @@
 #include <iostream>
 #include <string.h>
 #include <math.h>
-#include <arkode/arkode.h>              // prototypes for ARKode fcts., consts.
+#include <arkode/arkode_arkstep.h>      // prototypes for ARKStep fcts., consts.
 #include <nvector/nvector_serial.h>     // access to serial N_Vector
-#include <sunmatrix/sunmatrix_dense.h>  // access to dense SUNMatrix 
+#include <sunmatrix/sunmatrix_dense.h>  // access to dense SUNMatrix
 #include <sunlinsol/sunlinsol_dense.h>  // access to dense SUNLinearSolver
-#include <arkode/arkode_direct.h>       // access to ARKDls interface
 #include <sundials/sundials_types.h>    // def. of type 'realtype'
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
@@ -114,45 +109,41 @@ int main()
   // Initialize dense matrix data structure and solver
   A = SUNDenseMatrix(NEQ, NEQ);
   if (check_flag((void *)A, "SUNDenseMatrix", 0)) return 1;
-  LS = SUNDenseLinearSolver(y, A);
-  if (check_flag((void *)LS, "SUNDenseLinearSolver", 0)) return 1;
+  LS = SUNLinSol_Dense(y, A);
+  if (check_flag((void *)LS, "SUNLinSol_Dense", 0)) return 1;
 
-  // Create the ARKode memory structure
-  arkode_mem = ARKodeCreate();
-  if (check_flag((void *)arkode_mem, "ARKodeCreate", 0)) return 1;
-  
-  /* Call ARKodeInit to initialize the integrator memory and specify the
-     right-hand side function in y'=f(t,y), the inital time T0, and
-     the initial dependent variable vector y.  Note: since this
-     problem is fully implicit, we set f_E to NULL and f_I to f. */
-  flag = ARKodeInit(arkode_mem, NULL, f, T0, y);
-  if (check_flag(&flag, "ARKodeInit", 1)) return 1;
+  /* Call ARKStepCreate to initialize the ARK timestepper memory and
+     specify the right-hand side function in y'=f(t,y), the inital time
+     T0, and the initial dependent variable vector y.  Note: since
+     this problem is fully implicit, we set f_E to NULL and f_I to f. */
+  arkode_mem = ARKStepCreate(NULL, f, T0, y);
+  if (check_flag((void *)arkode_mem, "ARKStepCreate", 0)) return 1;
 
   // Set routines
-  flag = ARKodeSetUserData(arkode_mem, (void *) &lamda);   // Pass lamda to user functions
-  if (check_flag(&flag, "ARKodeSetUserData", 1)) return 1;
-  flag = ARKodeSStolerances(arkode_mem, reltol, abstol);   // Specify tolerances
-  if (check_flag(&flag, "ARKodeSStolerances", 1)) return 1;
+  flag = ARKStepSetUserData(arkode_mem, (void *) &lamda);   // Pass lamda to user functions
+  if (check_flag(&flag, "ARKStepSetUserData", 1)) return 1;
+  flag = ARKStepSStolerances(arkode_mem, reltol, abstol);   // Specify tolerances
+  if (check_flag(&flag, "ARKStepSStolerances", 1)) return 1;
 
   // Linear solver interface
-  flag = ARKDlsSetLinearSolver(arkode_mem, LS, A);         // Attach matrix and linear solver
-  if (check_flag(&flag, "ARKDlsSetLinearSolver", 1)) return 1;
-  flag = ARKDlsSetJacFn(arkode_mem, Jac);                  // Set Jacobian routine
-  if (check_flag(&flag, "ARKDlsSetJacFn", 1)) return 1;
+  flag = ARKStepSetLinearSolver(arkode_mem, LS, A);         // Attach matrix and linear solver
+  if (check_flag(&flag, "ARKStepSetLinearSolver", 1)) return 1;
+  flag = ARKStepSetJacFn(arkode_mem, Jac);                  // Set Jacobian routine
+  if (check_flag(&flag, "ARKStepSetJacFn", 1)) return 1;
 
   // Specify linearly implicit RHS, with non-time-dependent Jacobian
-  flag = ARKodeSetLinear(arkode_mem, 0);
-  if (check_flag(&flag, "ARKodeSetLinear", 1)) return 1;
+  flag = ARKStepSetLinear(arkode_mem, 0);
+  if (check_flag(&flag, "ARKStepSetLinear", 1)) return 1;
 
   // Open output stream for results, output comment line
   FILE *UFID = fopen("solution.txt","w");
   fprintf(UFID,"# t y1 y2 y3\n");
 
-  // output initial condition to disk 
-  fprintf(UFID," %.16" ESYM" %.16" ESYM" %.16" ESYM" %.16" ESYM"\n", 
-	  T0, NV_Ith_S(y,0), NV_Ith_S(y,1), NV_Ith_S(y,2));  
+  // output initial condition to disk
+  fprintf(UFID," %.16" ESYM" %.16" ESYM" %.16" ESYM" %.16" ESYM"\n",
+          T0, NV_Ith_S(y,0), NV_Ith_S(y,1), NV_Ith_S(y,2));
 
-  /* Main time-stepping loop: calls ARKode to perform the integration, then
+  /* Main time-stepping loop: calls ARKStepEvolve to perform the integration, then
      prints results.  Stops when the final time has been reached */
   realtype t = T0;
   realtype tout = T0+dTout;
@@ -160,12 +151,12 @@ int main()
   cout << "   --------------------------------------\n";
   while (Tf - t > 1.0e-15) {
 
-    flag = ARKode(arkode_mem, tout, y, &t, ARK_NORMAL);           // call integrator
-    if (check_flag(&flag, "ARKode", 1)) break;
+    flag = ARKStepEvolve(arkode_mem, tout, y, &t, ARK_NORMAL);           // call integrator
+    if (check_flag(&flag, "ARKStepEvolve", 1)) break;
     printf("  %8.4" FSYM"  %8.5" FSYM"  %8.5" FSYM"  %8.5" FSYM"\n",  // access/print solution
            t, NV_Ith_S(y,0), NV_Ith_S(y,1), NV_Ith_S(y,2));
-    fprintf(UFID," %.16" ESYM" %.16" ESYM" %.16" ESYM" %.16" ESYM"\n", 
-	    t, NV_Ith_S(y,0), NV_Ith_S(y,1), NV_Ith_S(y,2));  
+    fprintf(UFID," %.16" ESYM" %.16" ESYM" %.16" ESYM" %.16" ESYM"\n",
+            t, NV_Ith_S(y,0), NV_Ith_S(y,1), NV_Ith_S(y,2));
     if (flag >= 0) {                                              // successful solve: update time
       tout += dTout;
       tout = (tout > Tf) ? Tf : tout;
@@ -179,24 +170,24 @@ int main()
 
   // Print some final statistics
   long int nst, nst_a, nfe, nfi, nsetups, nje, nfeLS, nni, ncfn, netf;
-  flag = ARKodeGetNumSteps(arkode_mem, &nst);
-  check_flag(&flag, "ARKodeGetNumSteps", 1);
-  flag = ARKodeGetNumStepAttempts(arkode_mem, &nst_a);
-  check_flag(&flag, "ARKodeGetNumStepAttempts", 1);
-  flag = ARKodeGetNumRhsEvals(arkode_mem, &nfe, &nfi);
-  check_flag(&flag, "ARKodeGetNumRhsEvals", 1);
-  flag = ARKodeGetNumLinSolvSetups(arkode_mem, &nsetups);
-  check_flag(&flag, "ARKodeGetNumLinSolvSetups", 1);
-  flag = ARKodeGetNumErrTestFails(arkode_mem, &netf);
-  check_flag(&flag, "ARKodeGetNumErrTestFails", 1);
-  flag = ARKodeGetNumNonlinSolvIters(arkode_mem, &nni);
-  check_flag(&flag, "ARKodeGetNumNonlinSolvIters", 1);
-  flag = ARKodeGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
-  check_flag(&flag, "ARKodeGetNumNonlinSolvConvFails", 1);
-  flag = ARKDlsGetNumJacEvals(arkode_mem, &nje);
-  check_flag(&flag, "ARKDlsGetNumJacEvals", 1);
-  flag = ARKDlsGetNumRhsEvals(arkode_mem, &nfeLS);
-  check_flag(&flag, "ARKDlsGetNumRhsEvals", 1);
+  flag = ARKStepGetNumSteps(arkode_mem, &nst);
+  check_flag(&flag, "ARKStepGetNumSteps", 1);
+  flag = ARKStepGetNumStepAttempts(arkode_mem, &nst_a);
+  check_flag(&flag, "ARKStepGetNumStepAttempts", 1);
+  flag = ARKStepGetNumRhsEvals(arkode_mem, &nfe, &nfi);
+  check_flag(&flag, "ARKStepGetNumRhsEvals", 1);
+  flag = ARKStepGetNumLinSolvSetups(arkode_mem, &nsetups);
+  check_flag(&flag, "ARKStepGetNumLinSolvSetups", 1);
+  flag = ARKStepGetNumErrTestFails(arkode_mem, &netf);
+  check_flag(&flag, "ARKStepGetNumErrTestFails", 1);
+  flag = ARKStepGetNumNonlinSolvIters(arkode_mem, &nni);
+  check_flag(&flag, "ARKStepGetNumNonlinSolvIters", 1);
+  flag = ARKStepGetNumNonlinSolvConvFails(arkode_mem, &ncfn);
+  check_flag(&flag, "ARKStepGetNumNonlinSolvConvFails", 1);
+  flag = ARKStepGetNumJacEvals(arkode_mem, &nje);
+  check_flag(&flag, "ARKStepGetNumJacEvals", 1);
+  flag = ARKStepGetNumLinRhsEvals(arkode_mem, &nfeLS);
+  check_flag(&flag, "ARKStepGetNumLinRhsEvals", 1);
 
   cout << "\nFinal Solver Statistics:\n";
   cout << "   Internal solver steps = " << nst << " (attempted = " << nst_a << ")\n";
@@ -209,7 +200,7 @@ int main()
   cout << "   Total number of error test failures = " << netf << "\n\n";
 
   // Clean up and return with successful completion
-  ARKodeFree(&arkode_mem);     // Free integrator memory
+  ARKStepFree(&arkode_mem);    // Free integrator memory
   SUNLinSolFree(LS);           // Free linear solver
   SUNMatDestroy(A);            // Free A matrix
   N_VDestroy(y);               // Free y vector
@@ -257,7 +248,6 @@ static int Jac(realtype t, N_Vector y, N_Vector fy,
   SUNMatrix V  = SUNDenseMatrix(3,3);          // create temporary SUNMatrix objects
   SUNMatrix D  = SUNDenseMatrix(3,3);          // create temporary SUNMatrix objects
   SUNMatrix Vi = SUNDenseMatrix(3,3);          // create temporary SUNMatrix objects
-  sunindextype N = SUNDenseMatrix_Rows(J);
 
   SUNMatZero(V);        // initialize temporary matrices to zero
   SUNMatZero(D);        // (not technically required)
@@ -348,7 +338,7 @@ static int dense_MM(SUNMatrix A, SUNMatrix B, SUNMatrix C)
     opt == 1 means SUNDIALS function returns a flag so check if
              flag >= 0
     opt == 2 means function allocates memory so check if returned
-             NULL pointer  
+             NULL pointer
 */
 static int check_flag(void *flagvalue, const string funcname, int opt)
 {
@@ -364,10 +354,10 @@ static int check_flag(void *flagvalue, const string funcname, int opt)
     errflag = (int *) flagvalue;
     if (*errflag < 0) {
       cerr << "\nSUNDIALS_ERROR: " << funcname << " failed with flag = " << *errflag << "\n\n";
-      return 1; 
+      return 1;
     }
   }
-  
+
   // Check if function returned NULL pointer - no memory allocated
   else if (opt == 2 && flagvalue == NULL) {
     cerr << "\nMEMORY_ERROR: " << funcname << " failed - returned NULL pointer\n\n";
