@@ -1,22 +1,15 @@
 !-----------------------------------------------------------------
 ! Programmer(s): Daniel R. Reynolds @ SMU
 !-----------------------------------------------------------------
-! LLNS/SMU Copyright Start
-! Copyright (c) 2015, Southern Methodist University and 
-! Lawrence Livermore National Security
-!
-! This work was performed under the auspices of the U.S. Department 
-! of Energy by Southern Methodist University and Lawrence Livermore 
-! National Laboratory under Contract DE-AC52-07NA27344.
-! Produced at Southern Methodist University and the Lawrence 
-! Livermore National Laboratory.
-!
+! SUNDIALS Copyright Start
+! Copyright (c) 2002-2019, Lawrence Livermore National Security
+! and Southern Methodist University.
 ! All rights reserved.
-! For details, see the LICENSE file.
-! LLNS/SMU Copyright End
-! Copyright (c) 2013, Southern Methodist University.
-! All rights reserved.
-! For details, see the LICENSE file.
+!
+! See the top-level LICENSE and NOTICE files for details.
+!
+! SPDX-License-Identifier: BSD-3-Clause
+! SUNDIALS Copyright End
 !-----------------------------------------------------------------
 ! Example problem:
 ! 
@@ -498,7 +491,7 @@ program driver
   ! solution vector and other local variables
   real(kind=REALTYPE), allocatable :: y(:,:)
   real(kind=REALTYPE) :: rout(6), rpar, t, dTout, tout, urms
-  integer*8 :: iout(22), ipar, N, Ntot, i, j
+  integer*8 :: iout(35), ipar, N, Ntot, i, j
   integer   :: flag, ioutput
   logical   :: outproc
   character*100 :: outname
@@ -593,15 +586,15 @@ program driver
   end if
 
 
-  ! attach linear solver module to ARKSpils interface
-  call FARKSpilsInit(flag)
+  ! attach linear solver module to ARKLs interface
+  call FARKLsInit(flag)
   if (flag < 0) then
-     write(0,*) "Error in FARKSpilsInit = ", flag
+     write(0,*) "Error in FARKLsInit = ", flag
      call MPI_Finalize(flag)
   end if
-  call FARKSpilsSetPrec(1, flag)     ! Signal user-supplied preconditioner
+  call FARKLsSetPrec(1, flag)     ! Signal user-supplied preconditioner
   if (flag < 0) then
-     write(0,*) "Error in FARKSpilsSetPrec = ", flag
+     write(0,*) "Error in FARKLsSetPrec = ", flag
      call MPI_Finalize(flag)
   end if
 
@@ -682,12 +675,12 @@ program driver
           " (attempted = ", iout(6), ")"
      write(6,'(A,i6,A,i6)') "   Total RHS evals:  Fe = ", iout(7), ",  Fi = ", iout(8)
      write(6,'(A,i6)') "   Total linear solver setups = ", iout(9)
-     write(6,'(A,i6)') "   Total linear iterations = ", iout(21)
-     write(6,'(A,i6)') "   Total number of Jacobian-vector products = ", iout(18)
-     write(6,'(A,i6)') "   Total number of Preconditioner setups = ", iout(19)
-     write(6,'(A,i6)') "   Total number of Preconditioner solves = ", iout(20)
+     write(6,'(A,i6)') "   Total linear iterations = ", iout(23)
+     write(6,'(A,i6)') "   Total number of Jacobian-vector products = ", iout(20)
+     write(6,'(A,i6)') "   Total number of Preconditioner setups = ", iout(21)
+     write(6,'(A,i6)') "   Total number of Preconditioner solves = ", iout(22)
      write(6,'(A,i6)') "   Total number of linear solver convergence failures = ", &
-          iout(22)
+          iout(24)
      write(6,'(A,i6)') "   Total number of Newton iterations = ", iout(11)
      write(6,'(A,i6)') "   Total number of nonlinear solver convergence failures = ", &
           iout(12)
