@@ -1,8 +1,18 @@
-C     ----------------------------------------------------------------
+C     --------------------------------------------------------------------
+C     SUNDIALS Copyright Start
+C     Copyright (c) 2002-2019, Lawrence Livermore National Security
+C     and Southern Methodist University.
+C     All rights reserved.
+C
+C     See the top-level LICENSE and NOTICE files for details.
+C
+C     SPDX-License-Identifier: BSD-3-Clause
+C     SUNDIALS Copyright End
+C     --------------------------------------------------------------------
 C     Diagonal ODE example. Stiff case, with diagonal preconditioner.
 C     Uses FCVODE interfaces and FCVBBD interfaces.
 C     Solves problem twice -- with left and right preconditioning.
-C     ----------------------------------------------------------------
+C     --------------------------------------------------------------------
 C
 C     Include MPI-Fortran header file for MPI_COMM_WORLD, MPI types.
 
@@ -15,7 +25,7 @@ C The following declaration specification should match C type long int.
       PARAMETER (NLOCAL=10)   
 C
       INTEGER*4 NOUT, LNST, LNFE, LNSETUP, LNNI, LNCF, LNETF, LNPE
-      INTEGER*4 LNLI, LNPS, LNCFL, MYPE, IER, NPES, METH, ITMETH
+      INTEGER*4 LNLI, LNPS, LNCFL, MYPE, IER, NPES, METH
       INTEGER*4 LLENRW, LLENIW, LLENRWLS, LLENIWLS
       INTEGER*4 IATOL, ITASK, IPRE, IGS, JOUT
 C The following declaration specification should match C type long int.
@@ -29,7 +39,7 @@ C
       DATA ATOL/1.0D-10/, RTOL/1.0D-5/, DTOUT/0.1D0/, NOUT/10/
       DATA LLENRW/1/, LLENIW/2/, LNST/3/, LNFE/4/, LNETF/5/,  LNCF/6/,
      1     LNNI/7/, LNSETUP/8/, LLENRWLS/13/, LLENIWLS/14/,
-     1     LNPE/18/, LNLI/20/, LNPS/19/, LNCFL/21/
+     1     LNPE/20/, LNLI/22/, LNPS/21/, LNCFL/23/
 C
 C     Get NPES and MYPE.  Requires initialization of MPI.
       CALL MPI_INIT(IER)
@@ -57,7 +67,6 @@ C     Set input arguments.
       NEQ = NPES * NLOCAL
       T = 0.0D0
       METH = 2
-      ITMETH = 2
       IATOL = 1
       ITASK = 1
       IPRE = 1
@@ -111,7 +120,7 @@ C
          STOP
       ENDIF
 C     
-      CALL FCVMALLOC(T, Y, METH, ITMETH, IATOL, RTOL, ATOL,
+      CALL FCVMALLOC(T, Y, METH, IATOL, RTOL, ATOL,
      &               IOUT, ROUT, IPAR, RPAR, IER)
 C     
       IF (IER .NE. 0) THEN
@@ -121,11 +130,11 @@ C
          STOP
       ENDIF
 C
-C     attach linear solver module to CVSpils interface
-      CALL FCVSPILSINIT(IER)
+C     attach linear solver module to CVLs interface
+      CALL FCVLSINIT(IER)
       IF (IER .NE. 0) THEN
          WRITE(6,32) IER
- 32      FORMAT(///' SUNDIALS_ERROR: FCVSPILSINIT returned IER = ', I5)
+ 32      FORMAT(///' SUNDIALS_ERROR: FCVLSINIT returned IER = ', I5)
          CALL MPI_ABORT(MPI_COMM_WORLD, 1, IER)
          STOP
       ENDIF
