@@ -2,9 +2,15 @@ C     ----------------------------------------------------------------
 C     Programmer(s): Ting Yan @ SMU
 C          Based on cvRoberts_sps.c and modified to Fortran 77
 C     ----------------------------------------------------------------
-C     Copyright (c) 2016, Southern Methodist University.
+C     SUNDIALS Copyright Start
+C     Copyright (c) 2002-2019, Lawrence Livermore National Security
+C     and Southern Methodist University.
 C     All rights reserved.
-C     For details, see the LICENSE file.
+C
+C     See the top-level LICENSE and NOTICE files for details.
+C
+C     SPDX-License-Identifier: BSD-3-Clause
+C     SUNDIALS Copyright End
 C     ----------------------------------------------------------------
 C     FCVODE Example Problem: Robertson kinetics
 C
@@ -36,7 +42,7 @@ C
       IMPLICIT NONE
 C
       INTEGER*4 IER, LNST, LNFE, LNSETUP, LNNI, LNCF, LNETF, LNJE, LNGE
-      INTEGER*4 METH, ITMETH, ITOL, ITASK, JOUT, NOUT, IERROOT
+      INTEGER*4 METH, ITOL, ITASK, JOUT, NOUT, IERROOT
       INTEGER*4 INFO(2)
       INTEGER*4 I
 C The following declaration specification should match C type long int
@@ -59,8 +65,6 @@ C     initial y components
       Y(3) = 0.0D0
 C     basic integration method, 2 for BDF
       METH = 2
-C     nonlinear iteration method, 2 for Newton iteration
-      ITMETH = 2
 C     type for absolute tolerance, 2 for array
       ITOL = 2
 C     scalar relative tolerance
@@ -113,8 +117,8 @@ C     number of threads to use in factorization
       ENDIF
 
 C     Call FCVMALLOC to create the solver memory and specify the 
-C     Backward Differentiation Formula and the use of a Newton iteration
-      CALL FCVMALLOC(T0, Y, METH, ITMETH, ITOL, RTOL, ATOL,
+C     Backward Differentiation Formula
+      CALL FCVMALLOC(T0, Y, METH, ITOL, RTOL, ATOL,
      1               IOUT, ROUT, IPAR, RPAR, IER)
       IF (IER .NE. 0) THEN
         WRITE(6,30) IER
@@ -174,11 +178,11 @@ C     Call FCVROOTINIT to specify the root function g with 2 components
         STOP
       ENDIF
 
-C     attach the matrix and linear solver modules to CVDls interface
-      CALL FCVDLSINIT(IER)
+C     attach the matrix and linear solver modules to CVLs interface
+      CALL FCVLSINIT(IER)
       IF (IER .NE. 0) THEN
         WRITE(6,40) IER
- 40     FORMAT(///' SUNDIALS_ERROR: FCVDLSINIT returned IER = ', I5)
+ 40     FORMAT(///' SUNDIALS_ERROR: FCVLSINIT returned IER = ', I5)
         CALL FCVFREE
         STOP
       ENDIF
