@@ -1,13 +1,18 @@
-/*
- * -----------------------------------------------------------------
- * $Revision:  $
- * $Date: $
- * -----------------------------------------------------------------
+/* -----------------------------------------------------------------
  * Programmer(s): Ting Yan @ SMU
  *      Based on cvsRoberts_FSA_dns.c and modified to use SUPERLU_MT
  * -----------------------------------------------------------------
- * Example problem:
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
+ * All rights reserved.
  *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
+ *-----------------------------------------------------------------
+ * Adjoint sensitivity example problem.
  * The following is a simple example problem, with the coding
  * needed for its solution by CVODES for Forward Sensitivity 
  * Analysis. The problem is from chemical kinetics, and consists
@@ -19,7 +24,7 @@
  * conditions y1 = 1.0, y2 = y3 = 0. The reaction rates are: p1=0.04,
  * p2=1e4, and p3=3e7. The problem is stiff.
  * This program solves the problem with the BDF method, Newton
- * iteration with the CVODES SUPERLU_MT linear solver, and a
+ * iteration with the SUPERLU_MT linear solver, and a
  * user-supplied Jacobian routine.
  * It uses a scalar relative tolerance and a vector absolute
  * tolerance.
@@ -32,7 +37,7 @@
  * user routine fS (of type SensRhs1Fn).
  * Any of three sensitivity methods (SIMULTANEOUS, STAGGERED, and
  * STAGGERED1) can be used and sensitivities may be included in the
- * error test or not (error control set on TRUE or FALSE,
+ * error test or not (error control set on SUNTRUE or SUNFALSE,
  * respectively).
  *
  * Execution:
@@ -43,28 +48,24 @@
  *    % cvsRoberts_FSA_sps -sensi sensi_meth err_con
  * where sensi_meth is one of {sim, stg, stg1} and err_con is one of
  * {t, f}.
- * -----------------------------------------------------------------
- */
+ * -----------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-/* Header files with a description of contents used */
-
-#include <cvodes/cvodes.h>             /* prototypes for CVODES fcts. and consts. */
-#include <cvodes/cvodes_superlumt.h>   /* prototypes for CVSUPERLUMT fcts. and constants */
-#include <sundials/sundials_sparse.h>  /* definitions SlsMat */
-#include <nvector/nvector_serial.h>    /* defs. of serial NVECTOR fcts. and macros */
-#include <sundials/sundials_types.h>   /* def. of type realtype */
-#include <sundials/sundials_math.h>    /* definition of ABS */
+#include <cvodes/cvodes.h>                 /* prototypes for CVODE fcts., consts.  */
+#include <nvector/nvector_serial.h>        /* access to serial N_Vector            */
+#include <sunmatrix/sunmatrix_sparse.h>    /* access to sparse SUNMatrix           */
+#include <sunlinsol/sunlinsol_superlumt.h> /* access to SuperLUMT SUNLinearSolver  */
+#include <sundials/sundials_types.h>       /* defs. of realtype, sunindextype      */
+#include <sundials/sundials_math.h>        /* defs. of SUNRabs, SUNRexp, etc.      */
 
 /* Accessor macros */
 /* These macros are defined in order to write code with which exactly matched
-   the mathematical problem description given above.
-*/
+   the mathematical problem description given above. */
 
-#define Ith(v,i)    NV_Ith_S(v,i-1)       /* i-th vector component i=1..NEQ */
+#define Ith(v,i)    NV_Ith_S(v,i-1)       /* i-th vector component, i=1..NEQ */
 
 /* Problem Constants */
 
@@ -92,16 +93,15 @@ typedef struct {
   realtype p[3];           /* problem parameters */
 } *UserData;
 
-/* Prototypes of functions by CVODES */
+/* Prototypes of user-supplied functions */
 
 static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data);
 
-static int Jac(realtype t,
-               N_Vector y, N_Vector fy, SlsMat JacMat, void *user_data, 
-               N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
+static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
+               void *user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3);
 
-static int fS(int Ns, realtype t, N_Vector y, N_Vector ydot, 
-              int iS, N_Vector yS, N_Vector ySdot, 
+static int fS(int Ns, realtype t, N_Vector y, N_Vector ydot,
+              int iS, N_Vector yS, N_Vector ySdot,
               void *user_data, N_Vector tmp1, N_Vector tmp2);
 
 static int ewt(N_Vector y, N_Vector w, void *user_data);
@@ -115,7 +115,7 @@ static void WrongArgs(char *name);
 static void PrintOutput(void *cvode_mem, realtype t, N_Vector u);
 static void PrintOutputS(N_Vector *uS);
 static void PrintFinalStats(void *cvode_mem, booleantype sensi);
-static int check_flag(void *flagvalue, const char *funcname, int opt);
+static int check_retval(void *returnvalue, const char *funcname, int opt);
 
 /*
  *--------------------------------------------------------------------
@@ -125,11 +125,13 @@ static int check_flag(void *flagvalue, const char *funcname, int opt);
 
 int main(int argc, char *argv[])
 {
+  SUNMatrix A;
+  SUNLinearSolver LS;
   void *cvode_mem;
   UserData data;
   realtype t, tout;
   N_Vector y;
-  int iout, flag, nthreads, nnz;
+  int iout, retval, nthreads, nnz;
 
   realtype pbar[NS];
   int is; 
@@ -139,56 +141,66 @@ int main(int argc, char *argv[])
 
   cvode_mem = NULL;
   data      = NULL;
-  y         =  NULL;
+  y         = NULL;
   yS        = NULL;
+  A         = NULL;
+  LS        = NULL;
 
   /* Process arguments */
   ProcessArgs(argc, argv, &sensi, &sensi_meth, &err_con);
 
   /* User data structure */
   data = (UserData) malloc(sizeof *data);
-  if (check_flag((void *)data, "malloc", 2)) return(1);
+  if (check_retval((void *)data, "malloc", 2)) return(1);
   data->p[0] = RCONST(0.04);
   data->p[1] = RCONST(1.0e4);
   data->p[2] = RCONST(3.0e7);
 
   /* Initial conditions */
   y = N_VNew_Serial(NEQ);
-  if (check_flag((void *)y, "N_VNew_Serial", 0)) return(1);
+  if (check_retval((void *)y, "N_VNew_Serial", 0)) return(1);
 
   Ith(y,1) = Y1;
   Ith(y,2) = Y2;
   Ith(y,3) = Y3;
 
   /* Call CVodeCreate to create the solver memory and specify the 
-     Backward Differentiation Formula and the use of a Newton iteration */
-  cvode_mem = CVodeCreate(CV_BDF, CV_NEWTON);
-  if (check_flag((void *)cvode_mem, "CVodeCreate", 0)) return(1);
+     Backward Differentiation Formula */
+  cvode_mem = CVodeCreate(CV_BDF);
+  if (check_retval((void *)cvode_mem, "CVodeCreate", 0)) return(1);
 
   /* Call CVodeInit to initialize the integrator memory and specify the
      user's right hand side function in y'=f(t,y), the initial time T0, and
      the initial dependent variable vector y. */
-  flag = CVodeInit(cvode_mem, f, T0, y);
-  if (check_flag(&flag, "CVodeInit", 1)) return(1);
+  retval = CVodeInit(cvode_mem, f, T0, y);
+  if (check_retval(&retval, "CVodeInit", 1)) return(1);
 
   /* Call CVodeWFtolerances to specify a user-supplied function ewt that sets
-     the multiplicative error weights W_i for use in the weighted RMS norm */
-  flag = CVodeWFtolerances(cvode_mem, ewt);
-  if (check_flag(&flag, "CVodeSetEwtFn", 1)) return(1);
+     the multiplicative error weights w_i for use in the weighted RMS norm */
+  retval = CVodeWFtolerances(cvode_mem, ewt);
+  if (check_retval(&retval, "CVodeWFtolerances", 1)) return(1);
 
   /* Attach user data */
-  flag = CVodeSetUserData(cvode_mem, data);
-  if (check_flag(&flag, "CVodeSetUserData", 1)) return(1);
+  retval = CVodeSetUserData(cvode_mem, data);
+  if (check_retval(&retval, "CVodeSetUserData", 1)) return(1);
 
-  /* Call CVKLU to specify the CVKLU sparse direct linear solver */
-  nthreads = 1;                 /* no. of threads to use when factoring the system*/
-  nnz = NEQ * NEQ;              /* max no. of nonzeros entries in the Jac */
-  flag = CVSuperLUMT(cvode_mem, nthreads, NEQ, nnz);
-  if (check_flag(&flag, "CVSuperLUMT", 1)) return(1);
+  /* Create sparse SUNMatrix for use in linear solves */
+  nnz = NEQ * NEQ; /* max no. of nonzeros entries in the Jac */
+  A = SUNSparseMatrix(NEQ, NEQ, nnz, CSC_MAT);
+  if (check_retval((void *)A, "SUNSparseMatrix", 0)) return(1);
+
+  /* Create SuperLUMT SUNLinearSolver object */
+  nthreads = 1; /* no. of threads use when factoring the system */
+  LS = SUNLinSol_SuperLUMT(y, A, nthreads);
+  if (check_retval((void *)LS, "SUNLinSol_SuperLUMT", 0)) return(1);
+
+  /* Attach the matrix and linear solver */
+  retval = CVodeSetLinearSolver(cvode_mem, LS, A);
+  if (check_retval(&retval, "CVodeSetLinearSolver", 1)) return(1);
 
   /* Set the Jacobian routine to Jac (user-supplied) */
-  flag = CVSlsSetSparseJacFn(cvode_mem, Jac);
-  if (check_flag(&flag, "CVSlsSetSparseJacFn", 1)) return(1);
+  retval = CVodeSetJacFn(cvode_mem, Jac);
+  if (check_retval(&retval, "CVodeSetJacFn", 1)) return(1);
 
   printf("\n3-species chemical kinetics problem\n");
 
@@ -201,33 +213,33 @@ int main(int argc, char *argv[])
     pbar[2] = data->p[2];
 
     /* Set sensitivity initial conditions */
-    yS = N_VCloneVectorArray_Serial(NS, y);
-    if (check_flag((void *)yS, "N_VCloneVectorArray_Serial", 0)) return(1);
+    yS = N_VCloneVectorArray(NS, y);
+    if (check_retval((void *)yS, "N_VCloneVectorArray", 0)) return(1);
     for (is=0;is<NS;is++) N_VConst(ZERO, yS[is]);
 
     /* Call CVodeSensInit1 to activate forward sensitivity computations
        and allocate internal memory for COVEDS related to sensitivity
        calculations. Computes the right-hand sides of the sensitivity
        ODE, one at a time */
-    flag = CVodeSensInit1(cvode_mem, NS, sensi_meth, fS, yS);
-    if(check_flag(&flag, "CVodeSensInit", 1)) return(1);
+    retval = CVodeSensInit1(cvode_mem, NS, sensi_meth, fS, yS);
+    if(check_retval(&retval, "CVodeSensInit", 1)) return(1);
 
     /* Call CVodeSensEEtolerances to estimate tolerances for sensitivity 
        variables based on the rolerances supplied for states variables and 
        the scaling factor pbar */
-    flag = CVodeSensEEtolerances(cvode_mem);
-    if(check_flag(&flag, "CVodeSensEEtolerances", 1)) return(1);
+    retval = CVodeSensEEtolerances(cvode_mem);
+    if(check_retval(&retval, "CVodeSensEEtolerances", 1)) return(1);
 
     /* Set sensitivity analysis optional inputs */
     /* Call CVodeSetSensErrCon to specify the error control strategy for 
        sensitivity variables */
-    flag = CVodeSetSensErrCon(cvode_mem, err_con);
-    if (check_flag(&flag, "CVodeSetSensErrCon", 1)) return(1);
+    retval = CVodeSetSensErrCon(cvode_mem, err_con);
+    if (check_retval(&retval, "CVodeSetSensErrCon", 1)) return(1);
 
     /* Call CVodeSetSensParams to specify problem parameter information for 
        sensitivity calculations */
-    flag = CVodeSetSensParams(cvode_mem, NULL, pbar, NULL);
-    if (check_flag(&flag, "CVodeSetSensParams", 1)) return(1);
+    retval = CVodeSetSensParams(cvode_mem, NULL, pbar, NULL);
+    if (check_retval(&retval, "CVodeSetSensParams", 1)) return(1);
 
     printf("Sensitivity: YES ");
     if(sensi_meth == CV_SIMULTANEOUS)   
@@ -256,16 +268,16 @@ int main(int argc, char *argv[])
 
   for (iout=1, tout=T1; iout <= NOUT; iout++, tout *= TMULT) {
 
-    flag = CVode(cvode_mem, tout, y, &t, CV_NORMAL);
-    if (check_flag(&flag, "CVode", 1)) break;
+    retval = CVode(cvode_mem, tout, y, &t, CV_NORMAL);
+    if (check_retval(&retval, "CVode", 1)) break;
 
     PrintOutput(cvode_mem, t, y);
 
     /* Call CVodeGetSens to get the sensitivity solution vector after a
        successful return from CVode */
     if (sensi) {
-      flag = CVodeGetSens(cvode_mem, &t, yS);
-      if (check_flag(&flag, "CVodeGetSens", 1)) break;
+      retval = CVodeGetSens(cvode_mem, &t, yS);
+      if (check_retval(&retval, "CVodeGetSens", 1)) break;
       PrintOutputS(yS);
     } 
     printf("-----------------------------------------");
@@ -278,12 +290,14 @@ int main(int argc, char *argv[])
 
   /* Free memory */
 
-  N_VDestroy_Serial(y);                    /* Free y vector */
+  N_VDestroy(y);                    /* Free y vector */
   if (sensi) {
-    N_VDestroyVectorArray_Serial(yS, NS);  /* Free yS vector */
+    N_VDestroyVectorArray(yS, NS);  /* Free yS vector */
   }
   free(data);                              /* Free user data */
   CVodeFree(&cvode_mem);                   /* Free CVODES memory */
+  SUNLinSolFree(LS);                       /* Free the linear solver memory */
+  SUNMatDestroy(A);                        /* Free the matrix memory */
 
   return(0);
 }
@@ -315,51 +329,56 @@ static int f(realtype t, N_Vector y, N_Vector ydot, void *user_data)
   return(0);
 }
 
-
 /* 
  * Jacobian routine. Compute J(t,y). 
  */
 
-static int Jac(realtype t,
-	       N_Vector y, N_Vector fy, SlsMat JacMat, void *user_data, 
-               N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
+static int Jac(realtype t, N_Vector y, N_Vector fy, SUNMatrix J,
+               void *user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)
 {
   realtype *yval;
-  int* colptrs;
-  int* rowvals;
-  realtype* data;
+  sunindextype *colptrs = SUNSparseMatrix_IndexPointers(J);
+  sunindextype *rowvals = SUNSparseMatrix_IndexValues(J);
+  realtype *data = SUNSparseMatrix_Data(J);
   UserData userdata;
   realtype p1, p2, p3;
  
-  yval = N_VGetArrayPointer_Serial(y);
-  colptrs = (*JacMat->colptrs);
-  rowvals = (*JacMat->rowvals);
-  data = JacMat->data;
+  yval = N_VGetArrayPointer(y);
+
   userdata = (UserData) user_data;
   p1 = userdata->p[0]; p2 = userdata->p[1]; p3 = userdata->p[2];
 
-  SparseSetMatToZero(JacMat);
+  SUNMatZero(J);
   
   colptrs[0] = 0;
   colptrs[1] = 3;
   colptrs[2] = 6;
   colptrs[3] = 9;
 
-  data[0] = -p1;                          rowvals[0] = 0;
-  data[1] = p1;                           rowvals[1] = 1;
-  data[2] = ZERO;                         rowvals[2] = 2;
+  data[0] = -p1;
+  rowvals[0] = 0;
+  data[1] = p1;
+  rowvals[1] = 1;
+  data[2] = ZERO;
+  rowvals[2] = 2;
 
-  data[3] = p2*yval[2];                   rowvals[3] = 0;
-  data[4] = -p2*yval[2]-2*p3*yval[1];     rowvals[4] = 1;
-  data[5] = 2*yval[1];                    rowvals[5] = 2;
+  data[3] = p2*yval[2];
+  rowvals[3] = 0;
+  data[4] = -p2*yval[2]-2*p3*yval[1];
+  rowvals[4] = 1;
+  data[5] = 2*yval[1];
+  rowvals[5] = 2;
   
-  data[6] = p2*yval[1];                   rowvals[6] = 0;
-  data[7] = -p2*yval[1];                  rowvals[7] = 1;
-  data[8] = ZERO;                         rowvals[8] = 2;
- 
+  data[6] = p2*yval[1];
+  rowvals[6] = 0;
+  data[7] = -p2*yval[1];
+  rowvals[7] = 1;
+  data[8] = ZERO;
+  rowvals[8] = 2;
+
   return(0);
 }
- 
+
 /* 
  * fS routine. Compute sensitivity r.h.s. CVSensRhs1Fn is compatible with any
  * valid value of the argument ism to CVodeSensInit and CVodeSensInit1
@@ -444,16 +463,16 @@ static int ewt(N_Vector y, N_Vector w, void *user_data)
 static void ProcessArgs(int argc, char *argv[], 
                         booleantype *sensi, int *sensi_meth, booleantype *err_con)
 {
-  *sensi = FALSE;
+  *sensi = SUNFALSE;
   *sensi_meth = -1;
-  *err_con = FALSE;
+  *err_con = SUNFALSE;
 
   if (argc < 2) WrongArgs(argv[0]);
 
   if (strcmp(argv[1],"-nosensi") == 0)
-    *sensi = FALSE;
+    *sensi = SUNFALSE;
   else if (strcmp(argv[1],"-sensi") == 0)
-    *sensi = TRUE;
+    *sensi = SUNTRUE;
   else
     WrongArgs(argv[0]);
   
@@ -472,9 +491,9 @@ static void ProcessArgs(int argc, char *argv[],
       WrongArgs(argv[0]);
 
     if (strcmp(argv[3],"t") == 0)
-      *err_con = TRUE;
+      *err_con = SUNTRUE;
     else if (strcmp(argv[3],"f") == 0)
-      *err_con = FALSE;
+      *err_con = SUNFALSE;
     else
       WrongArgs(argv[0]);
   }
@@ -497,17 +516,17 @@ static void WrongArgs(char *name)
 static void PrintOutput(void *cvode_mem, realtype t, N_Vector u)
 {
   long int nst;
-  int qu, flag;
+  int qu, retval;
   realtype hu, *udata;
   
-  udata = N_VGetArrayPointer_Serial(u);
+  udata = N_VGetArrayPointer(u);
 
-  flag = CVodeGetNumSteps(cvode_mem, &nst);
-  check_flag(&flag, "CVodeGetNumSteps", 1);
-  flag = CVodeGetLastOrder(cvode_mem, &qu);
-  check_flag(&flag, "CVodeGetLastOrder", 1);
-  flag = CVodeGetLastStep(cvode_mem, &hu);
-  check_flag(&flag, "CVodeGetLastStep", 1);
+  retval = CVodeGetNumSteps(cvode_mem, &nst);
+  check_retval(&retval, "CVodeGetNumSteps", 1);
+  retval = CVodeGetLastOrder(cvode_mem, &qu);
+  check_retval(&retval, "CVodeGetLastOrder", 1);
+  retval = CVodeGetLastStep(cvode_mem, &hu);
+  check_retval(&retval, "CVodeGetLastStep", 1);
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("%8.3Le %2d  %8.3Le %5ld\n", t, qu, hu, nst);
@@ -537,7 +556,7 @@ static void PrintOutputS(N_Vector *uS)
 {
   realtype *sdata;
 
-  sdata = N_VGetArrayPointer_Serial(uS[0]);
+  sdata = N_VGetArrayPointer(uS[0]);
   printf("                  Sensitivity 1  ");
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
@@ -548,7 +567,7 @@ static void PrintOutputS(N_Vector *uS)
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
   
-  sdata = N_VGetArrayPointer_Serial(uS[1]);
+  sdata = N_VGetArrayPointer(uS[1]);
   printf("                  Sensitivity 2  ");
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
@@ -559,7 +578,7 @@ static void PrintOutputS(N_Vector *uS)
   printf("%12.4e %12.4e %12.4e \n", sdata[0], sdata[1], sdata[2]);
 #endif
 
-  sdata = N_VGetArrayPointer_Serial(uS[2]);
+  sdata = N_VGetArrayPointer(uS[2]);
   printf("                  Sensitivity 3  ");
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
@@ -581,38 +600,38 @@ static void PrintFinalStats(void *cvode_mem, booleantype sensi)
   long int nfe, nsetups, nni, ncfn, netf;
   long int nfSe, nfeS, nsetupsS, nniS, ncfnS, netfS;
   long int nje;
-  int flag;
+  int retval;
 
-  flag = CVodeGetNumSteps(cvode_mem, &nst);
-  check_flag(&flag, "CVodeGetNumSteps", 1);
-  flag = CVodeGetNumRhsEvals(cvode_mem, &nfe);
-  check_flag(&flag, "CVodeGetNumRhsEvals", 1);
-  flag = CVodeGetNumLinSolvSetups(cvode_mem, &nsetups);
-  check_flag(&flag, "CVodeGetNumLinSolvSetups", 1);
-  flag = CVodeGetNumErrTestFails(cvode_mem, &netf);
-  check_flag(&flag, "CVodeGetNumErrTestFails", 1);
-  flag = CVodeGetNumNonlinSolvIters(cvode_mem, &nni);
-  check_flag(&flag, "CVodeGetNumNonlinSolvIters", 1);
-  flag = CVodeGetNumNonlinSolvConvFails(cvode_mem, &ncfn);
-  check_flag(&flag, "CVodeGetNumNonlinSolvConvFails", 1);
+  retval = CVodeGetNumSteps(cvode_mem, &nst);
+  check_retval(&retval, "CVodeGetNumSteps", 1);
+  retval = CVodeGetNumRhsEvals(cvode_mem, &nfe);
+  check_retval(&retval, "CVodeGetNumRhsEvals", 1);
+  retval = CVodeGetNumLinSolvSetups(cvode_mem, &nsetups);
+  check_retval(&retval, "CVodeGetNumLinSolvSetups", 1);
+  retval = CVodeGetNumErrTestFails(cvode_mem, &netf);
+  check_retval(&retval, "CVodeGetNumErrTestFails", 1);
+  retval = CVodeGetNumNonlinSolvIters(cvode_mem, &nni);
+  check_retval(&retval, "CVodeGetNumNonlinSolvIters", 1);
+  retval = CVodeGetNumNonlinSolvConvFails(cvode_mem, &ncfn);
+  check_retval(&retval, "CVodeGetNumNonlinSolvConvFails", 1);
 
   if (sensi) {
-    flag = CVodeGetSensNumRhsEvals(cvode_mem, &nfSe);
-    check_flag(&flag, "CVodeGetSensNumRhsEvals", 1);
-    flag = CVodeGetNumRhsEvalsSens(cvode_mem, &nfeS);
-    check_flag(&flag, "CVodeGetNumRhsEvalsSens", 1);
-    flag = CVodeGetSensNumLinSolvSetups(cvode_mem, &nsetupsS);
-    check_flag(&flag, "CVodeGetSensNumLinSolvSetups", 1);
-    flag = CVodeGetSensNumErrTestFails(cvode_mem, &netfS);
-    check_flag(&flag, "CVodeGetSensNumErrTestFails", 1);
-    flag = CVodeGetSensNumNonlinSolvIters(cvode_mem, &nniS);
-    check_flag(&flag, "CVodeGetSensNumNonlinSolvIters", 1);
-    flag = CVodeGetSensNumNonlinSolvConvFails(cvode_mem, &ncfnS);
-    check_flag(&flag, "CVodeGetSensNumNonlinSolvConvFails", 1);
+    retval = CVodeGetSensNumRhsEvals(cvode_mem, &nfSe);
+    check_retval(&retval, "CVodeGetSensNumRhsEvals", 1);
+    retval = CVodeGetNumRhsEvalsSens(cvode_mem, &nfeS);
+    check_retval(&retval, "CVodeGetNumRhsEvalsSens", 1);
+    retval = CVodeGetSensNumLinSolvSetups(cvode_mem, &nsetupsS);
+    check_retval(&retval, "CVodeGetSensNumLinSolvSetups", 1);
+    retval = CVodeGetSensNumErrTestFails(cvode_mem, &netfS);
+    check_retval(&retval, "CVodeGetSensNumErrTestFails", 1);
+    retval = CVodeGetSensNumNonlinSolvIters(cvode_mem, &nniS);
+    check_retval(&retval, "CVodeGetSensNumNonlinSolvIters", 1);
+    retval = CVodeGetSensNumNonlinSolvConvFails(cvode_mem, &ncfnS);
+    check_retval(&retval, "CVodeGetSensNumNonlinSolvConvFails", 1);
   }
 
-  flag = CVSlsGetNumJacEvals(cvode_mem, &nje);
-  check_flag(&flag, "CVDlsGetNumJacEvals", 1);
+  retval = CVodeGetNumJacEvals(cvode_mem, &nje);
+  check_retval(&retval, "CVodeGetNumJacEvals", 1);
 
   printf("\nFinal Statistics\n\n");
   printf("nst     = %5ld\n\n", nst);
@@ -636,34 +655,34 @@ static void PrintFinalStats(void *cvode_mem, booleantype sensi)
  * Check function return value.
  *    opt == 0 means SUNDIALS function allocates memory so check if
  *             returned NULL pointer
- *    opt == 1 means SUNDIALS function returns a flag so check if
- *             flag >= 0
+ *    opt == 1 means SUNDIALS function returns an integer value so check if
+ *             retval < 0
  *    opt == 2 means function allocates memory so check if returned
  *             NULL pointer 
  */
 
-static int check_flag(void *flagvalue, const char *funcname, int opt)
+static int check_retval(void *returnvalue, const char *funcname, int opt)
 {
-  int *errflag;
+  int *retval;
 
   /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-  if (opt == 0 && flagvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL) {
     fprintf(stderr, 
             "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
 	    funcname);
     return(1); }
 
-  /* Check if flag < 0 */
+  /* Check if retval < 0 */
   else if (opt == 1) {
-    errflag = (int *) flagvalue;
-    if (*errflag < 0) {
+    retval = (int *) returnvalue;
+    if (*retval < 0) {
       fprintf(stderr, 
-              "\nSUNDIALS_ERROR: %s() failed with flag = %d\n\n",
-	      funcname, *errflag);
+              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
+	      funcname, *retval);
       return(1); }}
 
   /* Check if function returned NULL pointer - no memory allocated */
-  else if (opt == 2 && flagvalue == NULL) {
+  else if (opt == 2 && returnvalue == NULL) {
     fprintf(stderr, 
             "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
 	    funcname);
