@@ -2,10 +2,20 @@
  * -----------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds and Ting Yan @ SMU
  * -----------------------------------------------------------------
- * Example program for IDA: Food web problem, OpenMP, GMRES, 
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
+ * All rights reserved.
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
+ * -----------------------------------------------------------------
+ * Example program for IDA: Food web problem, OpenMP, GMRES,
  * user-supplied preconditioner
  *
- * This example program uses SUNSPGMR as the linear 
+ * This example program uses SUNLinSol_SPGMR as the linear
  * solver, and IDACalcIC for initial condition calculation.
  *
  * The mathematical problem solved in this example is a DAE system
@@ -59,22 +69,22 @@
  * The PDEs are discretized by central differencing on a MX by MY
  * mesh.
  *
- * The DAE system is solved by IDA using the SUNSPGMR linear solver.
+ * The DAE system is solved by IDA using the SUNLinSol_SPGMR linear solver.
  * Output is printed at t = 0, .001, .01, .1, .4, .7, 1.
  *
- * Optionally, we can set the number of threads from environment 
+ * Optionally, we can set the number of threads from environment
  * variable or command line. To check the current value for number
  * of threads from environment:
  *      % echo $OMP_NUM_THREADS
  *
  * Execution:
  *
- * To use the default value for the number of threads from 
+ * To use the default value for the number of threads from
  * the OMP_NUM_THREADS environment value:
- *      % ./idaFoodWeb_kry_omp 
+ *      % ./idaFoodWeb_kry_omp
  * To specify the number of threads at the command line, use
  *      % ./idaFoodWeb_kry_omp num_threads
- * where num_threads is the desired number of threads. 
+ * where num_threads is the desired number of threads.
  *
  * -----------------------------------------------------------------
  * References:
@@ -100,7 +110,6 @@
 #include <math.h>
 
 #include <ida/ida.h>
-#include <ida/ida_spils.h>
 #include <sunlinsol/sunlinsol_spgmr.h>
 #include <nvector/nvector_openmp.h>
 #include <sundials/sundials_dense.h>
@@ -138,15 +147,15 @@
 #define NOUT        6              /* Number of output times            */
 #define TMULT       RCONST(10.0)   /* Multiplier for tout values        */
 #define TADD        RCONST(0.3)    /* Increment for tout values         */
-#define ZERO        RCONST(0.)     
-#define ONE         RCONST(1.0)    
+#define ZERO        RCONST(0.)
+#define ONE         RCONST(1.0)
 
-/* 
+/*
  * User-defined vector and accessor macro: IJ_Vptr.
- * IJ_Vptr is defined in order to express the underlying 3-D structure of 
+ * IJ_Vptr is defined in order to express the underlying 3-D structure of
  * the dependent variable vector from its underlying 1-D storage (an N_Vector).
- * IJ_Vptr(vv,i,j) returns a pointer to the location in vv corresponding to 
- * species index is = 0, x-index ix = i, and y-index jy = j.                
+ * IJ_Vptr(vv,i,j) returns a pointer to the location in vv corresponding to
+ * species index is = 0, x-index ix = i, and y-index jy = j.
  */
 
 #define IJ_Vptr(vv,i,j) (&NV_Ith_OMP(vv, (i)*NUM_SPECIES + (j)*NSMX))
@@ -167,7 +176,7 @@ typedef struct {
 
 /* Prototypes for functions called by the IDA Solver. */
 
-static int resweb(realtype time, N_Vector cc, N_Vector cp, N_Vector resval, 
+static int resweb(realtype time, N_Vector cc, N_Vector cp, N_Vector resval,
                   void *user_data);
 
 static int Precond(realtype tt, N_Vector cc, N_Vector cp,
@@ -186,10 +195,10 @@ static void PrintHeader(int maxl, realtype rtol, realtype atol);
 static void PrintOutput(void *ida_mem, N_Vector c, realtype t);
 static void PrintFinalStats(void *ida_mem);
 static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate, UserData webdata);
-static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy, 
+static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
                      UserData webdata);
 static realtype dotprod(sunindextype size, realtype *x1, realtype *x2);
-static int check_flag(void *flagvalue, char *funcname, int opt);
+static int check_retval(void *returnvalue, char *funcname, int opt);
 
 /*
  *--------------------------------------------------------------------
@@ -198,12 +207,12 @@ static int check_flag(void *flagvalue, char *funcname, int opt);
  */
 
 int main(int argc, char *argv[])
-{ 
+{
   void *ida_mem;
   SUNLinearSolver LS;
   UserData webdata;
   N_Vector cc, cp, id;
-  int iout, jx, jy, flag;
+  int iout, jx, jy, retval;
   int maxl;
   realtype rtol, atol, t0, tout, tret;
   int num_threads;
@@ -240,80 +249,80 @@ int main(int argc, char *argv[])
   /* Allocate N-vectors and initialize cc, cp, and id. */
 
   cc  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_flag((void *)cc, "N_VNew_OpenMP", 0)) return(1);
+  if(check_retval((void *)cc, "N_VNew_OpenMP", 0)) return(1);
 
   cp  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_flag((void *)cp, "N_VNew_OpenMP", 0)) return(1);
+  if(check_retval((void *)cp, "N_VNew_OpenMP", 0)) return(1);
 
   id  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_flag((void *)id, "N_VNew_OpenMP", 0)) return(1);
-  
+  if(check_retval((void *)id, "N_VNew_OpenMP", 0)) return(1);
+
   SetInitialProfiles(cc, cp, id, webdata);
-  
+
   /* Set remaining inputs to IDAMalloc. */
-  
+
   t0 = ZERO;
-  rtol = RTOL; 
+  rtol = RTOL;
   atol = ATOL;
 
   /* Call IDACreate and IDAMalloc to initialize IDA. */
-  
+
   ida_mem = IDACreate();
-  if(check_flag((void *)ida_mem, "IDACreate", 0)) return(1);
+  if(check_retval((void *)ida_mem, "IDACreate", 0)) return(1);
 
-  flag = IDASetUserData(ida_mem, webdata);
-  if(check_flag(&flag, "IDASetUserData", 1)) return(1);
+  retval = IDASetUserData(ida_mem, webdata);
+  if(check_retval(&retval, "IDASetUserData", 1)) return(1);
 
-  flag = IDASetId(ida_mem, id);
-  if(check_flag(&flag, "IDASetId", 1)) return(1);
+  retval = IDASetId(ida_mem, id);
+  if(check_retval(&retval, "IDASetId", 1)) return(1);
 
-  flag = IDAInit(ida_mem, resweb, t0, cc, cp);
-  if(check_flag(&flag, "IDAInit", 1)) return(1);
+  retval = IDAInit(ida_mem, resweb, t0, cc, cp);
+  if(check_retval(&retval, "IDAInit", 1)) return(1);
 
-  flag = IDASStolerances(ida_mem, rtol, atol);
-  if(check_flag(&flag, "IDASStolerances", 1)) return(1);
+  retval = IDASStolerances(ida_mem, rtol, atol);
+  if(check_retval(&retval, "IDASStolerances", 1)) return(1);
 
   webdata->ida_mem = ida_mem;
 
-  /* Create SUNSPGMR linear solver, attach to IDA, and set 
+  /* Create SUNLinSol_SPGMR linear solver, attach to IDA, and set
      preconditioning routines. */
 
   maxl = 16;                               /* max dimension of the Krylov subspace */
-  LS = SUNSPGMR(cc, PREC_LEFT, maxl);      /* IDA only allows left preconditioning */
-  if(check_flag((void *)LS, "SUNSPGMR", 0)) return(1);
+  LS = SUNLinSol_SPGMR(cc, PREC_LEFT, maxl);      /* IDA only allows left preconditioning */
+  if(check_retval((void *)LS, "SUNLinSol_SPGMR", 0)) return(1);
 
-  flag = IDASpilsSetLinearSolver(ida_mem, LS);
-  if(check_flag(&flag, "IDASpilsSetLinearSolver", 1)) return(1);
+  retval = IDASetLinearSolver(ida_mem, LS, NULL);
+  if(check_retval(&retval, "IDASetLinearSolver", 1)) return(1);
 
-  flag = IDASpilsSetPreconditioner(ida_mem, Precond, PSolve);
-  if(check_flag(&flag, "IDASpilsSetPreconditioner", 1)) return(1);
+  retval = IDASetPreconditioner(ida_mem, Precond, PSolve);
+  if(check_retval(&retval, "IDASetPreconditioner", 1)) return(1);
 
   /* Call IDACalcIC (with default options) to correct the initial values. */
 
   tout = RCONST(0.001);
-  flag = IDACalcIC(ida_mem, IDA_YA_YDP_INIT, tout);
-  if(check_flag(&flag, "IDACalcIC", 1)) return(1);
-  
+  retval = IDACalcIC(ida_mem, IDA_YA_YDP_INIT, tout);
+  if(check_retval(&retval, "IDACalcIC", 1)) return(1);
+
   /* Print heading, basic parameters, and initial values. */
 
   PrintHeader(maxl, rtol, atol);
   PrintOutput(ida_mem, cc, ZERO);
-  
+
   /* Loop over iout, call IDASolve (normal mode), print selected output. */
-  
+
   for (iout = 1; iout <= NOUT; iout++) {
-    
-    flag = IDASolve(ida_mem, tout, &tret, cc, cp, IDA_NORMAL);
-    if(check_flag(&flag, "IDASolve", 1)) return(flag);
-    
+
+    retval = IDASolve(ida_mem, tout, &tret, cc, cp, IDA_NORMAL);
+    if(check_retval(&retval, "IDASolve", 1)) return(retval);
+
     PrintOutput(ida_mem, cc, tret);
-    
+
     if (iout < 3) tout *= TMULT; else tout += TADD;
-    
+
   }
-  
-  /* Print final statistics and free memory. */  
-  
+
+  /* Print final statistics and free memory. */
+
   PrintFinalStats(ida_mem);
   printf("num_threads = %i\n\n", num_threads);
 
@@ -341,7 +350,7 @@ int main(int argc, char *argv[])
   return(0);
 }
 
-/* Define lines for readability in later routines */ 
+/* Define lines for readability in later routines */
 
 #define acoef  (webdata->acoef)
 #define bcoef  (webdata->bcoef)
@@ -354,32 +363,32 @@ int main(int argc, char *argv[])
  *--------------------------------------------------------------------
  */
 
-/* 
+/*
  * resweb: System residual function for predator-prey system.
  * This routine calls Fweb to get all the right-hand sides of the
  * equations, then loads the residual vector accordingly,
- * using cp in the case of prey species.                 
+ * using cp in the case of prey species.
  */
 
-static int resweb(realtype tt, N_Vector cc, N_Vector cp, 
+static int resweb(realtype tt, N_Vector cc, N_Vector cp,
                   N_Vector res,  void *user_data)
 {
   sunindextype jx, jy, is, yloc, loc, np;
   realtype *resv, *cpv;
   UserData webdata;
-  
+
   webdata = (UserData)user_data;
-  
+
   cpv = NV_DATA_OMP(cp);
   resv = NV_DATA_OMP(res);
   np = webdata->np;
-  
+
   /* Call Fweb to set res to vector of right-hand sides. */
   Fweb(tt, cc, res, webdata);
-  
+
   /* Loop over all grid points, setting residual values appropriately
      for differential or algebraic components.                        */
-#pragma omp parallel for default(shared) private(jy, jx, is, yloc, loc) schedule(static) num_threads(webdata->nthreads)  
+#pragma omp parallel for default(shared) private(jy, jx, is, yloc, loc) schedule(static) num_threads(webdata->nthreads)
   for (jy = 0; jy < MY; jy++) {
     yloc = NSMX * jy;
     for (jx = 0; jx < MX; jx++) {
@@ -392,16 +401,16 @@ static int resweb(realtype tt, N_Vector cc, N_Vector cp,
       }
     }
   }
-  
+
   return(0);
-  
+
 }
 
 
 static int Precond(realtype tt, N_Vector cc, N_Vector cp,
                    N_Vector rr, realtype cj, void *user_data)
 {
-  int flag;
+  int retval;
   realtype uround, xx, yy, del_x, del_y;
   realtype **Pxy, *ratesxy, *Pxycol, *cxy, *cpxy, *ewtxy, cctmp;
   realtype inc, fac, sqru, perturb_rates[NUM_SPECIES];
@@ -420,14 +429,14 @@ static int Precond(realtype tt, N_Vector cc, N_Vector cp,
 
   ida_mem = webdata->ida_mem;
   ewt = webdata->ewt;
-  flag = IDAGetErrWeights(ida_mem, ewt);
-  if(check_flag(&flag, "IDAGetErrWeights", 1)) return(1);
-  flag = IDAGetCurrentStep(ida_mem, &hh);
-  if(check_flag(&flag, "IDAGetCurrentStep", 1)) return(1);
+  retval = IDAGetErrWeights(ida_mem, ewt);
+  if(check_retval(&retval, "IDAGetErrWeights", 1)) return(1);
+  retval = IDAGetCurrentStep(ida_mem, &hh);
+  if(check_retval(&retval, "IDAGetCurrentStep", 1)) return(1);
 
   for (jy = 0; jy < MY; jy++) {
     yy = jy * del_y;
-    
+
     for (jx = 0; jx < MX; jx++) {
       xx = jx * del_x;
       Pxy = (webdata->PP)[jx][jy];
@@ -445,12 +454,12 @@ static int Precond(realtype tt, N_Vector cc, N_Vector cp,
 	WebRates(xx, yy, cxy, perturb_rates, webdata);
 
 	Pxycol = Pxy[js];
-	
+
 	for (is = 0; is < NUM_SPECIES; is++)
 	  Pxycol[is] = (perturb_rates[is] - ratesxy[is])*fac;
 
 	if (js < 1) Pxycol[js] += cj;
-	
+
 	cxy[js] = cctmp;
       }
 
@@ -467,13 +476,13 @@ static int Precond(realtype tt, N_Vector cc, N_Vector cp,
 
 static int PSolve(realtype tt, N_Vector cc, N_Vector cp,
                   N_Vector rr, N_Vector rvec, N_Vector zvec,
-		  realtype cj, realtype dalta, void *user_data) 
+		  realtype cj, realtype dalta, void *user_data)
 {
   realtype **Pxy, *zxy;
   sunindextype *pivot;
   int jx, jy;
   UserData webdata;
-  
+
   webdata = (UserData) user_data;
 
   N_VScale(ONE, rvec, zvec);
@@ -481,14 +490,14 @@ static int PSolve(realtype tt, N_Vector cc, N_Vector cp,
 #pragma omp parallel for collapse(2) default(shared) private(jx, jy, zxy, Pxy, pivot) schedule(static) num_threads(webdata->nthreads)
   for (jx = 0; jx < MX; jx++) {
     for (jy = 0; jy <MY; jy++) {
-      
+
       zxy = IJ_Vptr(zvec, jx, jy);
       Pxy = (webdata->PP)[jx][jy];
       pivot = (webdata->pivot)[jx][jy];
       denseGETRS(Pxy, NUM_SPECIES, pivot, zxy);
     }
   }
-  
+
   return(0);
 
 }
@@ -501,7 +510,7 @@ static int PSolve(realtype tt, N_Vector cc, N_Vector cp,
  */
 
 /*
- * InitUserData: Load problem constants in webdata (of type UserData).   
+ * InitUserData: Load problem constants in webdata (of type UserData).
  */
 
 static void InitUserData(UserData webdata)
@@ -516,11 +525,11 @@ static void InitUserData(UserData webdata)
   webdata->dx = AX/(MX-1);
   webdata->dy = AY/(MY-1);
   webdata->Neq= NEQ;
-  
+
   /* Set up the coefficients a and b, and others found in the equations. */
   np = webdata->np;
   dx2 = (webdata->dx)*(webdata->dx); dy2 = (webdata->dy)*(webdata->dy);
-  
+
   for (i = 0; i < np; i++) {
     a1 = &(acoef[i][np]);
     a2 = &(acoef[i+np][0]);
@@ -533,25 +542,25 @@ static void InitUserData(UserData webdata)
       *a3++ = ZERO;
       *a4++ = ZERO;
     }
-    
+
     /* Reset the diagonal elements of acoef to -AA. */
     acoef[i][i] = -AA; acoef[i+np][i+np] = -AA;
-    
+
     /* Set coefficients for b and diffusion terms. */
     bcoef[i] = BB; bcoef[i+np] = -BB;
     cox[i] = DPREY/dx2; cox[i+np] = DPRED/dx2;
     coy[i] = DPREY/dy2; coy[i+np] = DPRED/dy2;
   }
-  
+
 }
 
-/* 
+/*
  * SetInitialProfiles: Set initial conditions in cc, cp, and id.
  * A polynomial profile is used for the prey cc values, and a constant
  * (1.0e5) is loaded as the initial guess for the predator cc values.
  * The id values are set to 1 for the prey and 0 for the predators.
  * The prey cp values are set according to the given system, and
- * the predator cp values are set to zero.                               
+ * the predator cp values are set to zero.
  */
 
 static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
@@ -560,12 +569,12 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
   sunindextype loc, yloc, is, jx, jy, np;
   realtype xx, yy, xyfactor;
   realtype *ccv, *cpv, *idv;
-  
+
   ccv = NV_DATA_OMP(cc);
   cpv = NV_DATA_OMP(cp);
   idv = NV_DATA_OMP(id);
   np = webdata->np;
-  
+
   /* Loop over grid, load cc values and id values. */
   for (jy = 0; jy < MY; jy++) {
     yy = jy * webdata->dy;
@@ -575,7 +584,7 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
       xyfactor = RCONST(16.0)*xx*(ONE-xx)*yy*(ONE-yy);
       xyfactor *= xyfactor;
       loc = yloc + NUM_SPECIES*jx;
-       
+
       for (is = 0; is < NUM_SPECIES; is++) {
         if (is < np) {
           ccv[loc+is] = RCONST(10.0) + (realtype)(is+1) * xyfactor;
@@ -588,10 +597,10 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
       }
     }
   }
-  
+
   /* Set c' for the prey by calling the function Fweb. */
   Fweb(ZERO, cc, cp, webdata);
-  
+
   /* Set c' for predators to 0. */
   for (jy = 0; jy < MY; jy++) {
     yloc = NSMX * jy;
@@ -614,56 +623,56 @@ static void PrintHeader(int maxl, realtype rtol, realtype atol)
   printf("Number of species ns: %d", NUM_SPECIES);
   printf("     Mesh dimensions: %d x %d", MX, MY);
   printf("     System size: %d\n", NEQ);
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
+#if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
-  printf("Linear solver: SUNSPGMR, maxl = %d\n",maxl);
+  printf("Linear solver: SUNLinSol_SPGMR, maxl = %d\n",maxl);
   printf("CalcIC called to correct initial predator concentrations.\n\n");
   printf("-----------------------------------------------------------\n");
   printf("  t        bottom-left  top-right");
   printf("    | nst  k      h\n");
   printf("-----------------------------------------------------------\n\n");
-  
+
 }
 
-/* 
+/*
  * PrintOutput: Print output values at output time t = tt.
  * Selected run statistics are printed.  Then values of the concentrations
- * are printed for the bottom left and top right grid points only.  
+ * are printed for the bottom left and top right grid points only.
  */
 
 static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
 {
-  int i, kused, flag;
+  int i, kused, retval;
   long int nst;
   realtype *c_bl, *c_tr, hused;
 
-  flag = IDAGetLastOrder(ida_mem, &kused);
-  check_flag(&flag, "IDAGetLastOrder", 1);
-  flag = IDAGetNumSteps(ida_mem, &nst);
-  check_flag(&flag, "IDAGetNumSteps", 1);
-  flag = IDAGetLastStep(ida_mem, &hused);
-  check_flag(&flag, "IDAGetLastStep", 1);
-  
+  retval = IDAGetLastOrder(ida_mem, &kused);
+  check_retval(&retval, "IDAGetLastOrder", 1);
+  retval = IDAGetNumSteps(ida_mem, &nst);
+  check_retval(&retval, "IDAGetNumSteps", 1);
+  retval = IDAGetLastStep(ida_mem, &hused);
+  check_retval(&retval, "IDAGetLastStep", 1);
+
   c_bl = IJ_Vptr(c,0,0);
   c_tr = IJ_Vptr(c,MX-1,MY-1);
 
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
-  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n", 
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n",
          t, c_bl[0], c_tr[0], nst, kused, hused);
   for (i=1;i<NUM_SPECIES;i++)
     printf("         %12.4Le %12.4Le   |\n",c_bl[i],c_tr[i]);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n",
          t, c_bl[0], c_tr[0], nst, kused, hused);
   for (i=1;i<NUM_SPECIES;i++)
     printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
 #else
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n",
          t, c_bl[0], c_tr[0], nst, kused, hused);
   for (i=1;i<NUM_SPECIES;i++)
     printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
@@ -672,29 +681,29 @@ static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
   printf("\n");
 }
 
-/* 
- * PrintFinalStats: Print final run data contained in iopt.              
+/*
+ * PrintFinalStats: Print final run data contained in iopt.
  */
 
 static void PrintFinalStats(void *ida_mem)
-{ 
+{
   long int nst, nre, sli, netf, nps, npevals, nrevalsLS;
-  int flag;
+  int retval;
 
-  flag = IDAGetNumSteps(ida_mem, &nst);
-  check_flag(&flag, "IDAGetNumSteps", 1);
-  flag = IDASpilsGetNumLinIters(ida_mem, &sli);
-  check_flag(&flag, "IDAGetNumNonlinSolvIters", 1);
-  flag = IDAGetNumResEvals(ida_mem, &nre);
-  check_flag(&flag, "IDAGetNumResEvals", 1);
-  flag = IDAGetNumErrTestFails(ida_mem, &netf);
-  check_flag(&flag, "IDAGetNumErrTestFails", 1);
-  flag = IDASpilsGetNumPrecSolves(ida_mem, &nps);
-  check_flag(&flag, "IDAGetNumNonlinSolvConvFails", 1);
-  flag = IDASpilsGetNumPrecEvals(ida_mem, &npevals);
-  check_flag(&flag, "IDADlsGetNumJacEvals", 1);
-  flag = IDASpilsGetNumResEvals(ida_mem, &nrevalsLS);
-  check_flag(&flag, "IDADlsGetNumResEvals", 1);
+  retval = IDAGetNumSteps(ida_mem, &nst);
+  check_retval(&retval, "IDAGetNumSteps", 1);
+  retval = IDAGetNumLinIters(ida_mem, &sli);
+  check_retval(&retval, "IDAGetNumLinIters", 1);
+  retval = IDAGetNumResEvals(ida_mem, &nre);
+  check_retval(&retval, "IDAGetNumResEvals", 1);
+  retval = IDAGetNumErrTestFails(ida_mem, &netf);
+  check_retval(&retval, "IDAGetNumErrTestFails", 1);
+  retval = IDAGetNumPrecSolves(ida_mem, &nps);
+  check_retval(&retval, "IDAGetNumPrecSolves", 1);
+  retval = IDAGetNumPrecEvals(ida_mem, &npevals);
+  check_retval(&retval, "IDAGetNumPrecEvals", 1);
+  retval = IDAGetNumLinResEvals(ida_mem, &nrevalsLS);
+  check_retval(&retval, "IDAGetNumLinResEvals", 1);
 
   printf("-----------------------------------------------------------\n");
   printf("Final run statistics: \n\n");
@@ -707,27 +716,27 @@ static void PrintFinalStats(void *ida_mem)
 
 }
 
-/* 
- * Fweb: Rate function for the food-web problem.                        
- * This routine computes the right-hand sides of the system equations,   
- * consisting of the diffusion term and interaction term.                
- * The interaction term is computed by the function WebRates.            
+/*
+ * Fweb: Rate function for the food-web problem.
+ * This routine computes the right-hand sides of the system equations,
+ * consisting of the diffusion term and interaction term.
+ * The interaction term is computed by the function WebRates.
  */
 
-static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,  
+static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,
                  UserData webdata)
-{ 
+{
   sunindextype jx, jy, is, idyu, idyl, idxu, idxl;
   realtype xx, yy, *cxy, *ratesxy, *cratexy, dcyli, dcyui, dcxli, dcxui;
-  
+
   /* Loop over grid points, evaluate interaction vector (length ns),
      form diffusion difference terms, and load crate.                    */
-  
+
   for (jy = 0; jy < MY; jy++) {
     yy = (webdata->dy) * jy ;
     idyu = (jy!=MY-1) ? NSMX : -NSMX;
     idyl = (jy!= 0  ) ? NSMX : -NSMX;
-    
+
     for (jx = 0; jx < MX; jx++) {
       xx = (webdata->dx) * jx;
       idxu = (jx!= MX-1) ?  NUM_SPECIES : -NUM_SPECIES;
@@ -735,33 +744,33 @@ static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,
       cxy = IJ_Vptr(cc,jx,jy);
       ratesxy = IJ_Vptr(webdata->rates,jx,jy);
       cratexy = IJ_Vptr(crate,jx,jy);
-      
+
       /* Get interaction vector at this grid point. */
       WebRates(xx, yy, cxy, ratesxy, webdata);
-      
+
       /* Loop over species, do differencing, load crate segment. */
 #pragma omp parallel for default(shared) private(is, dcyli, dcyui, dcxli, dcxui) schedule(static) num_threads(webdata->nthreads)
       for (is = 0; is < NUM_SPECIES; is++) {
-        
+
         /* Differencing in y. */
         dcyli = *(cxy+is) - *(cxy - idyl + is) ;
         dcyui = *(cxy + idyu + is) - *(cxy+is);
-        
+
         /* Differencing in x. */
         dcxli = *(cxy+is) - *(cxy - idxl + is);
         dcxui = *(cxy + idxu +is) - *(cxy+is);
-        
+
         /* Compute the crate values at (xx,yy). */
         cratexy[is] = coy[is] * (dcyui - dcyli) +
           cox[is] * (dcxui - dcxli) + ratesxy[is];
-        
+
       } /* End is loop */
     } /* End of jx loop */
   } /* End of jy loop */
-  
+
 }
 
-/* 
+/*
  * WebRates: Evaluate reaction rates at a given spatial point.
  * At a given (x,y), evaluate the array of ns reaction terms R.
  */
@@ -771,67 +780,67 @@ static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
 {
   int is;
   realtype fac;
-  
+
   for (is = 0; is < NUM_SPECIES; is++)
     ratesxy[is] = dotprod(NUM_SPECIES, cxy, acoef[is]);
-  
+
   fac = ONE + ALPHA*xx*yy + BETA*sin(FOURPI*xx)*sin(FOURPI*yy);
-  
-  for (is = 0; is < NUM_SPECIES; is++)  
+
+  for (is = 0; is < NUM_SPECIES; is++)
     ratesxy[is] = cxy[is]*( bcoef[is]*fac + ratesxy[is] );
-  
+
 }
 
 /*
- * dotprod: dot product routine for realtype arrays, for use by WebRates.    
+ * dotprod: dot product routine for realtype arrays, for use by WebRates.
  */
 
 static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
 {
   sunindextype i;
   realtype *xx1, *xx2, temp = ZERO;
-  
+
   xx1 = x1; xx2 = x2;
   for (i = 0; i < size; i++) temp += (*xx1++) * (*xx2++);
   return(temp);
-  
+
 }
 
 /*
  * Check function return value...
  *   opt == 0 means SUNDIALS function allocates memory so check if
  *            returned NULL pointer
- *   opt == 1 means SUNDIALS function returns a flag so check if
- *            flag >= 0
+ *   opt == 1 means SUNDIALS function returns an integer value so check if
+ *            retval < 0
  *   opt == 2 means function allocates memory so check if returned
- *            NULL pointer 
+ *            NULL pointer
  */
 
-static int check_flag(void *flagvalue, char *funcname, int opt)
+static int check_retval(void *returnvalue, char *funcname, int opt)
 {
-  int *errflag;
+  int *retval;
 
-  if (opt == 0 && flagvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL) {
     /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-    fprintf(stderr, 
-            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n", 
+    fprintf(stderr,
+            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
     return(1);
   } else if (opt == 1) {
-    /* Check if flag < 0 */
-    errflag = (int *) flagvalue;
-    if (*errflag < 0) {
-      fprintf(stderr, 
-              "\nSUNDIALS_ERROR: %s() failed with flag = %d\n\n", 
-              funcname, *errflag);
-      return(1); 
+    /* Check if retval < 0 */
+    retval = (int *) returnvalue;
+    if (*retval < 0) {
+      fprintf(stderr,
+              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
+              funcname, *retval);
+      return(1);
     }
-  } else if (opt == 2 && flagvalue == NULL) {
+  } else if (opt == 2 && returnvalue == NULL) {
     /* Check if function returned NULL pointer - no memory allocated */
-    fprintf(stderr, 
-            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n", 
+    fprintf(stderr,
+            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1); 
+    return(1);
   }
 
   return(0);
