@@ -2,19 +2,15 @@ C     ----------------------------------------------------------------
 C     Programmer(s): Daniel R. Reynolds @ SMU
 C                 Steve Smith, Eddy Banks and Alan C. Hindmarsh @ LLNL      
 C     ----------------------------------------------------------------
-C     LLNS/SMU Copyright Start
-C     Copyright (c) 2017, Southern Methodist University and 
-C     Lawrence Livermore National Security
-C
-C     This work was performed under the auspices of the U.S. Department 
-C     of Energy by Southern Methodist University and Lawrence Livermore 
-C     National Laboratory under Contract DE-AC52-07NA27344.
-C     Produced at Southern Methodist University and the Lawrence 
-C     Livermore National Laboratory.
-C
+C     SUNDIALS Copyright Start
+C     Copyright (c) 2002-2019, Lawrence Livermore National Security
+C     and Southern Methodist University.
 C     All rights reserved.
-C     For details, see the LICENSE file.
-C     LLNS/SMU Copyright End
+C
+C     See the top-level LICENSE and NOTICE files for details.
+C
+C     SPDX-License-Identifier: BSD-3-Clause
+C     SUNDIALS Copyright End
 c     ----------------------------------------------------------------
 c     This simple example problem for FIDA, due to Robertson, is from 
 c     chemical kinetics, and consists of the following three equations:
@@ -117,10 +113,10 @@ c
          call fidafree
          stop
       endif
-      call fidadlsinit(ier)
+      call fidalsinit(ier)
       if (ier .ne. 0) then
          write(6,35) ier
- 35      format(///' SUNDIALS_ERROR: FIDADLSINIT returned IER = ', i5)
+ 35      format(///' SUNDIALS_ERROR: FIDALSINIT returned IER = ', i5)
          call fidafree
          stop
       endif
