@@ -2,6 +2,16 @@
  * Programmer(s): Chris Nguyen @ LLNL
  *                based on idaHeat2D_bnd.c and idaRoberts_klu.c
  * -----------------------------------------------------------------
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
+ * All rights reserved.
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
+ * -----------------------------------------------------------------
  * Example problem for IDA: 2D heat equation, serial, sparse.
  *
  * This example solves a discretized 2D heat equation problem.
@@ -17,7 +27,7 @@
  * system of size N = MGRID^2. Here MGRID = 10.
  *
  * The system is solved with IDA using the sparse linear system
- * solver and a user supplied Jacobian. 
+ * solver and a user supplied Jacobian.
  * For purposes of illustration,
  * IDACalcIC is called to compute correct values at the boundary,
  * given incorrect values as input initial guesses. The constraints
@@ -34,7 +44,6 @@
 #include <nvector/nvector_serial.h>        /* access to serial N_Vector            */
 #include <sunmatrix/sunmatrix_sparse.h>    /* access to sparse SUNMatrix           */
 #include <sunlinsol/sunlinsol_klu.h>       /* access to KLU linear solver          */
-#include <ida/ida_direct.h>                /* access to IDADls interface           */
 #include <sundials/sundials_types.h>       /* defs. of realtype, sunindextype      */
 #include <sundials/sundials_math.h>        /* defs. of SUNRabs, SUNRexp, etc.      */
 
@@ -61,13 +70,13 @@ typedef struct {
 
 int heatres(realtype tres, N_Vector uu, N_Vector up, N_Vector resval, void *user_data);
 
-int jacHeat(realtype tt,  realtype cj, 
+int jacHeat(realtype tt,  realtype cj,
 	    N_Vector yy, N_Vector yp, N_Vector resvec,
 	    SUNMatrix JJ, void *user_data,
 	    N_Vector tempv1, N_Vector tempv2, N_Vector tempv3);
 
 /* Exact same setup as jacHeat. Function needed for special case MGRID=3  */
-int jacHeat3(realtype tt,  realtype cj, 
+int jacHeat3(realtype tt,  realtype cj,
              N_Vector yy, N_Vector yp, N_Vector resvec,
              SUNMatrix JJ, void *user_data,
              N_Vector tempv1, N_Vector tempv2, N_Vector tempv3);
@@ -76,10 +85,10 @@ int jacHeat3(realtype tt,  realtype cj,
 
 static void PrintHeader(realtype rtol, realtype atol);
 static void PrintOutput(void *mem, realtype t, N_Vector u);
-static int SetInitialProfile(UserData data, N_Vector uu, N_Vector up, 
+static int SetInitialProfile(UserData data, N_Vector uu, N_Vector up,
                              N_Vector id, N_Vector res);
 
-static int check_flag(void *flagvalue, const char *funcname, int opt);
+static int check_retval(void *returnvalue, const char *funcname, int opt);
 
 /*
  *--------------------------------------------------------------------
@@ -92,32 +101,34 @@ int main(void)
   void *mem;
   UserData data;
   N_Vector uu, up, constraints, id, res;
-  int ier, iout;
+  int retval, iout;
   long int netf, ncfn;
   realtype rtol, atol, t0, t1, tout, tret;
   SUNMatrix A;
   SUNLinearSolver LS;
   sunindextype nnz;
-  
+
   mem = NULL;
   data = NULL;
   uu = up = constraints = id = res = NULL;
+  A = NULL;
+  LS = NULL;
 
   /* Create vectors uu, up, res, constraints, id. */
   uu = N_VNew_Serial(NEQ);
-  if(check_flag((void *)uu, "N_VNew_Serial", 0)) return(1);
+  if(check_retval((void *)uu, "N_VNew_Serial", 0)) return(1);
   up = N_VNew_Serial(NEQ);
-  if(check_flag((void *)up, "N_VNew_Serial", 0)) return(1);
+  if(check_retval((void *)up, "N_VNew_Serial", 0)) return(1);
   res = N_VNew_Serial(NEQ);
-  if(check_flag((void *)res, "N_VNew_Serial", 0)) return(1);
+  if(check_retval((void *)res, "N_VNew_Serial", 0)) return(1);
   constraints = N_VNew_Serial(NEQ);
-  if(check_flag((void *)constraints, "N_VNew_Serial", 0)) return(1);
+  if(check_retval((void *)constraints, "N_VNew_Serial", 0)) return(1);
   id = N_VNew_Serial(NEQ);
-  if(check_flag((void *)id, "N_VNew_Serial", 0)) return(1);
+  if(check_retval((void *)id, "N_VNew_Serial", 0)) return(1);
 
   /* Create and load problem data block. */
   data = (UserData) malloc(sizeof *data);
-  if(check_flag((void *)data, "malloc", 2)) return(1);
+  if(check_retval((void *)data, "malloc", 2)) return(1);
   data->mm = MGRID;
   data->dx = ONE/(MGRID - ONE);
   data->coeff = ONE/( (data->dx) * (data->dx) );
@@ -136,77 +147,77 @@ int main(void)
 
   /* Call IDACreate and IDAMalloc to initialize solution */
   mem = IDACreate();
-  if(check_flag((void *)mem, "IDACreate", 0)) return(1);
+  if(check_retval((void *)mem, "IDACreate", 0)) return(1);
 
-  ier = IDASetUserData(mem, data);
-  if(check_flag(&ier, "IDASetUserData", 1)) return(1);
+  retval = IDASetUserData(mem, data);
+  if(check_retval(&retval, "IDASetUserData", 1)) return(1);
 
   /* Set which components are algebraic or differential */
-  ier = IDASetId(mem, id);
-  if(check_flag(&ier, "IDASetId", 1)) return(1);
+  retval = IDASetId(mem, id);
+  if(check_retval(&retval, "IDASetId", 1)) return(1);
 
-  ier = IDASetConstraints(mem, constraints);
-  if(check_flag(&ier, "IDASetConstraints", 1)) return(1);
+  retval = IDASetConstraints(mem, constraints);
+  if(check_retval(&retval, "IDASetConstraints", 1)) return(1);
   N_VDestroy(constraints);
 
-  ier = IDAInit(mem, heatres, t0, uu, up);
-  if(check_flag(&ier, "IDAInit", 1)) return(1);
+  retval = IDAInit(mem, heatres, t0, uu, up);
+  if(check_retval(&retval, "IDAInit", 1)) return(1);
 
-  ier = IDASStolerances(mem, rtol, atol);
-  if(check_flag(&ier, "IDASStolerances", 1)) return(1);
+  retval = IDASStolerances(mem, rtol, atol);
+  if(check_retval(&retval, "IDASStolerances", 1)) return(1);
 
   /* Create sparse SUNMatrix for use in linear solves */
   nnz = NEQ*NEQ;
   A = SUNSparseMatrix(NEQ, NEQ, nnz, CSC_MAT);
-  if(check_flag((void*)A, "SUNSparseMtarix", 0)) return(1);
+  if(check_retval((void*)A, "SUNSparseMtarix", 0)) return(1);
 
   /* Create KLU SUNLinearSolver object */
-  LS = SUNKLU(uu, A);
-  if(check_flag((void *)LS, "SUNKLU", 0)) return(1);
+  LS = SUNLinSol_KLU(uu, A);
+  if(check_retval((void *)LS, "SUNLinSol_KLU", 0)) return(1);
 
   /* Attach the matrix and linear solver */
-  ier = IDADlsSetLinearSolver(mem, LS, A);
-  if(check_flag(&ier, "IDADlsSetLinearSolver", 1)) return(1);
+  retval = IDASetLinearSolver(mem, LS, A);
+  if(check_retval(&retval, "IDASetLinearSolver", 1)) return(1);
 
   /* Set the user-supplied Jacobian routine */
   if(MGRID >= 4){
-    ier = IDADlsSetJacFn(mem, jacHeat);
+    retval = IDASetJacFn(mem, jacHeat);
   } else if(MGRID == 3) {
-    ier = IDADlsSetJacFn(mem, jacHeat3);
+    retval = IDASetJacFn(mem, jacHeat3);
   } else {
     /* MGRID<=2 is pure boundary points, nothing to solve */
     printf("MGRID size is too small to run.\n");
     return(1);
   }
-  if(check_flag(&ier, "IDADlsSetJacFn", 1)) return(1);
+  if(check_retval(&retval, "IDASetJacFn", 1)) return(1);
 
   /* Call IDACalcIC to correct the initial values. */
 
-  ier = IDACalcIC(mem, IDA_YA_YDP_INIT, t1);
-  if(check_flag(&ier, "IDACalcIC", 1)) return(1);
+  retval = IDACalcIC(mem, IDA_YA_YDP_INIT, t1);
+  if(check_retval(&retval, "IDACalcIC", 1)) return(1);
 
   /* Print output heading. */
   PrintHeader(rtol, atol);
-  
+
   PrintOutput(mem, t0, uu);
 
 
   /* Loop over output times, call IDASolve, and print results. */
-  
+
   for (tout = t1, iout = 1; iout <= NOUT; iout++, tout *= TWO) {
-    
-    ier = IDASolve(mem, tout, &tret, uu, up, IDA_NORMAL);
-    if(check_flag(&ier, "IDASolve", 1)) return(1);
+
+    retval = IDASolve(mem, tout, &tret, uu, up, IDA_NORMAL);
+    if(check_retval(&retval, "IDASolve", 1)) return(1);
 
     PrintOutput(mem, tret, uu);
-  
+
   }
-  
+
   /* Print remaining counters and free memory. */
-  ier = IDAGetNumErrTestFails(mem, &netf);
-  check_flag(&ier, "IDAGetNumErrTestFails", 1);
-  ier = IDAGetNumNonlinSolvConvFails(mem, &ncfn);
-  check_flag(&ier, "IDAGetNumNonlinSolvConvFails", 1);
+  retval = IDAGetNumErrTestFails(mem, &netf);
+  check_retval(&retval, "IDAGetNumErrTestFails", 1);
+  retval = IDAGetNumNonlinSolvConvFails(mem, &ncfn);
+  check_retval(&retval, "IDAGetNumNonlinSolvConvFails", 1);
   printf("\n netf = %ld,   ncfn = %ld \n", netf, ncfn);
 
   IDAFree(&mem);
@@ -228,53 +239,53 @@ int main(void)
  */
 
 /*
- * heatres: heat equation system residual function                       
- * This uses 5-point central differencing on the interior points, and    
- * includes algebraic equations for the boundary values.                 
- * So for each interior point, the residual component has the form       
- *    res_i = u'_i - (central difference)_i                              
- * while for each boundary point, it is res_i = u_i.                     
+ * heatres: heat equation system residual function
+ * This uses 5-point central differencing on the interior points, and
+ * includes algebraic equations for the boundary values.
+ * So for each interior point, the residual component has the form
+ *    res_i = u'_i - (central difference)_i
+ * while for each boundary point, it is res_i = u_i.
  */
 
-int heatres(realtype tres, N_Vector uu, N_Vector up, N_Vector resval, 
+int heatres(realtype tres, N_Vector uu, N_Vector up, N_Vector resval,
             void *user_data)
 {
   sunindextype mm, i, j, offset, loc;
   realtype *uv, *upv, *resv, coeff;
   UserData data;
-  
+
   uv = N_VGetArrayPointer(uu); upv = N_VGetArrayPointer(up); resv = N_VGetArrayPointer(resval);
 
   data = (UserData)user_data;
   mm = data->mm;
   coeff = data->coeff;
-  
+
   /* Initialize resval to uu, to take care of boundary equations. */
   N_VScale(ZERO, uu, resval);
-  
+
   /* Loop over interior points; set res = up - (central difference). */
   for (j = 1; j < mm-1; j++) {
     offset = mm*j;
     for (i = 1; i < mm-1; i++) {
       loc = offset + i;
-      resv[loc] = upv[loc] - coeff * 
+      resv[loc] = upv[loc] - coeff *
 	  (uv[loc-1] + uv[loc+1] + uv[loc-mm] + uv[loc+mm] - RCONST(4.0)*uv[loc]);
     }
   }
-  
+
   return(0);
 
 }
 
 /* Jacobian matrix setup for MGRID=3  */
-int jacHeat3(realtype tt,  realtype cj, 
+int jacHeat3(realtype tt,  realtype cj,
              N_Vector yy, N_Vector yp, N_Vector resvec,
              SUNMatrix JJ, void *user_data,
              N_Vector tempv1, N_Vector tempv2, N_Vector tempv3)
 {
   realtype dx =  ONE/(MGRID - ONE);
   realtype beta = RCONST(4.0)/(dx*dx) + cj;
-  
+
   sunindextype *colptrs = SUNSparseMatrix_IndexPointers(JJ);
   sunindextype *rowvals = SUNSparseMatrix_IndexValues(JJ);
   realtype *data = SUNSparseMatrix_Data(JJ);
@@ -282,7 +293,7 @@ int jacHeat3(realtype tt,  realtype cj,
   SUNMatZero(JJ);
 
   /*
-   * set up number of elements in each column 
+   * set up number of elements in each column
    */
   colptrs[0]  = 0;
   colptrs[1]  = 1;
@@ -294,23 +305,23 @@ int jacHeat3(realtype tt,  realtype cj,
   colptrs[7]  = 10;
   colptrs[8]  = 12;
   colptrs[9]  = 13;
-  
+
   /*
-   * set up data and row values stored 
+   * set up data and row values stored
    */
 
   data[0] = ONE;
-  rowvals[0] = 0;  
+  rowvals[0] = 0;
   data[1] = ONE;
   rowvals[1] = 1;
   data[2] = -ONE/(dx*dx);
-  rowvals[2] = 4;  
+  rowvals[2] = 4;
   data[3] = ONE;
   rowvals[3] = 2;
   data[4] = ONE;
   rowvals[4] = 3;
   data[5] = -ONE/(dx*dx);
-  rowvals[5] = 4;  
+  rowvals[5] = 4;
   data[6] = beta;
   rowvals[6] = 4;
   data[7] = -ONE/(dx*dx);
@@ -318,7 +329,7 @@ int jacHeat3(realtype tt,  realtype cj,
   data[8] = ONE;
   rowvals[8] = 5;
   data[9] = ONE;
-  rowvals[9] = 6; 
+  rowvals[9] = 6;
   data[10] = -ONE/(dx*dx);
   rowvals[10] = 4;
   data[11] = ONE;
@@ -330,12 +341,11 @@ int jacHeat3(realtype tt,  realtype cj,
 }
 
 /* Jacobian matrix setup for MGRID>=4  */
-int jacHeat(realtype tt,  realtype cj, 
+int jacHeat(realtype tt,  realtype cj,
             N_Vector yy, N_Vector yp, N_Vector resvec,
             SUNMatrix JJ, void *user_data,
             N_Vector tempv1, N_Vector tempv2, N_Vector tempv3)
 {
-  realtype *yval;
   realtype dx =  ONE/(MGRID - ONE);
   realtype beta = RCONST(4.0)/(dx*dx) + cj;
   int i,j, repeat=0;
@@ -344,16 +354,14 @@ int jacHeat(realtype tt,  realtype cj,
   sunindextype *rowvals = SUNSparseMatrix_IndexValues(JJ);
   realtype *data = SUNSparseMatrix_Data(JJ);
 
-  yval = N_VGetArrayPointer(yy);
-
   SUNMatZero(JJ);
 
-  /* 
+  /*
    *-----------------------------------------------
-   * set up number of elements in each column 
+   * set up number of elements in each column
    *-----------------------------------------------
    */
-  
+
   /**** first column block ****/
   colptrs[0] = 0;
   colptrs[1] = 1;
@@ -368,27 +376,27 @@ int jacHeat(realtype tt,  realtype cj,
   for(i=0;i<MGRID-4;i++) colptrs[MGRID+3+i] = (colptrs[MGRID+3+i-1])+4;
   colptrs[2*MGRID-1] = 2*MGRID+4*(MGRID-2)-2;
   colptrs[2*MGRID] = 2*MGRID+4*(MGRID-2);
-  
+
   /**** repeated (MGRID-4 times) middle column blocks ****/
   for(i=0;i<MGRID-4;i++){
     colptrs[2*MGRID+1+repeat]   = (colptrs[2*MGRID+1+repeat-1])+2;
     colptrs[2*MGRID+1+repeat+1] = (colptrs[2*MGRID+1+repeat])+4;
-    
+
     /* count by fives in the middle */
-    for(j=0;j<MGRID-4;j++) colptrs[2*MGRID+1+repeat+2+j] = 
+    for(j=0;j<MGRID-4;j++) colptrs[2*MGRID+1+repeat+2+j] =
 			  (colptrs[2*MGRID+1+repeat+1+j])+5;
-   
+
     colptrs[2*MGRID+1+repeat+(MGRID-4)+2] = (colptrs[2*MGRID+1+repeat+(MGRID-4)+1])+4;
-    colptrs[2*MGRID+1+repeat+(MGRID-4)+3] = (colptrs[2*MGRID+1+repeat+(MGRID-4)+2])+2;  
+    colptrs[2*MGRID+1+repeat+(MGRID-4)+3] = (colptrs[2*MGRID+1+repeat+(MGRID-4)+2])+2;
 
     repeat+=MGRID; /* shift that accounts for accumulated number of columns */
   }
-  
+
   /**** last-1 column block ****/
   colptrs[MGRID*MGRID-2*MGRID+1] = TOTAL-2*MGRID-4*(MGRID-2)+2;
   colptrs[MGRID*MGRID-2*MGRID+2] = TOTAL-2*MGRID-4*(MGRID-2)+5;
   /* count by fours in the middle */
-  for(i=0;i<MGRID-4;i++) colptrs[MGRID*MGRID-2*MGRID+3+i] = 
+  for(i=0;i<MGRID-4;i++) colptrs[MGRID*MGRID-2*MGRID+3+i] =
 			(colptrs[MGRID*MGRID-2*MGRID+3+i-1])+4;
   colptrs[MGRID*MGRID-MGRID-1] = TOTAL-2*MGRID;
   colptrs[MGRID*MGRID-MGRID]   = TOTAL-2*MGRID+2;
@@ -396,11 +404,11 @@ int jacHeat(realtype tt,  realtype cj,
   /**** last column block ****/
   colptrs[MGRID*MGRID-MGRID+1] = TOTAL-MGRID-(MGRID-2)+1;
   /* count by twos in the middle */
-  for(i=0;i<MGRID-2;i++) colptrs[MGRID*MGRID-MGRID+2+i] = 
+  for(i=0;i<MGRID-2;i++) colptrs[MGRID*MGRID-MGRID+2+i] =
 			(colptrs[MGRID*MGRID-MGRID+2+i-1])+2;
   colptrs[MGRID*MGRID-1] = TOTAL-1;
   colptrs[MGRID*MGRID]   = TOTAL;
-  
+
 
   /*
    *-----------------------------------------------
@@ -430,13 +438,13 @@ int jacHeat(realtype tt,  realtype cj,
   data[2*MGRID+4*(MGRID-2)-3] = -ONE/(dx*dx);
   data[2*MGRID+4*(MGRID-2)-2] = -ONE/(dx*dx);
   data[2*MGRID+4*(MGRID-2)-1] = ONE;
-    
+
   /**** repeated (MGRID-4 times) middle column blocks ****/
   repeat=0;
   for(i=0;i<MGRID-4;i++){
     data[2*MGRID+4*(MGRID-2)+repeat]   = ONE;
     data[2*MGRID+4*(MGRID-2)+repeat+1] = -ONE/(dx*dx);
-    
+
     data[2*MGRID+4*(MGRID-2)+repeat+2] = -ONE/(dx*dx);
     data[2*MGRID+4*(MGRID-2)+repeat+3] = beta;
     data[2*MGRID+4*(MGRID-2)+repeat+4] = -ONE/(dx*dx);
@@ -451,18 +459,18 @@ int jacHeat(realtype tt,  realtype cj,
       data[2*MGRID+4*(MGRID-2)+repeat+9+5*j]  = -ONE/(dx*dx);
       data[2*MGRID+4*(MGRID-2)+repeat+10+5*j] = -ONE/(dx*dx);
     }
-    
+
     data[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+6] = -ONE/(dx*dx);
     data[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+7] = -ONE/(dx*dx);
     data[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+8] = beta;
     data[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+9] = -ONE/(dx*dx);
-    
+
     data[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+10] = -ONE/(dx*dx);
     data[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+11] = ONE;
-    
+
     repeat+=MGRID+4*(MGRID-2); /* shift that accounts for accumulated columns and elements */
   }
-  
+
   /**** last-1 column block ****/
   data[TOTAL-6*(MGRID-2)-4] = ONE;
   data[TOTAL-6*(MGRID-2)-3] = -ONE/(dx*dx);
@@ -486,10 +494,10 @@ int jacHeat(realtype tt,  realtype cj,
   for(i=TOTAL-2*(MGRID-2)-1;i<TOTAL-2;i+=2) data[i] = -ONE/(dx*dx);
   for(i=TOTAL-2*(MGRID-2)  ;i<TOTAL-1;i+=2) data[i] = ONE;
   data[TOTAL-1] = ONE;
-  
+
   /*
    *-----------------------------------------------
-   * row values 
+   * row values
    *-----------------------------------------------
    */
 
@@ -498,7 +506,7 @@ int jacHeat(realtype tt,  realtype cj,
   /* alternating pattern in data, separate loop for each pattern */
   for(i=1;i<MGRID+(MGRID-2)  ;i+=2) rowvals[i] = (i+1)/2;
   for(i=2;i<MGRID+(MGRID-2)-1;i+=2) rowvals[i] = i/2+MGRID; /* i+1 unnecessary here */
-  
+
   /**** second column block ****/
   rowvals[MGRID+MGRID-2] = MGRID;
   rowvals[MGRID+MGRID-1] = MGRID+1;
@@ -515,18 +523,18 @@ int jacHeat(realtype tt,  realtype cj,
   rowvals[2*MGRID+4*(MGRID-2)-3] = 2*MGRID+(MGRID-2);
   rowvals[2*MGRID+4*(MGRID-2)-2] = MGRID+(MGRID-2);
   rowvals[2*MGRID+4*(MGRID-2)-1] = MGRID+(MGRID-2)+1;
-  
+
   /**** repeated (MGRID-4 times) middle column blocks ****/
   repeat=0;
   for(i=0;i<MGRID-4;i++){
     rowvals[2*MGRID+4*(MGRID-2)+repeat]   = MGRID+(MGRID-2)+2+MGRID*i;
     rowvals[2*MGRID+4*(MGRID-2)+repeat+1] = MGRID+(MGRID-2)+2+MGRID*i+1;
-    
+
     rowvals[2*MGRID+4*(MGRID-2)+repeat+2] = MGRID+(MGRID-2)+2+MGRID*i+1-MGRID;
     rowvals[2*MGRID+4*(MGRID-2)+repeat+3] = MGRID+(MGRID-2)+2+MGRID*i+1;
     rowvals[2*MGRID+4*(MGRID-2)+repeat+4] = MGRID+(MGRID-2)+2+MGRID*i+2; /* *this */
     rowvals[2*MGRID+4*(MGRID-2)+repeat+5] = MGRID+(MGRID-2)+2+MGRID*i+1+MGRID;
-    
+
     /* 5 in 5*j chosen since there are 5 elements in each column */
     /* column repeats MGRID-4 times within the outer loop */
     for(j=0;j<MGRID-4;j++){
@@ -536,7 +544,7 @@ int jacHeat(realtype tt,  realtype cj,
       rowvals[2*MGRID+4*(MGRID-2)+repeat+9+5*j]  = MGRID+(MGRID-2)+2+MGRID*i+2+1+j;
       rowvals[2*MGRID+4*(MGRID-2)+repeat+10+5*j] = MGRID+(MGRID-2)+2+MGRID*i+1+MGRID+1+j;
     }
-    
+
     rowvals[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+6] = MGRID+(MGRID-2)+2+MGRID*i-2;
     rowvals[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+7] = MGRID+(MGRID-2)+2+MGRID*i-2+MGRID-1;
     rowvals[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+8] = MGRID+(MGRID-2)+2+MGRID*i-2+MGRID; /* *this+MGRID */
@@ -544,11 +552,11 @@ int jacHeat(realtype tt,  realtype cj,
 
     rowvals[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+10] = MGRID+(MGRID-2)+2+MGRID*i-2+MGRID;
     rowvals[2*MGRID+4*(MGRID-2)+repeat+(MGRID-4)*5+11] = MGRID+(MGRID-2)+2+MGRID*i-2+MGRID+1;
-    
-    repeat+=MGRID+4*(MGRID-2); /* shift that accounts for accumulated columns and elements */
-  }  
 
-  
+    repeat+=MGRID+4*(MGRID-2); /* shift that accounts for accumulated columns and elements */
+  }
+
+
   /**** last-1 column block ****/
   rowvals[TOTAL-6*(MGRID-2)-4] = MGRID*MGRID-1-2*(MGRID-1)-1;
   rowvals[TOTAL-6*(MGRID-2)-3] = MGRID*MGRID-1-2*(MGRID-1); /* starting with this as base */
@@ -570,7 +578,7 @@ int jacHeat(realtype tt,  realtype cj,
   rowvals[TOTAL-2*(MGRID-2)-2] = MGRID*MGRID-MGRID;
   /* alternating pattern in data, separate loop for each pattern  */
   for(i=0;i<(MGRID-2);i++) rowvals[TOTAL-2*(MGRID-2)-1+2*i] = MGRID*MGRID-2*MGRID+1+i;
-  for(i=0;i<(MGRID-2);i++) rowvals[TOTAL-2*(MGRID-2)  +2*i] = MGRID*MGRID-MGRID+1+i;  
+  for(i=0;i<(MGRID-2);i++) rowvals[TOTAL-2*(MGRID-2)  +2*i] = MGRID*MGRID-MGRID+1+i;
   rowvals[TOTAL-1] = MGRID*MGRID-1;
 
   return(0);
@@ -584,18 +592,18 @@ int jacHeat(realtype tt,  realtype cj,
  */
 
 /*
- * SetInitialProfile: routine to initialize u, up, and id vectors.       
+ * SetInitialProfile: routine to initialize u, up, and id vectors.
  */
 
-static int SetInitialProfile(UserData data, N_Vector uu, N_Vector up, 
+static int SetInitialProfile(UserData data, N_Vector uu, N_Vector up,
                              N_Vector id, N_Vector res)
 {
   realtype xfact, yfact, *udata, *updata, *iddata;
   sunindextype mm, mm1, i, j, offset, loc;
-  
+
   mm = data->mm;
   mm1 = mm - 1;
-  
+
   udata = N_VGetArrayPointer(uu);
   updata = N_VGetArrayPointer(up);
   iddata = N_VGetArrayPointer(id);
@@ -603,7 +611,7 @@ static int SetInitialProfile(UserData data, N_Vector uu, N_Vector up,
   /* Initialize id to 1's. */
   N_VConst(ONE, id);
 
-  /* Initialize uu on all grid points. */ 
+  /* Initialize uu on all grid points. */
   for (j = 0; j < mm; j++) {
     yfact = data->dx * j;
     offset = mm*j;
@@ -613,13 +621,13 @@ static int SetInitialProfile(UserData data, N_Vector uu, N_Vector up,
       udata[loc] = RCONST(16.0) * xfact * (ONE - xfact) * yfact * (ONE - yfact);
     }
   }
-  
+
   /* Initialize up vector to 0. */
   N_VConst(ZERO, up);
 
   /* heatres sets res to negative of ODE RHS values at interior points. */
   heatres(ZERO, uu, up, res, data);
-  
+
   /* Copy -res into up to get correct interior initial up values. */
   N_VScale(-ONE, res, up);
 
@@ -632,12 +640,12 @@ static int SetInitialProfile(UserData data, N_Vector uu, N_Vector up,
         udata[loc] = BVAL; updata[loc] = ZERO; iddata[loc] = ZERO; }
     }
   }
-  
+
   return(0);
 
 }
 
-/* 
+/*
  * Print first lines of output (problem description)
  */
 
@@ -649,9 +657,9 @@ static void PrintHeader(realtype rtol, realtype atol)
   printf(" polynomial initial conditions.\n");
   printf("          Mesh dimensions: %d x %d", MGRID, MGRID);
   printf("        Total system size: %d\n\n", NEQ);
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
+#if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
@@ -678,30 +686,30 @@ static void PrintHeader(realtype rtol, realtype atol)
 
 static void PrintOutput(void *mem, realtype t, N_Vector uu)
 {
-  int ier;
+  int retval;
   realtype umax, hused;
   long int nst, nni, nje, nre;
   int kused;
 
   umax = N_VMaxNorm(uu);
-  
-  ier = IDAGetLastOrder(mem, &kused);
-  check_flag(&ier, "IDAGetLastOrder", 1);
-  ier = IDAGetNumSteps(mem, &nst);
-  check_flag(&ier, "IDAGetNumSteps", 1);
-  ier = IDAGetNumNonlinSolvIters(mem, &nni);
-  check_flag(&ier, "IDAGetNumNonlinSolvIters", 1);
-  ier = IDAGetNumResEvals(mem, &nre);
-  check_flag(&ier, "IDAGetNumResEvals", 1);
-  ier = IDAGetLastStep(mem, &hused);
-  check_flag(&ier, "IDAGetLastStep", 1);
-  ier = IDADlsGetNumJacEvals(mem, &nje);
-  check_flag(&ier, "IDADlsGetNumJacEvals", 1);
 
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
+  retval = IDAGetLastOrder(mem, &kused);
+  check_retval(&retval, "IDAGetLastOrder", 1);
+  retval = IDAGetNumSteps(mem, &nst);
+  check_retval(&retval, "IDAGetNumSteps", 1);
+  retval = IDAGetNumNonlinSolvIters(mem, &nni);
+  check_retval(&retval, "IDAGetNumNonlinSolvIters", 1);
+  retval = IDAGetNumResEvals(mem, &nre);
+  check_retval(&retval, "IDAGetNumResEvals", 1);
+  retval = IDAGetLastStep(mem, &hused);
+  check_retval(&retval, "IDAGetLastStep", 1);
+  retval = IDAGetNumJacEvals(mem, &nje);
+  check_retval(&retval, "IDAGetNumJacEvals", 1);
+
+#if defined(SUNDIALS_EXTENDED_PRECISION)
   printf(" %5.2Lf %13.5Le  %d  %3ld  %3ld  %3ld  %4ld  %9.2Le \n",
          t, umax, kused, nst, nni, nje, nre, hused);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
   printf(" %5.2f %13.5e  %d  %3ld  %3ld  %3ld  %4ld  %9.2e \n",
          t, umax, kused, nst, nni, nje, nre, hused);
 #else
@@ -711,39 +719,39 @@ static void PrintOutput(void *mem, realtype t, N_Vector uu)
 
 }
 
-/* 
+/*
  * Check function return value...
  *   opt == 0 means SUNDIALS function allocates memory so check if
  *            returned NULL pointer
- *   opt == 1 means SUNDIALS function returns a flag so check if
- *            flag >= 0
+ *   opt == 1 means SUNDIALS function returns an integer value so check if
+ *            retval < 0
  *   opt == 2 means function allocates memory so check if returned
- *            NULL pointer 
+ *            NULL pointer
  */
 
-static int check_flag(void *flagvalue, const char *funcname, int opt)
+static int check_retval(void *returnvalue, const char *funcname, int opt)
 {
-  int *errflag;
+  int *retval;
 
   /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-  if (opt == 0 && flagvalue == NULL) {
-    fprintf(stderr, 
-            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n", 
+  if (opt == 0 && returnvalue == NULL) {
+    fprintf(stderr,
+            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
     return(1);
   } else if (opt == 1) {
-    /* Check if flag < 0 */
-    errflag = (int *) flagvalue;
-    if (*errflag < 0) {
-      fprintf(stderr, 
-              "\nSUNDIALS_ERROR: %s() failed with flag = %d\n\n", 
-              funcname, *errflag);
-      return(1); 
+    /* Check if retval < 0 */
+    retval = (int *) returnvalue;
+    if (*retval < 0) {
+      fprintf(stderr,
+              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
+              funcname, *retval);
+      return(1);
     }
-  } else if (opt == 2 && flagvalue == NULL) {
+  } else if (opt == 2 && returnvalue == NULL) {
     /* Check if function returned NULL pointer - no memory allocated */
-    fprintf(stderr, 
-            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n", 
+    fprintf(stderr,
+            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
     return(1);
   }
