@@ -2,10 +2,20 @@
  * -----------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds and Ting Yan @ SMU
  * -----------------------------------------------------------------
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
+ * All rights reserved.
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
+ * -----------------------------------------------------------------
  * Example program for IDAS: Food web problem, OpenMP, GMRES, 
  * user-supplied preconditioner
  *
- * This example program uses SUNSPGMR as the linear 
+ * This example program uses SUNLinSol_SPGMR as the linear 
  * solver, and IDACalcIC for initial condition calculation.
  *
  * The mathematical problem solved in this example is a DAE system
@@ -59,7 +69,7 @@
  * The PDEs are discretized by central differencing on a MX by MY
  * mesh.
  *
- * The DAE system is solved by IDAS using the SUNSPGMR linear solver.
+ * The DAE system is solved by IDAS using the SUNLinSol_SPGMR linear solver.
  * Output is printed at t = 0, .001, .01, .1, .4, .7, 1.
  *
  * Optionally, we can set the number of threads from environment 
@@ -100,7 +110,6 @@
 #include <math.h>
 
 #include <idas/idas.h>
-#include <idas/idas_spils.h>
 #include <sunlinsol/sunlinsol_spgmr.h>
 #include <nvector/nvector_openmp.h>
 #include <sundials/sundials_dense.h>
@@ -189,7 +198,7 @@ static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate, UserData webdata);
 static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy, 
                      UserData webdata);
 static realtype dotprod(sunindextype size, realtype *x1, realtype *x2);
-static int check_flag(void *flagvalue, char *funcname, int opt);
+static int check_retval(void *returnvalue, char *funcname, int opt);
 
 /*
  *--------------------------------------------------------------------
@@ -203,7 +212,7 @@ int main(int argc, char *argv[])
   SUNLinearSolver LS;
   UserData webdata;
   N_Vector cc, cp, id;
-  int iout, jx, jy, flag;
+  int iout, jx, jy, retval;
   sunindextype maxl;
   realtype rtol, atol, t0, tout, tret;
   int num_threads;
@@ -240,13 +249,13 @@ int main(int argc, char *argv[])
   /* Allocate N-vectors and initialize cc, cp, and id. */
 
   cc  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_flag((void *)cc, "N_VNew_OpenMP", 0)) return(1);
+  if(check_retval((void *)cc, "N_VNew_OpenMP", 0)) return(1);
 
   cp  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_flag((void *)cp, "N_VNew_OpenMP", 0)) return(1);
+  if(check_retval((void *)cp, "N_VNew_OpenMP", 0)) return(1);
 
   id  = N_VNew_OpenMP(NEQ, num_threads);
-  if(check_flag((void *)id, "N_VNew_OpenMP", 0)) return(1);
+  if(check_retval((void *)id, "N_VNew_OpenMP", 0)) return(1);
   
   SetInitialProfiles(cc, cp, id, webdata);
   
@@ -259,40 +268,40 @@ int main(int argc, char *argv[])
   /* Call IDACreate and IDAMalloc to initialize IDA. */
   
   ida_mem = IDACreate();
-  if(check_flag((void *)ida_mem, "IDACreate", 0)) return(1);
+  if(check_retval((void *)ida_mem, "IDACreate", 0)) return(1);
 
-  flag = IDASetUserData(ida_mem, webdata);
-  if(check_flag(&flag, "IDASetUserData", 1)) return(1);
+  retval = IDASetUserData(ida_mem, webdata);
+  if(check_retval(&retval, "IDASetUserData", 1)) return(1);
 
-  flag = IDASetId(ida_mem, id);
-  if(check_flag(&flag, "IDASetId", 1)) return(1);
+  retval = IDASetId(ida_mem, id);
+  if(check_retval(&retval, "IDASetId", 1)) return(1);
 
-  flag = IDAInit(ida_mem, resweb, t0, cc, cp);
-  if(check_flag(&flag, "IDAInit", 1)) return(1);
+  retval = IDAInit(ida_mem, resweb, t0, cc, cp);
+  if(check_retval(&retval, "IDAInit", 1)) return(1);
 
-  flag = IDASStolerances(ida_mem, rtol, atol);
-  if(check_flag(&flag, "IDASStolerances", 1)) return(1);
+  retval = IDASStolerances(ida_mem, rtol, atol);
+  if(check_retval(&retval, "IDASStolerances", 1)) return(1);
 
   webdata->ida_mem = ida_mem;
 
-  /* Create SUNSPGMR linear solver, attach to IDA, and set 
+  /* Create SUNLinSol_SPGMR linear solver, attach to IDA, and set 
      preconditioning routines. */
 
-  maxl = 16;                               /* max dimension of the Krylov subspace */
-  LS = SUNSPGMR(cc, PREC_LEFT, maxl);      /* IDA only allows left preconditioning */
-  if(check_flag((void *)LS, "SUNSPGMR", 0)) return(1);
+  maxl = 16;                                      /* max dimension of the Krylov subspace */
+  LS = SUNLinSol_SPGMR(cc, PREC_LEFT, maxl);      /* IDA only allows left preconditioning */
+  if(check_retval((void *)LS, "SUNLinSol_SPGMR", 0)) return(1);
 
-  flag = IDASpilsSetLinearSolver(ida_mem, LS);
-  if(check_flag(&flag, "IDASpilsSetLinearSolver", 1)) return(1);
+  retval = IDASetLinearSolver(ida_mem, LS, NULL);
+  if(check_retval(&retval, "IDASetLinearSolver", 1)) return(1);
 
-  flag = IDASpilsSetPreconditioner(ida_mem, Precond, PSolve);
-  if(check_flag(&flag, "IDASpilsSetPreconditioner", 1)) return(1);
+  retval = IDASetPreconditioner(ida_mem, Precond, PSolve);
+  if(check_retval(&retval, "IDASetPreconditioner", 1)) return(1);
 
   /* Call IDACalcIC (with default options) to correct the initial values. */
 
   tout = RCONST(0.001);
-  flag = IDACalcIC(ida_mem, IDA_YA_YDP_INIT, tout);
-  if(check_flag(&flag, "IDACalcIC", 1)) return(1);
+  retval = IDACalcIC(ida_mem, IDA_YA_YDP_INIT, tout);
+  if(check_retval(&retval, "IDACalcIC", 1)) return(1);
   
   /* Print heading, basic parameters, and initial values. */
 
@@ -303,8 +312,8 @@ int main(int argc, char *argv[])
   
   for (iout = 1; iout <= NOUT; iout++) {
     
-    flag = IDASolve(ida_mem, tout, &tret, cc, cp, IDA_NORMAL);
-    if(check_flag(&flag, "IDASolve", 1)) return(flag);
+    retval = IDASolve(ida_mem, tout, &tret, cc, cp, IDA_NORMAL);
+    if(check_retval(&retval, "IDASolve", 1)) return(retval);
     
     PrintOutput(ida_mem, cc, tret);
     
@@ -401,7 +410,7 @@ static int resweb(realtype tt, N_Vector cc, N_Vector cp,
 static int Precond(realtype tt, N_Vector cc, N_Vector cp,
                    N_Vector rr, realtype cj, void *user_data)
 {
-  int flag;
+  int retval;
   realtype uround, xx, yy, del_x, del_y;
   realtype **Pxy, *ratesxy, *Pxycol, *cxy, *cpxy, *ewtxy, cctmp;
   realtype inc, fac, sqru, perturb_rates[NUM_SPECIES];
@@ -420,10 +429,10 @@ static int Precond(realtype tt, N_Vector cc, N_Vector cp,
 
   ida_mem = webdata->ida_mem;
   ewt = webdata->ewt;
-  flag = IDAGetErrWeights(ida_mem, ewt);
-  if(check_flag(&flag, "IDAGetErrWeights", 1)) return(1);
-  flag = IDAGetCurrentStep(ida_mem, &hh);
-  if(check_flag(&flag, "IDAGetCurrentStep", 1)) return(1);
+  retval = IDAGetErrWeights(ida_mem, ewt);
+  if(check_retval(&retval, "IDAGetErrWeights", 1)) return(1);
+  retval = IDAGetCurrentStep(ida_mem, &hh);
+  if(check_retval(&retval, "IDAGetCurrentStep", 1)) return(1);
 
   for (jy = 0; jy < MY; jy++) {
     yy = jy * del_y;
@@ -621,7 +630,7 @@ static void PrintHeader(sunindextype maxl, realtype rtol, realtype atol)
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
-  printf("Linear solver: SUNSPGMR, maxl = %ld\n",(long int) maxl);
+  printf("Linear solver: SUNLinSol_SPGMR, maxl = %ld\n",(long int) maxl);
   printf("CalcIC called to correct initial predator concentrations.\n\n");
   printf("-----------------------------------------------------------\n");
   printf("  t        bottom-left  top-right");
@@ -638,16 +647,16 @@ static void PrintHeader(sunindextype maxl, realtype rtol, realtype atol)
 
 static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
 {
-  int i, kused, flag;
+  int i, kused, retval;
   long int nst;
   realtype *c_bl, *c_tr, hused;
 
-  flag = IDAGetLastOrder(ida_mem, &kused);
-  check_flag(&flag, "IDAGetLastOrder", 1);
-  flag = IDAGetNumSteps(ida_mem, &nst);
-  check_flag(&flag, "IDAGetNumSteps", 1);
-  flag = IDAGetLastStep(ida_mem, &hused);
-  check_flag(&flag, "IDAGetLastStep", 1);
+  retval = IDAGetLastOrder(ida_mem, &kused);
+  check_retval(&retval, "IDAGetLastOrder", 1);
+  retval = IDAGetNumSteps(ida_mem, &nst);
+  check_retval(&retval, "IDAGetNumSteps", 1);
+  retval = IDAGetLastStep(ida_mem, &hused);
+  check_retval(&retval, "IDAGetLastStep", 1);
   
   c_bl = IJ_Vptr(c,0,0);
   c_tr = IJ_Vptr(c,MX-1,MY-1);
@@ -679,22 +688,22 @@ static void PrintOutput(void *ida_mem, N_Vector c, realtype t)
 static void PrintFinalStats(void *ida_mem)
 { 
   long int nst, nre, sli, netf, nps, npevals, nrevalsLS;
-  int flag;
+  int retval;
 
-  flag = IDAGetNumSteps(ida_mem, &nst);
-  check_flag(&flag, "IDAGetNumSteps", 1);
-  flag = IDASpilsGetNumLinIters(ida_mem, &sli);
-  check_flag(&flag, "IDAGetNumNonlinSolvIters", 1);
-  flag = IDAGetNumResEvals(ida_mem, &nre);
-  check_flag(&flag, "IDAGetNumResEvals", 1);
-  flag = IDAGetNumErrTestFails(ida_mem, &netf);
-  check_flag(&flag, "IDAGetNumErrTestFails", 1);
-  flag = IDASpilsGetNumPrecSolves(ida_mem, &nps);
-  check_flag(&flag, "IDAGetNumNonlinSolvConvFails", 1);
-  flag = IDASpilsGetNumPrecEvals(ida_mem, &npevals);
-  check_flag(&flag, "IDADlsGetNumJacEvals", 1);
-  flag = IDASpilsGetNumResEvals(ida_mem, &nrevalsLS);
-  check_flag(&flag, "IDADlsGetNumResEvals", 1);
+  retval = IDAGetNumSteps(ida_mem, &nst);
+  check_retval(&retval, "IDAGetNumSteps", 1);
+  retval = IDAGetNumLinIters(ida_mem, &sli);
+  check_retval(&retval, "IDAGetNumLinIters", 1);
+  retval = IDAGetNumResEvals(ida_mem, &nre);
+  check_retval(&retval, "IDAGetNumResEvals", 1);
+  retval = IDAGetNumErrTestFails(ida_mem, &netf);
+  check_retval(&retval, "IDAGetNumErrTestFails", 1);
+  retval = IDAGetNumPrecSolves(ida_mem, &nps);
+  check_retval(&retval, "IDAGetNumPrecSolves", 1);
+  retval = IDAGetNumPrecEvals(ida_mem, &npevals);
+  check_retval(&retval, "IDAGetNumPrecEvals", 1);
+  retval = IDAGetNumLinResEvals(ida_mem, &nrevalsLS);
+  check_retval(&retval, "IDAGetNumLinResEvals", 1);
 
   printf("-----------------------------------------------------------\n");
   printf("Final run statistics: \n\n");
@@ -801,32 +810,32 @@ static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
  * Check function return value...
  *   opt == 0 means SUNDIALS function allocates memory so check if
  *            returned NULL pointer
- *   opt == 1 means SUNDIALS function returns a flag so check if
- *            flag >= 0
+ *   opt == 1 means SUNDIALS function returns an integer value so check if
+ *            retval < 0
  *   opt == 2 means function allocates memory so check if returned
  *            NULL pointer 
  */
 
-static int check_flag(void *flagvalue, char *funcname, int opt)
+static int check_retval(void *returnvalue, char *funcname, int opt)
 {
-  int *errflag;
+  int *retval;
 
-  if (opt == 0 && flagvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL) {
     /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
     fprintf(stderr, 
             "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n", 
             funcname);
     return(1);
   } else if (opt == 1) {
-    /* Check if flag < 0 */
-    errflag = (int *) flagvalue;
-    if (*errflag < 0) {
+    /* Check if retval < 0 */
+    retval = (int *) returnvalue;
+    if (*retval < 0) {
       fprintf(stderr, 
-              "\nSUNDIALS_ERROR: %s() failed with flag = %d\n\n", 
-              funcname, *errflag);
+              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n", 
+              funcname, *retval);
       return(1); 
     }
-  } else if (opt == 2 && flagvalue == NULL) {
+  } else if (opt == 2 && returnvalue == NULL) {
     /* Check if function returned NULL pointer - no memory allocated */
     fprintf(stderr, 
             "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n", 
