@@ -2,13 +2,23 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *                Cosmin Petra and Radu Serban @ LLNL
  * -----------------------------------------------------------------
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
+ * All rights reserved.
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
+ * -----------------------------------------------------------------
  * Example program for IDA: Brusselator, parallel, GMRES, IDABBD
  * preconditioner, FSA.
  *
- * This example program for IDAS uses SUNSPGMR as the linear solver.
+ * This example program for IDAS uses SUNLinSol_SPGMR as the linear solver.
  * It is written for a parallel computer system and uses the
  * IDABBDPRE band-block-diagonal preconditioner module for the
- * IDASPILS interface.
+ * IDALS interface.
  *
  * The mathematical problem solved in this example is a DAE system
  * that arises from a system of partial differential equations after
@@ -50,7 +60,6 @@
 #include <math.h>
 
 #include <idas/idas.h>
-#include <idas/idas_spils.h>
 #include <sunlinsol/sunlinsol_spgmr.h>
 #include <idas/idas_bbdpre.h>
 #include <nvector/nvector_parallel.h>
@@ -164,7 +173,7 @@ static void PrintSol(void* mem, N_Vector uv, N_Vector uvp, UserData data,
 
 static void PrintFinalStats(void *mem);
 
-static int check_flag(void *flagvalue, const char *funcname, int opt, int id);
+static int check_retval(void *returnvalue, const char *funcname, int opt, int id);
 
 /*
  *--------------------------------------------------------------------
@@ -220,24 +229,24 @@ int main(int argc, char *argv[])
      The vector resid is used temporarily only.        */
   
   uv  = N_VNew_Parallel(comm, local_N, SystemSize);
-  if(check_flag((void *)uv, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
+  if(check_retval((void *)uv, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
 
   uvp  = N_VNew_Parallel(comm, local_N, SystemSize);
-  if(check_flag((void *)uvp, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
+  if(check_retval((void *)uvp, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
 
   resid = N_VNew_Parallel(comm, local_N, SystemSize);
-  if(check_flag((void *)resid, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
+  if(check_retval((void *)resid, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
 
   id  = N_VNew_Parallel(comm, local_N, SystemSize);
-  if(check_flag((void *)id, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
+  if(check_retval((void *)id, "N_VNew_Parallel", 0, thispe)) MPI_Abort(comm, 1);
 
   uvS = N_VCloneVectorArray_Parallel(NS, uv);
-  if (check_flag((void *)uvS, "N_VCloneVectorArray_Parallel", 0, thispe)) 
+  if (check_retval((void *)uvS, "N_VCloneVectorArray_Parallel", 0, thispe)) 
     MPI_Abort(comm, 1);
   for (is=0;is<NS;is++) N_VConst(ZERO, uvS[is]);
     
   uvpS = N_VCloneVectorArray_Parallel(NS, uv);
-  if (check_flag((void *)uvpS, "N_VCloneVectorArray_Parallel", 0, thispe))  
+  if (check_retval((void *)uvpS, "N_VCloneVectorArray_Parallel", 0, thispe))  
     MPI_Abort(comm, 1);
   for (is=0;is<NS;is++) N_VConst(ZERO, uvpS[is]);
 
@@ -250,43 +259,43 @@ int main(int argc, char *argv[])
   
   /* Call IDACreate and IDAInit to initialize solution */
   ida_mem = IDACreate();
-  if(check_flag((void *)ida_mem, "IDACreate", 0, thispe)) MPI_Abort(comm, 1);
+  if(check_retval((void *)ida_mem, "IDACreate", 0, thispe)) MPI_Abort(comm, 1);
 
   retval = IDASetUserData(ida_mem, data);
-  if(check_flag(&retval, "IDASetUserData", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDASetUserData", 1, thispe)) MPI_Abort(comm, 1);
 
   retval = IDASetId(ida_mem, id);
-  if(check_flag(&retval, "IDASetId", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDASetId", 1, thispe)) MPI_Abort(comm, 1);
 
   retval = IDAInit(ida_mem, res, t0, uv, uvp);
-  if(check_flag(&retval, "IDAInit", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDAInit", 1, thispe)) MPI_Abort(comm, 1);
   
   retval = IDASStolerances(ida_mem, rtol, atol);
-  if(check_flag(&retval, "IDASStolerances", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDASStolerances", 1, thispe)) MPI_Abort(comm, 1);
 
 
   /* Enable forward sensitivity analysis. */
   retval = IDASensInit(ida_mem, NS, IDA_SIMULTANEOUS, NULL, uvS, uvpS);
-  if(check_flag(&retval, "IDASensInit", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDASensInit", 1, thispe)) MPI_Abort(comm, 1);
 
   retval = IDASensEEtolerances(ida_mem);
-  if(check_flag(&retval, "IDASensEEtolerances", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDASensEEtolerances", 1, thispe)) MPI_Abort(comm, 1);
 
   retval = IDASetSensErrCon(ida_mem, SUNTRUE);
-  if (check_flag(&retval, "IDASetSensErrCon", 1, thispe)) MPI_Abort(comm, 1);
+  if (check_retval(&retval, "IDASetSensErrCon", 1, thispe)) MPI_Abort(comm, 1);
 
   pbar[0] = data->eps[0];
   pbar[1] = data->eps[1];
   retval = IDASetSensParams(ida_mem, data->eps, pbar, NULL);
-  if (check_flag(&retval, "IDASetSensParams", 1, thispe)) MPI_Abort(comm, 1);
+  if (check_retval(&retval, "IDASetSensParams", 1, thispe)) MPI_Abort(comm, 1);
 
-  /* Call SUNSPGMR and IDASpilsSetLinearSolver to specify the IDAS linear solver */
-  maxl = 16;                               /* max dimension of the Krylov subspace */
-  LS = SUNSPGMR(uv, PREC_LEFT, maxl);      /* IDA only allows left preconditioning */
-  if(check_flag((void *)LS, "SUNSPGMR", 0, thispe)) MPI_Abort(comm, 1);
+  /* Call SUNLinSol_SPGMR and IDASetLinearSolver to specify the IDAS linear solver */
+  maxl = 16;                                      /* max dimension of the Krylov subspace */
+  LS = SUNLinSol_SPGMR(uv, PREC_LEFT, maxl);      /* IDA only allows left preconditioning */
+  if(check_retval((void *)LS, "SUNLinSol_SPGMR", 0, thispe)) MPI_Abort(comm, 1);
 
-  retval = IDASpilsSetLinearSolver(ida_mem, LS);
-  if(check_flag(&retval, "IDASpilsSetLinearSolver", 1, thispe)) MPI_Abort(comm, 1);
+  retval = IDASetLinearSolver(ida_mem, LS, NULL);
+  if(check_retval(&retval, "IDASetLinearSolver", 1, thispe)) MPI_Abort(comm, 1);
 
   /* Call IDABBDPrecInit to initialize the band-block-diagonal preconditioner.
      The half-bandwidths for the difference quotient evaluation are exact
@@ -295,12 +304,12 @@ int main(int argc, char *argv[])
   mukeep = mlkeep = 2;
   retval = IDABBDPrecInit(ida_mem, local_N, mudq, mldq, mukeep, mlkeep, 
                           ZERO, reslocal, NULL);
-  if(check_flag(&retval, "IDABBDPrecInit", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDABBDPrecInit", 1, thispe)) MPI_Abort(comm, 1);
 
   /* Call IDACalcIC (with default options) to correct the initial values. */
   tout = RCONST(0.001);
   retval = IDACalcIC(ida_mem, IDA_YA_YDP_INIT, tout);
-  if(check_flag(&retval, "IDACalcIC", 1, thispe)) MPI_Abort(comm, 1);
+  if(check_retval(&retval, "IDACalcIC", 1, thispe)) MPI_Abort(comm, 1);
   
   /* On PE 0, print heading, basic parameters, initial values. */
   if (thispe == 0) PrintHeader(SystemSize, maxl, 
@@ -313,7 +322,7 @@ int main(int argc, char *argv[])
   for (iout = 1; iout <= NOUT; iout++) {
     
     retval = IDASolve(ida_mem, tout, &tret, uv, uvp, IDA_NORMAL);
-    if(check_flag(&retval, "IDASolve", 1, thispe)) MPI_Abort(comm, 1);
+    if(check_retval(&retval, "IDASolve", 1, thispe)) MPI_Abort(comm, 1);
 
     PrintOutput(ida_mem, uv, tret, data, comm);
 
@@ -526,7 +535,7 @@ static void PrintHeader(sunindextype SystemSize, int maxl,
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #endif
-  printf("Linear solver: SUNSPGMR     Max. Krylov dimension maxl: %d\n", maxl);
+  printf("Linear solver: SUNLinSol_SPGMR     Max. Krylov dimension maxl: %d\n", maxl);
   printf("Preconditioner: band-block-diagonal (IDABBDPRE), with parameters\n");
   printf("     mudq = %ld,  mldq = %ld,  mukeep = %ld,  mlkeep = %ld\n",
          (long int) mudq, (long int) mldq, (long int) mukeep, (long int) mlkeep);
@@ -550,7 +559,7 @@ static void PrintOutput(void *ida_mem, N_Vector uv, realtype tt,
   MPI_Status status;
   realtype *cdata, clast[2], hused;
   long int nst;
-  int i, kused, flag, thispe, npelast, ilast;;
+  int i, kused, retval, thispe, npelast, ilast;;
 
   thispe = data->thispe; 
   npelast = data->npes - 1;
@@ -571,12 +580,12 @@ static void PrintOutput(void *ida_mem, N_Vector uv, realtype tt,
     if (npelast != 0)
       MPI_Recv(&clast[0], 2, PVEC_REAL_MPI_TYPE, npelast, 0, comm, &status);
     
-    flag = IDAGetLastOrder(ida_mem, &kused);
-    check_flag(&flag, "IDAGetLastOrder", 1, thispe);
-    flag = IDAGetNumSteps(ida_mem, &nst);
-    check_flag(&flag, "IDAGetNumSteps", 1, thispe);
-    flag = IDAGetLastStep(ida_mem, &hused);
-    check_flag(&flag, "IDAGetLastStep", 1, thispe);
+    retval = IDAGetLastOrder(ida_mem, &kused);
+    check_retval(&retval, "IDAGetLastOrder", 1, thispe);
+    retval = IDAGetNumSteps(ida_mem, &nst);
+    check_retval(&retval, "IDAGetNumSteps", 1, thispe);
+    retval = IDAGetLastStep(ida_mem, &hused);
+    check_retval(&retval, "IDAGetLastStep", 1, thispe);
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
     printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n", 
@@ -646,32 +655,32 @@ static void PrintSol(void* ida_mem, N_Vector uv, N_Vector uvp,
 static void PrintFinalStats(void *ida_mem)
 {
   long int nst, nre, nreLS, netf, ncfn, nni, ncfl, nli, npe, nps, nge;
-  int flag;
+  int retval;
 
-  flag = IDAGetNumSteps(ida_mem, &nst);
-  check_flag(&flag, "IDAGetNumSteps", 1, 0);
-  flag = IDAGetNumResEvals(ida_mem, &nre);
-  check_flag(&flag, "IDAGetNumResEvals", 1, 0);
-  flag = IDAGetNumErrTestFails(ida_mem, &netf);
-  check_flag(&flag, "IDAGetNumErrTestFails", 1, 0);
-  flag = IDAGetNumNonlinSolvConvFails(ida_mem, &ncfn);
-  check_flag(&flag, "IDAGetNumNonlinSolvConvFails", 1, 0);
-  flag = IDAGetNumNonlinSolvIters(ida_mem, &nni);
-  check_flag(&flag, "IDAGetNumNonlinSolvIters", 1, 0);
+  retval = IDAGetNumSteps(ida_mem, &nst);
+  check_retval(&retval, "IDAGetNumSteps", 1, 0);
+  retval = IDAGetNumResEvals(ida_mem, &nre);
+  check_retval(&retval, "IDAGetNumResEvals", 1, 0);
+  retval = IDAGetNumErrTestFails(ida_mem, &netf);
+  check_retval(&retval, "IDAGetNumErrTestFails", 1, 0);
+  retval = IDAGetNumNonlinSolvConvFails(ida_mem, &ncfn);
+  check_retval(&retval, "IDAGetNumNonlinSolvConvFails", 1, 0);
+  retval = IDAGetNumNonlinSolvIters(ida_mem, &nni);
+  check_retval(&retval, "IDAGetNumNonlinSolvIters", 1, 0);
 
-  flag = IDASpilsGetNumConvFails(ida_mem, &ncfl);
-  check_flag(&flag, "IDASpilsGetNumConvFails", 1, 0);
-  flag = IDASpilsGetNumLinIters(ida_mem, &nli);
-  check_flag(&flag, "IDASpilsGetNumLinIters", 1, 0);
-  flag = IDASpilsGetNumPrecEvals(ida_mem, &npe);
-  check_flag(&flag, "IDASpilsGetNumPrecEvals", 1, 0);
-  flag = IDASpilsGetNumPrecSolves(ida_mem, &nps);
-  check_flag(&flag, "IDASpilsGetNumPrecSolves", 1, 0);
-  flag = IDASpilsGetNumResEvals(ida_mem, &nreLS);
-  check_flag(&flag, "IDASpilsGetNumResEvals", 1, 0);
+  retval = IDAGetNumLinConvFails(ida_mem, &ncfl);
+  check_retval(&retval, "IDAGetNumLinConvFails", 1, 0);
+  retval = IDAGetNumLinIters(ida_mem, &nli);
+  check_retval(&retval, "IDAGetNumLinIters", 1, 0);
+  retval = IDAGetNumPrecEvals(ida_mem, &npe);
+  check_retval(&retval, "IDAGetNumPrecEvals", 1, 0);
+  retval = IDAGetNumPrecSolves(ida_mem, &nps);
+  check_retval(&retval, "IDAGetNumPrecSolves", 1, 0);
+  retval = IDAGetNumLinResEvals(ida_mem, &nreLS);
+  check_retval(&retval, "IDAGetNumLinResEvals", 1, 0);
 
-  flag = IDABBDPrecGetNumGfnEvals(ida_mem, &nge);
-  check_flag(&flag, "IDABBDPrecGetNumGfnEvals", 1, 0);
+  retval = IDABBDPrecGetNumGfnEvals(ida_mem, &nge);
+  check_retval(&retval, "IDABBDPrecGetNumGfnEvals", 1, 0);
 
   printf("-----------------------------------------------------------\n");
   printf("\nFinal statistics: \n\n");
@@ -695,32 +704,32 @@ static void PrintFinalStats(void *ida_mem)
  * Check function return value...
  *   opt == 0 means SUNDIALS function allocates memory so check if
  *            returned NULL pointer
- *   opt == 1 means SUNDIALS function returns a flag so check if
- *            flag >= 0
+ *   opt == 1 means SUNDIALS function returns an integer value so check if
+ *            retval < 0
  *   opt == 2 means function allocates memory so check if returned
  *            NULL pointer 
  */
 
-static int check_flag(void *flagvalue, const char *funcname, int opt, int id)
+static int check_retval(void *returnvalue, const char *funcname, int opt, int id)
 {
-  int *errflag;
+  int *retval;
 
-  if (opt == 0 && flagvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL) {
     /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
     fprintf(stderr, 
             "\nSUNDIALS_ERROR(%d): %s() failed - returned NULL pointer\n\n", 
             id, funcname);
     return(1); 
   } else if (opt == 1) {
-    /* Check if flag < 0 */
-    errflag = (int *) flagvalue;
-    if (*errflag < 0) {
+    /* Check if retval < 0 */
+    retval = (int *) returnvalue;
+    if (*retval < 0) {
       fprintf(stderr, 
-              "\nSUNDIALS_ERROR(%d): %s() failed with flag = %d\n\n", 
-              id, funcname, *errflag);
+              "\nSUNDIALS_ERROR(%d): %s() failed with retval = %d\n\n", 
+              id, funcname, *retval);
       return(1); 
     }
-  } else if (opt == 2 && flagvalue == NULL) {
+  } else if (opt == 2 && returnvalue == NULL) {
     /* Check if function returned NULL pointer - no memory allocated */
     fprintf(stderr, 
             "\nMEMORY_ERROR(%d): %s() failed - returned NULL pointer\n\n", 
