@@ -46,7 +46,6 @@
 #include <kinsol/kinsol.h>              /* access to KINSOL func., consts. */
 #include <nvector/nvector_serial.h>     /* access to serial N_Vector       */
 #include <sunmatrix/sunmatrix_sparse.h> /* access to sparse SUNMatrix      */
-#include <kinsol/kinsol_direct.h>       /* access to KINDls interface      */
 #include <sunlinsol/sunlinsol_klu.h>    /* access to KLU SUNLinearSolver   */
 #include <sundials/sundials_types.h>    /* defs. of realtype, sunindextype */
 #include <sundials/sundials_math.h>     /* access to SUNRexp               */
@@ -170,16 +169,16 @@ int main()
   if(check_flag((void *)J, "SUNSparseMatrix", 0)) return(1);
 
   /* Create KLU solver object */
-  LS = SUNKLU(u, J);
-  if(check_flag((void *)LS, "SUNKLU", 0)) return(1);
+  LS = SUNLinSol_KLU(u, J);
+  if(check_flag((void *)LS, "SUNLinSol_KLU", 0)) return(1);
 
   /* Attach KLU linear solver */
-  flag = KINDlsSetLinearSolver(kmem, LS, J);
-  if(check_flag(&flag, "KINDlsSetLinearSolver", 1)) return(1);
+  flag = KINSetLinearSolver(kmem, LS, J);
+  if(check_flag(&flag, "KINSetLinearSolver", 1)) return(1);
 
   /* Set the Jacobian function */
-  flag = KINDlsSetJacFn(kmem, jac);
-  if (check_flag(&flag, "KINDlsSetJacFn", 1)) return(1);
+  flag = KINSetJacFn(kmem, jac);
+  if (check_flag(&flag, "KINSetJacFn", 1)) return(1);
 
   /* Print out the problem size, solution parameters, initial guess. */
   PrintHeader(fnormtol, scsteptol);
@@ -518,8 +517,8 @@ static void PrintFinalStats(void *kmem)
   check_flag(&flag, "KINGetNumNonlinSolvIters", 1);
   flag = KINGetNumFuncEvals(kmem, &nfe);
   check_flag(&flag, "KINGetNumFuncEvals", 1);
-  flag = KINDlsGetNumJacEvals(kmem, &nje);
-  check_flag(&flag, "KINDlsGetNumJacEvals", 1);
+  flag = KINGetNumJacEvals(kmem, &nje);
+  check_flag(&flag, "KINGetNumJacEvals", 1);
   
   printf("Final Statistics:\n");
   printf("  nni = %5ld    nfe  = %5ld \n", nni, nfe);
