@@ -1,23 +1,19 @@
 /*---------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2017, Southern Methodist University and 
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Southern Methodist University and Lawrence Livermore 
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence 
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  *---------------------------------------------------------------
  * This file contains implementations of routines for a
  * band-block-diagonal preconditioner, i.e. a block-diagonal
- * matrix with banded blocks, for use with ARKODE, the ARKSPILS 
+ * matrix with banded blocks, for use with ARKode, the ARKLS 
  * linear solver interface, and the MPI-parallel implementation 
  * of NVECTOR.
  *--------------------------------------------------------------*/
@@ -27,7 +23,7 @@
 
 #include "arkode_impl.h"
 #include "arkode_bbdpre_impl.h"
-#include "arkode_spils_impl.h"
+#include "arkode_ls_impl.h"
 #include <sundials/sundials_math.h>
 #include <nvector/nvector_serial.h>
 
@@ -39,20 +35,20 @@
 
 /* Prototypes of functions ARKBBDPrecSetup and ARKBBDPrecSolve */
 static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy, 
-			   booleantype jok, booleantype *jcurPtr, 
-			   realtype gamma, void *bbd_data);
+                           booleantype jok, booleantype *jcurPtr, 
+                           realtype gamma, void *bbd_data);
 static int ARKBBDPrecSolve(realtype t, N_Vector y, N_Vector fy, 
-			   N_Vector r, N_Vector z, 
-			   realtype gamma, realtype delta,
-			   int lr, void *bbd_data);
+                           N_Vector r, N_Vector z, 
+                           realtype gamma, realtype delta,
+                           int lr, void *bbd_data);
 
 /* Prototype for ARKBBDPrecFree */
 static int ARKBBDPrecFree(ARKodeMem ark_mem);
 
 /* Prototype for difference quotient Jacobian calculation routine */
 static int ARKBBDDQJac(ARKBBDPrecData pdata, realtype t, 
-		       N_Vector y, N_Vector gy, 
-		       N_Vector ytemp, N_Vector gtemp);
+                       N_Vector y, N_Vector gy, 
+                       N_Vector ytemp, N_Vector gtemp);
 
 
 /*---------------------------------------------------------------
@@ -64,42 +60,32 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
                    realtype dqrely, 
                    ARKLocalFn gloc, ARKCommFn cfn)
 {
-  ARKodeMem ark_mem;
-  ARKSpilsMem arkspils_mem;
+  ARKodeMem      ark_mem;
+  ARKLsMem       arkls_mem;
   ARKBBDPrecData pdata;
-  sunindextype muk, mlk, storage_mu, lrw1, liw1;
-  long int lrw, liw;
-  int flag;
+  sunindextype   muk, mlk, storage_mu, lrw1, liw1;
+  long int       lrw, liw;
+  int            retval;
 
-  if (arkode_mem == NULL) {
-    arkProcessError(NULL, ARKSPILS_MEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_NULL);
-    return(ARKSPILS_MEM_NULL);
-  }
-  ark_mem = (ARKodeMem) arkode_mem;
-
-  /* Test if the SPILS linear solver interface has been created */
-  if (ark_mem->ark_lmem == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_LMEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_LMEM_NULL);
-    return(ARKSPILS_LMEM_NULL);
-  }
-  arkspils_mem = (ARKSpilsMem) ark_mem->ark_lmem;
+  /* access ARKMilsMem structure */
+  retval = arkLs_AccessLMem(arkode_mem, "ARKBBDPrecInit",
+                            &ark_mem, &arkls_mem);
+  if (retval != ARK_SUCCESS)  return(retval);
 
   /* Test compatibility of NVECTOR package with the BBD preconditioner */
-  if(ark_mem->ark_tempv->ops->nvgetarraypointer == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_ILL_INPUT, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_BAD_NVECTOR);
-    return(ARKSPILS_ILL_INPUT);
+  if(ark_mem->tempv1->ops->nvgetarraypointer == NULL) {
+    arkProcessError(ark_mem, ARKLS_ILL_INPUT, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_BAD_NVECTOR);
+    return(ARKLS_ILL_INPUT);
   }
 
   /* Allocate data memory */
   pdata = NULL;
   pdata = (ARKBBDPrecData) malloc(sizeof *pdata);  
   if (pdata == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
 
   /* Set pointers to gloc and cfn; load half-bandwidths */
@@ -114,24 +100,24 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
   pdata->mlkeep = mlk;
 
   /* Allocate memory for saved Jacobian */
-  pdata->savedJ = SUNBandMatrix(Nlocal, muk, mlk, muk);
+  pdata->savedJ = SUNBandMatrixStorage(Nlocal, muk, mlk, muk);
   if (pdata->savedJ == NULL) { 
     free(pdata); pdata = NULL; 
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL); 
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL); 
   }
 
   /* Allocate memory for preconditioner matrix */
   storage_mu = SUNMIN(Nlocal-1, muk + mlk);
   pdata->savedP = NULL;
-  pdata->savedP = SUNBandMatrix(Nlocal, muk, mlk, storage_mu);
+  pdata->savedP = SUNBandMatrixStorage(Nlocal, muk, mlk, storage_mu);
   if (pdata->savedP == NULL) {
     SUNMatDestroy(pdata->savedJ);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
 
   /* Allocate memory for temporary N_Vectors */
@@ -141,9 +127,9 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
     SUNMatDestroy(pdata->savedP);
     SUNMatDestroy(pdata->savedJ);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
   pdata->rlocal = NULL;
   pdata->rlocal = N_VNewEmpty_Serial(Nlocal);
@@ -152,24 +138,24 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
     SUNMatDestroy(pdata->savedP);
     SUNMatDestroy(pdata->savedJ);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
   pdata->tmp1 = NULL;
-  pdata->tmp1 = N_VClone(ark_mem->ark_tempv);
+  pdata->tmp1 = N_VClone(ark_mem->tempv1);
   if (pdata->tmp1 == NULL) {
     N_VDestroy(pdata->zlocal);
     N_VDestroy(pdata->rlocal);
     SUNMatDestroy(pdata->savedP);
     SUNMatDestroy(pdata->savedJ);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
   pdata->tmp2 = NULL;
-  pdata->tmp2 = N_VClone(ark_mem->ark_tempv);
+  pdata->tmp2 = N_VClone(ark_mem->tempv1);
   if (pdata->tmp2 == NULL) {
     N_VDestroy(pdata->tmp1);
     N_VDestroy(pdata->zlocal);
@@ -177,12 +163,12 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
     SUNMatDestroy(pdata->savedP);
     SUNMatDestroy(pdata->savedJ);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
   pdata->tmp3 = NULL;
-  pdata->tmp3 = N_VClone(ark_mem->ark_tempv);
+  pdata->tmp3 = N_VClone(ark_mem->tempv1);
   if (pdata->tmp3 == NULL) {
     N_VDestroy(pdata->tmp1);
     N_VDestroy(pdata->tmp2);
@@ -191,14 +177,14 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
     SUNMatDestroy(pdata->savedP);
     SUNMatDestroy(pdata->savedJ);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
 
   /* Allocate memory for banded linear solver */
   pdata->LS = NULL;
-  pdata->LS = SUNBandLinearSolver(pdata->rlocal, pdata->savedP);
+  pdata->LS = SUNLinSol_Band(pdata->rlocal, pdata->savedP);
   if (pdata->LS == NULL) {
     N_VDestroy(pdata->tmp1);
     N_VDestroy(pdata->tmp2);
@@ -208,13 +194,13 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
     SUNMatDestroy(pdata->savedP);
     SUNMatDestroy(pdata->savedJ);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_MEM_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_MEM_FAIL);
-    return(ARKSPILS_MEM_FAIL);
+    arkProcessError(ark_mem, ARKLS_MEM_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_MEM_FAIL);
+    return(ARKLS_MEM_FAIL);
   }
 
   /* initialize band linear solver object */
-  flag = SUNLinSolInitialize(pdata->LS);
+  retval = SUNLinSolInitialize(pdata->LS);
   if (pdata->LS == NULL) {
     N_VDestroy(pdata->tmp1);
     N_VDestroy(pdata->tmp2);
@@ -225,14 +211,14 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
     SUNMatDestroy(pdata->savedJ);
     SUNLinSolFree(pdata->LS);
     free(pdata); pdata = NULL;
-    arkProcessError(ark_mem, ARKSPILS_SUNLS_FAIL, "ARKBBDPRE", 
-                    "ARKBBDPrecInit", MSGBBD_SUNLS_FAIL);
-    return(ARKSPILS_SUNLS_FAIL);
+    arkProcessError(ark_mem, ARKLS_SUNLS_FAIL, "ARKBBDPRE", 
+                    "ARKBBDPrecInit", MSG_BBD_SUNLS_FAIL);
+    return(ARKLS_SUNLS_FAIL);
   }
   
   /* Set dqrely based on input dqrely (0 implies default). */
   pdata->dqrely = (dqrely > ZERO) ? 
-    dqrely : SUNRsqrt(ark_mem->ark_uround);
+    dqrely : SUNRsqrt(ark_mem->uround);
 
   /* Store Nlocal to be used in ARKBBDPrecSetup */
   pdata->n_local = Nlocal;
@@ -240,8 +226,8 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
   /* Set work space sizes and initialize nge */
   pdata->rpwsize = 0;
   pdata->ipwsize = 0;
-  if (ark_mem->ark_tempv->ops->nvspace) {
-    N_VSpace(ark_mem->ark_tempv, &lrw1, &liw1);
+  if (ark_mem->tempv1->ops->nvspace) {
+    N_VSpace(ark_mem->tempv1, &lrw1, &liw1);
     pdata->rpwsize += 3*lrw1;
     pdata->ipwsize += 3*liw1;
   }
@@ -251,72 +237,63 @@ int ARKBBDPrecInit(void *arkode_mem, sunindextype Nlocal,
     pdata->ipwsize += 2*liw1;
   }
   if (pdata->savedJ->ops->space) {
-    flag = SUNMatSpace(pdata->savedJ, &lrw, &liw);
+    retval = SUNMatSpace(pdata->savedJ, &lrw, &liw);
     pdata->rpwsize += lrw;
     pdata->ipwsize += liw;
   }
   if (pdata->savedP->ops->space) {
-    flag = SUNMatSpace(pdata->savedP, &lrw, &liw);
+    retval = SUNMatSpace(pdata->savedP, &lrw, &liw);
     pdata->rpwsize += lrw;
     pdata->ipwsize += liw;
   }
   if (pdata->LS->ops->space) {
-    flag = SUNLinSolSpace(pdata->LS, &lrw, &liw);
+    retval = SUNLinSolSpace(pdata->LS, &lrw, &liw);
     pdata->rpwsize += lrw;
     pdata->ipwsize += liw;
   }
   pdata->nge = 0;
 
   /* make sure P_data is free from any previous allocations */
-  if (arkspils_mem->pfree) 
-    arkspils_mem->pfree(ark_mem);
+  if (arkls_mem->pfree) 
+    arkls_mem->pfree(ark_mem);
 
-  /* Point to the new P_data field in the SPILS memory */
-  arkspils_mem->P_data = pdata;
+  /* Point to the new P_data field in the LS memory */
+  arkls_mem->P_data = pdata;
 
   /* Attach the pfree function */
-  arkspils_mem->pfree = ARKBBDPrecFree;
+  arkls_mem->pfree = ARKBBDPrecFree;
 
   /* Attach preconditioner solve and setup functions */
-  flag = ARKSpilsSetPreconditioner(arkode_mem, 
-                                   ARKBBDPrecSetup, 
-				   ARKBBDPrecSolve);
+  retval = arkLSSetPreconditioner(arkode_mem, 
+                                  ARKBBDPrecSetup, 
+                                  ARKBBDPrecSolve);
 
-  return(flag);
+  return(retval);
 }
 
 
 /*-------------------------------------------------------------*/
 int ARKBBDPrecReInit(void *arkode_mem, sunindextype mudq, 
-		     sunindextype mldq, realtype dqrely)
+                     sunindextype mldq, realtype dqrely)
 {
-  ARKodeMem ark_mem;
-  ARKSpilsMem arkspils_mem;
+  ARKodeMem      ark_mem;
+  ARKLsMem       arkls_mem;
   ARKBBDPrecData pdata;
-  sunindextype Nlocal;
+  sunindextype   Nlocal;
+  int            retval;
+  
+  /* access ARKMilsMem structure */
+  retval = arkLs_AccessLMem(arkode_mem, "ARKBBDPrecReInit",
+                            &ark_mem, &arkls_mem);
+  if (retval != ARK_SUCCESS)  return(retval);
 
-  if (arkode_mem == NULL) {
-    arkProcessError(NULL, ARKSPILS_MEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecReInit", MSGBBD_MEM_NULL);
-    return(ARKSPILS_MEM_NULL);
-  }
-  ark_mem = (ARKodeMem) arkode_mem;
-
-  /* Test if the SPILS linear solver interface has been created */
-  if (ark_mem->ark_lmem == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_LMEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecReInit", MSGBBD_LMEM_NULL);
-    return(ARKSPILS_LMEM_NULL);
-  }
-  arkspils_mem = (ARKSpilsMem) ark_mem->ark_lmem;
-
-  /* Test if the preconditioner data is non-NULL */
-  if (arkspils_mem->P_data == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_PMEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecReInit", MSGBBD_PMEM_NULL);
-    return(ARKSPILS_PMEM_NULL);
+  /* Return immediately ARKBBDPrecData is NULL */
+  if (arkls_mem->P_data == NULL) {
+    arkProcessError(ark_mem, ARKLS_PMEM_NULL, "ARKBBDPRE", 
+                    "ARKBBDPrecReInit", MSG_BBD_PMEM_NULL);
+    return(ARKLS_PMEM_NULL);
   } 
-  pdata = (ARKBBDPrecData) arkspils_mem->P_data;
+  pdata = (ARKBBDPrecData) arkls_mem->P_data;
 
   /* Load half-bandwidths */
   Nlocal = pdata->n_local;
@@ -325,49 +302,43 @@ int ARKBBDPrecReInit(void *arkode_mem, sunindextype mudq,
 
   /* Set dqrely based on input dqrely (0 implies default). */
   pdata->dqrely = (dqrely > ZERO) ? 
-    dqrely : SUNRsqrt(ark_mem->ark_uround);
+    dqrely : SUNRsqrt(ark_mem->uround);
 
   /* Re-initialize nge */
   pdata->nge = 0;
 
-  return(ARKSPILS_SUCCESS);
+  return(ARKLS_SUCCESS);
 }
 
 
 /*-------------------------------------------------------------*/
 int ARKBBDPrecGetWorkSpace(void *arkode_mem, 
                            long int *lenrwBBDP, 
-			   long int *leniwBBDP)
+                           long int *leniwBBDP)
 {
-  ARKodeMem ark_mem;
-  ARKSpilsMem arkspils_mem;
+  ARKodeMem      ark_mem;
+  ARKLsMem       arkls_mem;
   ARKBBDPrecData pdata;
+  int            retval;
+  
+  /* access ARKMilsMem structure */
+  retval = arkLs_AccessLMem(arkode_mem, "ARKBBDPrecGetWorkSpace",
+                            &ark_mem, &arkls_mem);
+  if (retval != ARK_SUCCESS)  return(retval);
 
-  if (arkode_mem == NULL) {
-    arkProcessError(NULL, ARKSPILS_MEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecGetWorkSpace", MSGBBD_MEM_NULL);
-    return(ARKSPILS_MEM_NULL);
-  }
-  ark_mem = (ARKodeMem) arkode_mem;
-
-  if (ark_mem->ark_lmem == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_LMEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecGetWorkSpace", MSGBBD_LMEM_NULL);
-    return(ARKSPILS_LMEM_NULL);
-  }
-  arkspils_mem = (ARKSpilsMem) ark_mem->ark_lmem;
-
-  if (arkspils_mem->P_data == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_PMEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecGetWorkSpace", MSGBBD_PMEM_NULL);
-    return(ARKSPILS_PMEM_NULL);
+  /* Return immediately ARKBBDPrecData is NULL */
+  if (arkls_mem->P_data == NULL) {
+    arkProcessError(ark_mem, ARKLS_PMEM_NULL, "ARKBBDPRE", 
+                    "ARKBBDPrecGetWorkSpace", MSG_BBD_PMEM_NULL);
+    return(ARKLS_PMEM_NULL);
   } 
-  pdata = (ARKBBDPrecData) arkspils_mem->P_data;
+  pdata = (ARKBBDPrecData) arkls_mem->P_data;
 
+  /* set outputs */
   *lenrwBBDP = pdata->rpwsize;
   *leniwBBDP = pdata->ipwsize;
 
-  return(ARKSPILS_SUCCESS);
+  return(ARKLS_SUCCESS);
 }
 
 
@@ -375,34 +346,28 @@ int ARKBBDPrecGetWorkSpace(void *arkode_mem,
 int ARKBBDPrecGetNumGfnEvals(void *arkode_mem, 
                              long int *ngevalsBBDP)
 {
-  ARKodeMem ark_mem;
-  ARKSpilsMem arkspils_mem;
+  ARKodeMem      ark_mem;
+  ARKLsMem       arkls_mem;
   ARKBBDPrecData pdata;
+  int            retval;
+  
+  /* access ARKMilsMem structure */
+  retval = arkLs_AccessLMem(arkode_mem, "ARKBBDPrecGetNumGfnEvals",
+                            &ark_mem, &arkls_mem);
+  if (retval != ARK_SUCCESS)  return(retval);
 
-  if (arkode_mem == NULL) {
-    arkProcessError(NULL, ARKSPILS_MEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecGetNumGfnEvals", MSGBBD_MEM_NULL);
-    return(ARKSPILS_MEM_NULL);
-  }
-  ark_mem = (ARKodeMem) arkode_mem;
-
-  if (ark_mem->ark_lmem == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_LMEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecGetNumGfnEvals", MSGBBD_LMEM_NULL);
-    return(ARKSPILS_LMEM_NULL);
-  }
-  arkspils_mem = (ARKSpilsMem) ark_mem->ark_lmem;
-
-  if (arkspils_mem->P_data == NULL) {
-    arkProcessError(ark_mem, ARKSPILS_PMEM_NULL, "ARKBBDPRE", 
-                    "ARKBBDPrecGetNumGfnEvals", MSGBBD_PMEM_NULL);
-    return(ARKSPILS_PMEM_NULL);
+  /* Return immediately if ARKBBDPrecData is NULL */
+  if (arkls_mem->P_data == NULL) {
+    arkProcessError(ark_mem, ARKLS_PMEM_NULL, "ARKBBDPRE", 
+                    "ARKBBDPrecGetNumGfnEvals", MSG_BBD_PMEM_NULL);
+    return(ARKLS_PMEM_NULL);
   } 
-  pdata = (ARKBBDPrecData) arkspils_mem->P_data;
+  pdata = (ARKBBDPrecData) arkls_mem->P_data;
 
+  /* set output */
   *ngevalsBBDP = pdata->nge;
 
-  return(ARKSPILS_SUCCESS);
+  return(ARKLS_SUCCESS);
 }
 
 
@@ -453,8 +418,8 @@ int ARKBBDPrecGetNumGfnEvals(void *arkode_mem,
    1  for a recoverable error (step will be retried).
 ---------------------------------------------------------------*/
 static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy, 
-			   booleantype jok, booleantype *jcurPtr, 
-			   realtype gamma, void *bbd_data)
+                           booleantype jok, booleantype *jcurPtr, 
+                           realtype gamma, void *bbd_data)
 {
   sunindextype ier;
   ARKBBDPrecData pdata;
@@ -471,7 +436,7 @@ static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
     retval = SUNMatCopy(pdata->savedJ, pdata->savedP);
     if (retval < 0) {
       arkProcessError(ark_mem, -1, "ARKBBDPRE", 
-                      "ARKBBDPrecSetup", MSGBBD_SUNMAT_FAIL);
+                      "ARKBBDPrecSetup", MSG_BBD_SUNMAT_FAIL);
       return(-1);
     }
     if (retval > 0) {
@@ -485,7 +450,7 @@ static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
     retval = SUNMatZero(pdata->savedJ);
     if (retval < 0) {
       arkProcessError(ark_mem, -1, "ARKBBDPRE", 
-                      "ARKBBDPrecSetup", MSGBBD_SUNMAT_FAIL);
+                      "ARKBBDPrecSetup", MSG_BBD_SUNMAT_FAIL);
       return(-1);
     }
     if (retval > 0) {
@@ -496,7 +461,7 @@ static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
                          pdata->tmp2, pdata->tmp3);
     if (retval < 0) {
       arkProcessError(ark_mem, -1, "ARKBBDPRE", "ARKBBDPrecSetup", 
-                      MSGBBD_FUNC_FAILED);
+                      MSG_BBD_FUNC_FAILED);
       return(-1);
     }
     if (retval > 0) {
@@ -506,7 +471,7 @@ static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
     retval = SUNMatCopy(pdata->savedJ, pdata->savedP);
     if (retval < 0) {
       arkProcessError(ark_mem, -1, "ARKBBDPRE", 
-                      "ARKBBDPrecSetup", MSGBBD_SUNMAT_FAIL);
+                      "ARKBBDPrecSetup", MSG_BBD_SUNMAT_FAIL);
       return(-1);
     }
     if (retval > 0) {
@@ -519,7 +484,7 @@ static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
   retval = SUNMatScaleAddI(-gamma, pdata->savedP);
   if (retval) {
     arkProcessError(ark_mem, -1, "ARKBBDPRE", 
-                    "ARKBBDPrecSetup", MSGBBD_SUNMAT_FAIL);
+                    "ARKBBDPrecSetup", MSG_BBD_SUNMAT_FAIL);
     return(-1);
   }
  
@@ -549,9 +514,9 @@ static int ARKBBDPrecSetup(realtype t, N_Vector y, N_Vector fy,
  as the value returned from the linear solver object.
 ---------------------------------------------------------------*/
 static int ARKBBDPrecSolve(realtype t, N_Vector y, N_Vector fy, 
-			   N_Vector r, N_Vector z, 
-			   realtype gamma, realtype delta,
-			   int lr, void *bbd_data)
+                           N_Vector r, N_Vector z, 
+                           realtype gamma, realtype delta,
+                           int lr, void *bbd_data)
 {
   int retval;
   ARKBBDPrecData pdata;
@@ -577,14 +542,17 @@ static int ARKBBDPrecSolve(realtype t, N_Vector y, N_Vector fy,
 /*-------------------------------------------------------------*/
 static int ARKBBDPrecFree(ARKodeMem ark_mem)
 {
-  ARKSpilsMem arkspils_mem;
+  ARKLsMem       arkls_mem;
+  void*          ark_step_lmem;
   ARKBBDPrecData pdata;
   
-  if (ark_mem->ark_lmem == NULL) return(0);
-  arkspils_mem = (ARKSpilsMem) ark_mem->ark_lmem;
-  
-  if (arkspils_mem->P_data == NULL) return(0);
-  pdata = (ARKBBDPrecData) arkspils_mem->P_data;
+  /* Return immediately if ARKodeMem, ARKLsMem or ARKBandPrecData are NULL */
+  if (ark_mem == NULL) return(0);
+  ark_step_lmem = ark_mem->step_getlinmem((void*) ark_mem);
+  if (ark_step_lmem == NULL) return(0);
+  arkls_mem = (ARKLsMem) ark_step_lmem;
+  if (arkls_mem->P_data == NULL) return(0);
+  pdata = (ARKBBDPrecData) arkls_mem->P_data;
 
   SUNLinSolFree(pdata->LS);
   N_VDestroy(pdata->tmp1);
@@ -617,8 +585,8 @@ static int ARKBBDPrecFree(ARKodeMem ark_mem)
  stored contiguously.
 ---------------------------------------------------------------*/
 static int ARKBBDDQJac(ARKBBDPrecData pdata, realtype t, 
-		       N_Vector y, N_Vector gy, 
-		       N_Vector ytemp, N_Vector gtemp)
+                       N_Vector y, N_Vector gy, 
+                       N_Vector ytemp, N_Vector gtemp)
 {
   ARKodeMem ark_mem;
   realtype gnorm, minInc, inc, inc_inv;
@@ -633,27 +601,27 @@ static int ARKBBDDQJac(ARKBBDPrecData pdata, realtype t,
 
   /* Call cfn and gloc to get base value of g(t,y) */
   if (pdata->cfn != NULL) {
-    retval = pdata->cfn(pdata->n_local, t, y, ark_mem->ark_user_data);
+    retval = pdata->cfn(pdata->n_local, t, y, ark_mem->user_data);
     if (retval != 0) return(retval);
   }
 
   retval = pdata->gloc(pdata->n_local, t, ytemp, gy, 
-                       ark_mem->ark_user_data);
+                       ark_mem->user_data);
   pdata->nge++;
   if (retval != 0) return(retval);
 
   /* Obtain pointers to the data for various vectors */
   y_data     =  N_VGetArrayPointer(y);
   gy_data    =  N_VGetArrayPointer(gy);
-  ewt_data   =  N_VGetArrayPointer(ark_mem->ark_ewt);
+  ewt_data   =  N_VGetArrayPointer(ark_mem->ewt);
   ytemp_data =  N_VGetArrayPointer(ytemp);
   gtemp_data =  N_VGetArrayPointer(gtemp);
 
   /* Set minimum increment based on uround and norm of g */
-  gnorm = N_VWrmsNorm(gy, ark_mem->ark_rwt);
+  gnorm = N_VWrmsNorm(gy, ark_mem->rwt);
   minInc = (gnorm != ZERO) ? 
-    (MIN_INC_MULT * SUNRabs(ark_mem->ark_h) *
-     ark_mem->ark_uround * pdata->n_local * gnorm) : ONE;
+    (MIN_INC_MULT * SUNRabs(ark_mem->h) *
+     ark_mem->uround * pdata->n_local * gnorm) : ONE;
 
   /* Set bandwidth and number of column groups for band differencing */
   width = pdata->mldq + pdata->mudq + 1;
@@ -670,7 +638,7 @@ static int ARKBBDDQJac(ARKBBDPrecData pdata, realtype t,
 
     /* Evaluate g with incremented y */
     retval = pdata->gloc(pdata->n_local, t, ytemp, gtemp, 
-			 ark_mem->ark_user_data);
+                         ark_mem->user_data);
     pdata->nge++;
     if (retval != 0) return(retval);
 
