@@ -1,21 +1,17 @@
 /*---------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2017, Southern Methodist University and
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department
- * of Energy by Southern Methodist University and Lawrence Livermore
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  *---------------------------------------------------------------
- * Fortran/C interface routines for ARKODE/ARKDLS, for the case
+ * Fortran/C interface routines for ARKODE/ARKLS, for the case
  * of a user-supplied mass-matrix approximation routine.
  *--------------------------------------------------------------*/
 
@@ -23,7 +19,7 @@
 #include <stdlib.h>
 #include "farkode.h"
 #include "arkode_impl.h"
-#include <arkode/arkode_direct.h>
+#include <arkode/arkode_arkstep.h>
 #include <sunmatrix/sunmatrix_dense.h>
 
 /*=============================================================*/
@@ -35,9 +31,9 @@ extern "C" {
 #endif
 
   extern void FARK_DMASS(long int *N, realtype *T,
-			 realtype *DMASS, long int *IPAR,
-			 realtype *RPAR, realtype *V1,
-			 realtype *V2, realtype *V3, int *ier);
+                         realtype *DMASS, long int *IPAR,
+                         realtype *RPAR, realtype *V1,
+                         realtype *V2, realtype *V3, int *ier);
 
 #ifdef __cplusplus
 }
@@ -45,11 +41,11 @@ extern "C" {
 
 /*=============================================================*/
 
-/* Fortran interface routine to ARKDlsSetMassFn; see
+/* Fortran interface routine to ARKStepSetMassFn; see
    farkode.h for further details */
 void FARK_DENSESETMASS(int *ier)
 {
-  *ier = ARKDlsSetMassFn(ARK_arkodemem, FARKDenseMass);
+  *ier = ARKStepSetMassFn(ARK_arkodemem, FARKDenseMass);
 }
 
 /*=============================================================*/
@@ -57,7 +53,7 @@ void FARK_DENSESETMASS(int *ier)
 /* C interface to user-supplied Fortran routine FARKDMASS; see
    farkode.h for additional information  */
 int FARKDenseMass(realtype t, SUNMatrix M, void *user_data,
-		  N_Vector vtemp1, N_Vector vtemp2, N_Vector vtemp3)
+                  N_Vector vtemp1, N_Vector vtemp2, N_Vector vtemp3)
 {
   int ier;
   realtype *massdata, *v1data, *v2data, *v3data;
@@ -72,7 +68,7 @@ int FARKDenseMass(realtype t, SUNMatrix M, void *user_data,
   ARK_userdata = (FARKUserData) user_data;
 
   FARK_DMASS(&N, &t, massdata, ARK_userdata->ipar, ARK_userdata->rpar,
-	     v1data, v2data, v3data, &ier);
+             v1data, v2data, v3data, &ier);
   return(ier);
 }
 
