@@ -1,19 +1,15 @@
 /*---------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2017, Southern Methodist University and
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department
- * of Energy by Southern Methodist University and Lawrence Livermore
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  *---------------------------------------------------------------
  * This is the implementation file for the Fortran interface to
  * the ARKODE package.  See farkode.h for usage.
@@ -28,8 +24,8 @@
 #include "farkode.h"
 #include "arkode_impl.h"
 #include <sundials/sundials_matrix.h>
-#include <arkode/arkode_direct.h>
-#include <arkode/arkode_spils.h>
+#include <arkode/arkode_ls.h>
+#include <arkode/arkode_arkstep.h>
 
 /*=============================================================*/
 
@@ -58,9 +54,9 @@ extern "C" {
 #endif
 
   extern void FARK_IMP_FUN(realtype *T, realtype *Y, realtype *YDOT,
-			   long int *IPAR, realtype *RPAR, int *IER);
+                           long int *IPAR, realtype *RPAR, int *IER);
   extern void FARK_EXP_FUN(realtype *T, realtype *Y, realtype *YDOT,
-			   long int *IPAR, realtype *RPAR, int *IER);
+                           long int *IPAR, realtype *RPAR, int *IER);
 
 #ifdef __cplusplus
 }
@@ -68,15 +64,15 @@ extern "C" {
 
 /*=============================================================*/
 
-/* Fortran interface routine to initialize ARKode memory
+/* Fortran interface routine to initialize ARKStep memory
    structure; functions as an all-in-one interface to the C
-   routines ARKodeCreate, ARKodeSetUserData, ARKodeInit, and
-   ARKodeSStolerances (or ARKodeSVtolerances); see farkode.h
+   routines ARKStepCreate, ARKStepSetUserData, and
+   ARKStepSStolerances (or ARKStepSVtolerances); see farkode.h
    for further details */
 void FARK_MALLOC(realtype *t0, realtype *y0, int *imex,
-		 int *iatol, realtype *rtol, realtype *atol,
-		 long int *iout, realtype *rout,
-		 long int *ipar, realtype *rpar, int *ier) {
+                 int *iatol, realtype *rtol, realtype *atol,
+                 long int *iout, realtype *rout,
+                 long int *ipar, realtype *rpar, int *ier) {
 
   N_Vector Vatol;
   FARKUserData ARK_userdata;
@@ -107,11 +103,27 @@ void FARK_MALLOC(realtype *t0, realtype *y0, int *imex,
 
   /* initialize global constants to disable each option */
   ARK_nrtfn = 0;
-  ARK_ls = -1;
-  ARK_mass_ls = -1;
+  ARK_ls = SUNFALSE;
+  ARK_mass_ls = SUNFALSE;
 
-  /* Create ARKODE object */
-  ARK_arkodemem = ARKodeCreate();
+  /* Set data in F2C_ARKODE_vec to y0 */
+  N_VSetArrayPointer(y0, F2C_ARKODE_vec);
+
+  /* Call ARKStepCreate based on imex argument */
+  switch (*imex) {
+  case 0:  /* purely implicit */
+    ARK_arkodemem = ARKStepCreate(NULL, FARKfi, *t0, F2C_ARKODE_vec);
+    break;
+  case 1:  /* purely explicit */
+    ARK_arkodemem = ARKStepCreate(FARKfe, NULL, *t0, F2C_ARKODE_vec);
+    FARKNullMatrix();
+    FARKNullLinsol();
+    FARKNullNonlinsol();
+    break;
+  case 2:  /* imex */
+    ARK_arkodemem = ARKStepCreate(FARKfe, FARKfi, *t0, F2C_ARKODE_vec);
+    break;
+  }
   if (ARK_arkodemem == NULL) {
     *ier = -1;
     return;
@@ -126,45 +138,16 @@ void FARK_MALLOC(realtype *t0, realtype *y0, int *imex,
   }
   ARK_userdata->rpar = rpar;
   ARK_userdata->ipar = ipar;
-  *ier = ARKodeSetUserData(ARK_arkodemem, ARK_userdata);
+  *ier = ARKStepSetUserData(ARK_arkodemem, ARK_userdata);
   if(*ier != ARK_SUCCESS) {
     free(ARK_userdata); ARK_userdata = NULL;
     *ier = -1;
     return;
   }
 
-  /* Set data in F2C_ARKODE_vec to y0 */
-  N_VSetArrayPointer(y0, F2C_ARKODE_vec);
-
-  /* Call ARKodeInit based on imex argument */
-  switch (*imex) {
-  case 0:  /* purely implicit */
-    *ier = ARKodeInit(ARK_arkodemem, NULL, FARKfi,
-		      *t0, F2C_ARKODE_vec);
-    break;
-  case 1:  /* purely explicit */
-    *ier = ARKodeInit(ARK_arkodemem, FARKfe, NULL,
-		      *t0, F2C_ARKODE_vec);
-    FARKNullMatrix();
-    FARKNullLinsol();
-    break;
-  case 2:  /* imex */
-    *ier = ARKodeInit(ARK_arkodemem, FARKfe, FARKfi,
-		      *t0, F2C_ARKODE_vec);
-    break;
-  }
-
   /* Reset data pointers */
   N_VSetArrayPointer(NULL, F2C_ARKODE_vec);
 
-  /* On failure, exit */
-  if(*ier != ARK_SUCCESS) {
-    free(ARK_userdata);
-    ARK_userdata = NULL;
-    *ier = -1;
-    return;
-  }
-
   /* Set tolerances -- if <= 0, keep as defaults */
   reltol = RELTOL;
   abstol = ABSTOL;
@@ -172,7 +155,7 @@ void FARK_MALLOC(realtype *t0, realtype *y0, int *imex,
   switch (*iatol) {
   case 1:
     if (*atol > ZERO)  abstol = *atol;
-    *ier = ARKodeSStolerances(ARK_arkodemem, reltol, abstol);
+    *ier = ARKStepSStolerances(ARK_arkodemem, reltol, abstol);
     break;
   case 2:
     Vatol = N_VCloneEmpty(F2C_ARKODE_vec);
@@ -184,7 +167,7 @@ void FARK_MALLOC(realtype *t0, realtype *y0, int *imex,
     }
     N_VSetArrayPointer(atol, Vatol);
     if (N_VMin(Vatol) <= ZERO)  N_VConst(abstol, Vatol);
-    *ier = ARKodeSVtolerances(ARK_arkodemem, reltol, Vatol);
+    *ier = ARKStepSVtolerances(ARK_arkodemem, reltol, Vatol);
     N_VDestroy(Vatol);
     break;
   }
@@ -209,12 +192,12 @@ void FARK_MALLOC(realtype *t0, realtype *y0, int *imex,
 
 /*=============================================================*/
 
-/* Fortran interface routine to re-initialize ARKode memory
+/* Fortran interface routine to re-initialize ARKStep memory
    structure; functions as an all-in-one interface to the C
-   routines ARKodeReInit and ARKodeSStolerances (or
-   ARKodeSVtolerances); see farkode.h for further details */
+   routines ARKStepReInit and ARKStepSStolerances (or
+   ARKStepSVtolerances); see farkode.h for further details */
 void FARK_REINIT(realtype *t0, realtype *y0, int *imex, int *iatol,
-		 realtype *rtol, realtype *atol, int *ier) {
+                 realtype *rtol, realtype *atol, int *ier) {
 
   N_Vector Vatol;
   realtype reltol, abstol;
@@ -226,19 +209,19 @@ void FARK_REINIT(realtype *t0, realtype *y0, int *imex, int *iatol,
   /* Set data in F2C_ARKODE_vec to y0 */
   N_VSetArrayPointer(y0, F2C_ARKODE_vec);
 
-  /* Call ARKodeReInit based on imex argument */
+  /* Call ARKStepReInit based on imex argument */
   switch (*imex) {
   case 0:  /* purely implicit */
-    *ier = ARKodeReInit(ARK_arkodemem, NULL, FARKfi,
-			*t0, F2C_ARKODE_vec);
+    *ier = ARKStepReInit(ARK_arkodemem, NULL, FARKfi,
+                         *t0, F2C_ARKODE_vec);
     break;
   case 1:  /* purely explicit */
-    *ier = ARKodeReInit(ARK_arkodemem, FARKfe, NULL,
-			*t0, F2C_ARKODE_vec);
+    *ier = ARKStepReInit(ARK_arkodemem, FARKfe, NULL,
+                         *t0, F2C_ARKODE_vec);
     break;
   case 2:  /* imex */
-    *ier = ARKodeReInit(ARK_arkodemem, FARKfe, FARKfi,
-			*t0, F2C_ARKODE_vec);
+    *ier = ARKStepReInit(ARK_arkodemem, FARKfe, FARKfi,
+                         *t0, F2C_ARKODE_vec);
     break;
   }
 
@@ -258,7 +241,7 @@ void FARK_REINIT(realtype *t0, realtype *y0, int *imex, int *iatol,
   switch (*iatol) {
   case 1:
     if (*atol > ZERO)  abstol = *atol;
-    *ier = ARKodeSStolerances(ARK_arkodemem, reltol, abstol);
+    *ier = ARKStepSStolerances(ARK_arkodemem, reltol, abstol);
     break;
   case 2:
     Vatol = N_VCloneEmpty(F2C_ARKODE_vec);
@@ -268,7 +251,7 @@ void FARK_REINIT(realtype *t0, realtype *y0, int *imex, int *iatol,
     }
     N_VSetArrayPointer(atol, Vatol);
     if (N_VMin(Vatol) <= ZERO)  N_VConst(abstol, Vatol);
-    *ier = ARKodeSVtolerances(ARK_arkodemem, reltol, Vatol);
+    *ier = ARKStepSVtolerances(ARK_arkodemem, reltol, Vatol);
     N_VDestroy(Vatol);
     break;
   }
@@ -284,23 +267,23 @@ void FARK_REINIT(realtype *t0, realtype *y0, int *imex, int *iatol,
 
 /*=============================================================*/
 
-/* Fortran interface routine to re-initialize ARKode memory
+/* Fortran interface routine to re-initialize ARKStep memory
    structure for a problem with a new size but similar time
    scale; functions as an all-in-one interface to the C
-   routines ARKodeResize (and potentially ARKodeSVtolerances);
+   routines ARKStepResize (and potentially ARKStepSVtolerances);
    see farkode.h for further details */
 void FARK_RESIZE(realtype *t0, realtype *y0, realtype *hscale,
-		 int *itol, realtype *rtol, realtype *atol, int *ier) {
+                 int *itol, realtype *rtol, realtype *atol, int *ier) {
 
   *ier = 0;
 
   /* Set data in F2C_ARKODE_vec to y0 */
   N_VSetArrayPointer(y0, F2C_ARKODE_vec);
 
-  /* Call ARKodeResize (currently does not allow Fortran
+  /* Call ARKStepResize (currently does not allow Fortran
      user-supplied vector resize function) */
-  *ier = ARKodeResize(ARK_arkodemem, F2C_ARKODE_vec, *hscale,
-		      *t0, NULL, NULL);
+  *ier = ARKStepResize(ARK_arkodemem, F2C_ARKODE_vec, *hscale,
+                       *t0, NULL, NULL);
 
   /* Reset data pointer */
   N_VSetArrayPointer(NULL, F2C_ARKODE_vec);
@@ -320,7 +303,7 @@ void FARK_RESIZE(realtype *t0, realtype *y0, realtype *hscale,
       return;
     }
     N_VSetArrayPointer(atol, Vatol);
-    *ier = ARKodeSVtolerances(ARK_arkodemem, *rtol, Vatol);
+    *ier = ARKStepSVtolerances(ARK_arkodemem, *rtol, Vatol);
     N_VDestroy(Vatol);
   }
 
@@ -329,10 +312,10 @@ void FARK_RESIZE(realtype *t0, realtype *y0, realtype *hscale,
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeSetDefaults; see
+/* Fortran interface to C routine ARKStepSetDefaults; see
    farkode.h for further details */
 void FARK_SETDEFAULTS(int *ier) {
-  *ier = ARKodeSetDefaults(ARK_arkodemem);
+  *ier += ARKStepSetDefaults(ARK_arkodemem);
   return;
 }
 
@@ -342,45 +325,41 @@ void FARK_SETDEFAULTS(int *ier) {
    arguments; see farkode.h for further details */
 void FARK_SETIIN(char key_name[], long int *ival, int *ier) {
   if (!strncmp(key_name, "ORDER", 5))
-    *ier = ARKodeSetOrder(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetOrder(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "DENSE_ORDER", 11))
-    *ier = ARKodeSetDenseOrder(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetDenseOrder(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "LINEAR", 6))
-    *ier = ARKodeSetLinear(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetLinear(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "NONLINEAR", 9))
-    *ier = ARKodeSetNonlinear(ARK_arkodemem);
-  else if (!strncmp(key_name, "FIXEDPOINT", 10))
-    *ier = ARKodeSetFixedPoint(ARK_arkodemem, (long int) *ival);
-  else if (!strncmp(key_name, "NEWTON", 6))
-    *ier = ARKodeSetNewton(ARK_arkodemem);
+    *ier = ARKStepSetNonlinear(ARK_arkodemem);
   else if (!strncmp(key_name, "EXPLICIT", 8))
-    *ier = ARKodeSetExplicit(ARK_arkodemem);
+    *ier = ARKStepSetExplicit(ARK_arkodemem);
   else if (!strncmp(key_name, "IMPLICIT", 8))
-    *ier = ARKodeSetImplicit(ARK_arkodemem);
+    *ier = ARKStepSetImplicit(ARK_arkodemem);
   else if (!strncmp(key_name, "IMEX", 4))
-    *ier = ARKodeSetImEx(ARK_arkodemem);
+    *ier = ARKStepSetImEx(ARK_arkodemem);
   else if (!strncmp(key_name, "IRK_TABLE_NUM", 13))
-    *ier = ARKodeSetIRKTableNum(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetTableNum(ARK_arkodemem, (int) *ival, -1);
   else if (!strncmp(key_name, "ERK_TABLE_NUM", 13))
-    *ier = ARKodeSetERKTableNum(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetTableNum(ARK_arkodemem, -1, (int) *ival);
   else if (!strncmp(key_name, "ARK_TABLE_NUM", 13))
-    *ier = ARKodeSetARKTableNum(ARK_arkodemem, (int) ival[0], (int) ival[1]);
+    *ier = ARKStepSetTableNum(ARK_arkodemem, (int) ival[0], (int) ival[1]);
   else if (!strncmp(key_name, "MAX_NSTEPS", 10))
-    *ier = ARKodeSetMaxNumSteps(ARK_arkodemem, (long int) *ival);
+    *ier = ARKStepSetMaxNumSteps(ARK_arkodemem, (long int) *ival);
   else if (!strncmp(key_name, "HNIL_WARNS", 10))
-    *ier = ARKodeSetMaxHnilWarns(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetMaxHnilWarns(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "PREDICT_METHOD", 14))
-    *ier = ARKodeSetPredictorMethod(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetPredictorMethod(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "MAX_ERRFAIL", 11))
-    *ier = ARKodeSetMaxErrTestFails(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetMaxErrTestFails(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "MAX_CONVFAIL", 12))
-    *ier = ARKodeSetMaxConvFails(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetMaxConvFails(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "MAX_NITERS", 10))
-    *ier = ARKodeSetMaxNonlinIters(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetMaxNonlinIters(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "ADAPT_SMALL_NEF", 15))
-    *ier = ARKodeSetSmallNumEFails(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetSmallNumEFails(ARK_arkodemem, (int) *ival);
   else if (!strncmp(key_name, "LSETUP_MSBP", 11))
-    *ier = ARKodeSetMaxStepsBetweenLSet(ARK_arkodemem, (int) *ival);
+    *ier = ARKStepSetMaxStepsBetweenLSet(ARK_arkodemem, (int) *ival);
   else {
     *ier = -99;
     fprintf(stderr, "FARKSETIIN: Unrecognized key.\n\n");
@@ -394,39 +373,39 @@ void FARK_SETIIN(char key_name[], long int *ival, int *ier) {
    arguments; see farkode.h for further details */
 void FARK_SETRIN(char key_name[], realtype *rval, int *ier) {
   if (!strncmp(key_name, "INIT_STEP", 9))
-    *ier = ARKodeSetInitStep(ARK_arkodemem, *rval);
+    *ier = ARKStepSetInitStep(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "MAX_STEP", 8))
-    *ier = ARKodeSetMaxStep(ARK_arkodemem, *rval);
+    *ier = ARKStepSetMaxStep(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "MIN_STEP", 8))
-    *ier = ARKodeSetMinStep(ARK_arkodemem, *rval);
+    *ier = ARKStepSetMinStep(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "STOP_TIME", 9))
-    *ier = ARKodeSetStopTime(ARK_arkodemem, *rval);
+    *ier = ARKStepSetStopTime(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "NLCONV_COEF", 11))
-    *ier = ARKodeSetNonlinConvCoef(ARK_arkodemem, *rval);
+    *ier = ARKStepSetNonlinConvCoef(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "ADAPT_CFL", 9))
-    *ier = ARKodeSetCFLFraction(ARK_arkodemem, *rval);
+    *ier = ARKStepSetCFLFraction(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "ADAPT_SAFETY", 12))
-    *ier = ARKodeSetSafetyFactor(ARK_arkodemem, *rval);
+    *ier = ARKStepSetSafetyFactor(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "ADAPT_BIAS", 10))
-    *ier = ARKodeSetErrorBias(ARK_arkodemem, *rval);
+    *ier = ARKStepSetErrorBias(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "ADAPT_GROWTH", 12))
-    *ier = ARKodeSetMaxGrowth(ARK_arkodemem, *rval);
+    *ier = ARKStepSetMaxGrowth(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "ADAPT_BOUNDS", 12))
-    *ier = ARKodeSetFixedStepBounds(ARK_arkodemem, rval[0], rval[1]);
+    *ier = ARKStepSetFixedStepBounds(ARK_arkodemem, rval[0], rval[1]);
   else if (!strncmp(key_name, "ADAPT_ETAMX1", 12))
-    *ier = ARKodeSetMaxFirstGrowth(ARK_arkodemem, *rval);
+    *ier = ARKStepSetMaxFirstGrowth(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "ADAPT_ETAMXF", 12))
-    *ier = ARKodeSetMaxEFailGrowth(ARK_arkodemem, *rval);
+    *ier = ARKStepSetMaxEFailGrowth(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "ADAPT_ETACF", 11))
-    *ier = ARKodeSetMaxCFailGrowth(ARK_arkodemem, *rval);
+    *ier = ARKStepSetMaxCFailGrowth(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "NONLIN_CRDOWN", 11))
-    *ier = ARKodeSetNonlinCRDown(ARK_arkodemem, *rval);
+    *ier = ARKStepSetNonlinCRDown(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "NONLIN_RDIV", 9))
-    *ier = ARKodeSetNonlinRDiv(ARK_arkodemem, *rval);
+    *ier = ARKStepSetNonlinRDiv(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "LSETUP_DGMAX", 12))
-    *ier = ARKodeSetDeltaGammaMax(ARK_arkodemem, *rval);
+    *ier = ARKStepSetDeltaGammaMax(ARK_arkodemem, *rval);
   else if (!strncmp(key_name, "FIXED_STEP", 10))
-    *ier = ARKodeSetFixedStep(ARK_arkodemem, *rval);
+    *ier = ARKStepSetFixedStep(ARK_arkodemem, *rval);
   else {
     *ier = -99;
     fprintf(stderr, "FARKSETRIN: Unrecognized key: %s\n\n",key_name);
@@ -436,46 +415,56 @@ void FARK_SETRIN(char key_name[], realtype *rval, int *ier) {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeSetAdaptivityMethod;
+/* Fortran interface to C routine ARKStepSetAdaptivityMethod;
    see farkode.h for further details */
 void FARK_SETADAPTMETHOD(int *imethod, int *idefault, int *ipq,
-			 realtype *params, int *ier) {
+                         realtype *params, int *ier) {
 
-  *ier = ARKodeSetAdaptivityMethod(ARK_arkodemem, *imethod,
-				   *idefault, *ipq, params);
+  *ier = ARKStepSetAdaptivityMethod(ARK_arkodemem, *imethod,
+                                    *idefault, *ipq, params);
   return;
 }
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeSetERKTable; see
+/* Fortran interface to C routine ARKStepSetTables; see
    farkode.h for further details */
 void FARK_SETERKTABLE(int *s, int *q, int *p, realtype *c, realtype *A,
-		      realtype *b, realtype *b2, int *ier) {
-  *ier = ARKodeSetERKTable(ARK_arkodemem, *s, *q, *p, c, A, b, b2);
+                      realtype *b, realtype *b2, int *ier) {
+  ARKodeButcherTable Be;
+  Be = ARKodeButcherTable_Create(*s, *q, *p, c, A, b, b2);
+  *ier = ARKStepSetTables(ARK_arkodemem, *q, *p, NULL, Be);
+  ARKodeButcherTable_Free(Be);
   return;
 }
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeSetIRKTable; see
+/* Fortran interface to C routine ARKStepSetTables; see
    farkode.h for further details */
 void FARK_SETIRKTABLE(int *s, int *q, int *p, realtype *c, realtype *A,
-		      realtype *b, realtype *b2, int *ier) {
-  *ier = ARKodeSetIRKTable(ARK_arkodemem, *s, *q, *p, c, A, b, b2);
+                      realtype *b, realtype *b2, int *ier) {
+  ARKodeButcherTable Bi;
+  Bi = ARKodeButcherTable_Create(*s, *q, *p, c, A, b, b2);
+  *ier = ARKStepSetTables(ARK_arkodemem, *q, *p, Bi, NULL);
+  ARKodeButcherTable_Free(Bi);
   return;
 }
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeSetARKTables; see
+/* Fortran interface to C routine ARKStepSetTables; see
    farkode.h for further details */
 void FARK_SETARKTABLES(int *s, int *q, int *p, realtype *ci,
-		       realtype *ce, realtype *Ai, realtype *Ae,
-		       realtype *bi, realtype *be, realtype *b2i,
-		       realtype *b2e, int *ier) {
-  *ier = ARKodeSetARKTables(ARK_arkodemem, *s, *q, *p, ci,
-			    ce, Ai, Ae, bi, be, b2i, b2e);
+                       realtype *ce, realtype *Ai, realtype *Ae,
+                       realtype *bi, realtype *be, realtype *b2i,
+                       realtype *b2e, int *ier) {
+  ARKodeButcherTable Bi, Be;
+  Bi = ARKodeButcherTable_Create(*s, *q, *p, ci, Ai, bi, b2i);
+  Be = ARKodeButcherTable_Create(*s, *q, *p, ce, Ae, be, b2e);
+  *ier = ARKStepSetTables(ARK_arkodemem, *q, *p, Bi, Be);
+  ARKodeButcherTable_Free(Bi);
+  ARKodeButcherTable_Free(Be);
   return;
 }
 
@@ -483,7 +472,7 @@ void FARK_SETARKTABLES(int *s, int *q, int *p, realtype *ci,
 
 /* Fortran interface routine to set residual tolerance
    scalar/array; functions as an all-in-one interface to the C
-   routines ARKodeResStolerance and ARKodeResVtolerance;
+   routines ARKStepResStolerance and ARKStepResVtolerance;
    see farkode.h for further details */
 void FARK_SETRESTOLERANCE(int *itol, realtype *atol, int *ier) {
 
@@ -497,7 +486,7 @@ void FARK_SETRESTOLERANCE(int *itol, realtype *atol, int *ier) {
   switch (*itol) {
   case 1:
     if (*atol > ZERO)  abstol = *atol;
-    *ier = ARKodeResStolerance(ARK_arkodemem, abstol);
+    *ier = ARKStepResStolerance(ARK_arkodemem, abstol);
     break;
   case 2:
     Vatol = NULL;
@@ -508,7 +497,7 @@ void FARK_SETRESTOLERANCE(int *itol, realtype *atol, int *ier) {
     }
     N_VSetArrayPointer(atol, Vatol);
     if (N_VMin(Vatol) <= ZERO)  N_VConst(abstol, Vatol);
-    *ier = ARKodeResVtolerance(ARK_arkodemem, Vatol);
+    *ier = ARKStepResVtolerance(ARK_arkodemem, Vatol);
     N_VDestroy(Vatol);
     break;
   }
@@ -518,7 +507,7 @@ void FARK_SETRESTOLERANCE(int *itol, realtype *atol, int *ier) {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeSetDiagnostics; see
+/* Fortran interface to C routine ARKStepSetDiagnostics; see
    farkode.h for further details */
 void FARK_SETDIAGNOSTICS(char fname[], int *flen, int *ier) {
   char *filename=NULL;
@@ -535,7 +524,7 @@ void FARK_SETDIAGNOSTICS(char fname[], int *flen, int *ier) {
     *ier = 1;
     return;
   }
-  *ier = ARKodeSetDiagnostics(ARK_arkodemem, DFID);
+  *ier = ARKStepSetDiagnostics(ARK_arkodemem, DFID);
   free(filename);
   return;
 }
@@ -552,179 +541,183 @@ void FARK_STOPDIAGNOSTICS(int *ier) {
   }
   ark_mem = (ARKodeMem) ARK_arkodemem;
 
-  if (ark_mem->ark_diagfp == NULL) {
+  if (ark_mem->diagfp == NULL) {
     *ier = 1;
     return;
   }
-  *ier = fclose(ark_mem->ark_diagfp);
+  *ier = fclose(ark_mem->diagfp);
   return;
 }
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKDlsSetLinearSolver; see
-   farkode.h for further details */
-void FARK_DLSINIT(int *ier) {
-  if ( (ARK_arkodemem == NULL) || (F2C_ARKODE_linsol == NULL) ||
-       (F2C_ARKODE_matrix == NULL) ) {
+/* Fortran interface to C routine ARKStepSetNonlinearSolver */
+void FARK_NLSINIT(int *ier) {
+  if ( (ARK_arkodemem == NULL) || (F2C_ARKODE_nonlinsol == NULL) ) {
     *ier = -1;
     return;
   }
-  *ier = ARKDlsSetLinearSolver(ARK_arkodemem, F2C_ARKODE_linsol,
-                               F2C_ARKODE_matrix);
-  ARK_ls = ARK_LS_DIRECT;
-  return;
-}
-
-/* Fortran interface to C routine ARKDlsSetMassLinearSolver; see
-   farkode.h for further details */
-void FARK_DLSMASSINIT(int *time_dep, int *ier) {
-  if ( (ARK_arkodemem == NULL) || (F2C_ARKODE_mass_sol == NULL) ||
-       (F2C_ARKODE_mass_matrix == NULL) ) {
-    *ier = -1;
-    return;
-  }
-  *ier = ARKDlsSetMassLinearSolver(ARK_arkodemem, F2C_ARKODE_mass_sol,
-                                   F2C_ARKODE_mass_matrix, *time_dep);
-  ARK_mass_ls = ARK_LS_DIRECT;
+  *ier = ARKStepSetNonlinearSolver(ARK_arkodemem, F2C_ARKODE_nonlinsol);
   return;
 }
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKSpilsSetLinearSolver; see 
+/* ---DEPRECATED---
+   Fortran interface to C routine ARKStepSetLinearSolver; see
    farkode.h for further details */
-void FARK_SPILSINIT(int *ier) {
+void FARK_DLSINIT(int *ier)
+{ FARK_LSINIT(ier); }
+
+/* ---DEPRECATED---
+   Fortran interface to C routine ARKStepSetMassLinearSolver; see
+   farkode.h for further details */
+void FARK_DLSMASSINIT(int *time_dep, int *ier)
+{ FARK_LSMASSINIT(time_dep, ier); }
+
+/*=============================================================*/
+
+/* ---DEPRECATED---
+   Fortran interface to C routine ARKStepSetLinearSolver; see
+   farkode.h for further details */
+void FARK_SPILSINIT(int *ier)
+{ FARK_LSINIT(ier); }
+
+/* ---DEPRECATED---
+   Fortran interface to C routine ARKStepSetMassLinearSolver; see
+   farkode.h for further details */
+void FARK_SPILSMASSINIT(int *time_dep, int *ier)
+{ FARK_LSMASSINIT(time_dep, ier); }
+
+/*=============================================================*/
+
+/* ---DEPRECATED---
+   Fortran interfaces to C "set" routines for the ARKStep linear
+   solver; see farkode.h for further details */
+void FARK_SPILSSETEPSLIN(realtype *eplifac, int *ier)
+{ FARK_LSSETEPSLIN(eplifac, ier); }
+
+void FARK_SPILSSETMASSEPSLIN(realtype *eplifac, int *ier)
+{ FARK_LSSETMASSEPSLIN(eplifac, ier); }
+
+/*=============================================================*/
+
+/* Fortran interface to C routine ARKStepSetLinearSolver; see
+   farkode.h for further details */
+void FARK_LSINIT(int *ier) {
   if ( (ARK_arkodemem == NULL) || (F2C_ARKODE_linsol == NULL) ) {
     *ier = -1;
     return;
   }
-  *ier = ARKSpilsSetLinearSolver(ARK_arkodemem, F2C_ARKODE_linsol);
-  FARKNullMatrix();
-  ARK_ls = ARK_LS_ITERATIVE;
+  *ier = ARKStepSetLinearSolver(ARK_arkodemem, F2C_ARKODE_linsol,
+                                F2C_ARKODE_matrix);
+  ARK_ls = SUNTRUE;
   return;
 }
 
-/* Fortran interface to C routine ARKSpilsSetMassLinearSolver; see 
+/* Fortran interface to C routine ARKStepSetMassLinearSolver; see
    farkode.h for further details */
-void FARK_SPILSMASSINIT(int *time_dep, int *ier) {
+void FARK_LSMASSINIT(int *time_dep, int *ier) {
   if ( (ARK_arkodemem == NULL) || (F2C_ARKODE_mass_sol == NULL) ) {
     *ier = -1;
     return;
   }
-  *ier = ARKSpilsSetMassLinearSolver(ARK_arkodemem, 
-                                     F2C_ARKODE_mass_sol, 
-                                     *time_dep);
-  FARKNullMatrix();
-  ARK_mass_ls = ARK_LS_ITERATIVE;
+  *ier = ARKStepSetMassLinearSolver(ARK_arkodemem,
+                                    F2C_ARKODE_mass_sol,
+                                    F2C_ARKODE_mass_matrix, 
+                                    *time_dep);
+  ARK_mass_ls = SUNTRUE;
   return;
 }
 
 /*=============================================================*/
 
-/* Fortran interfaces to C "set" routines for the ARKSpils solver;
-   see farkode.h for further details */
-void FARK_SPILSSETEPSLIN(realtype *eplifac, int *ier) {
-  if (ARK_ls == ARK_LS_ITERATIVE)
-    *ier = ARKSpilsSetEpsLin(ARK_arkodemem, *eplifac);
-  else
-    *ier = 1;
-  return;
-}
+/* Fortran interfaces to C "set" routines for the ARKStep linear
+   solver; see farkode.h for further details */
+void FARK_LSSETEPSLIN(realtype *eplifac, int *ier)
+{ *ier = ARKStepSetEpsLin(ARK_arkodemem, *eplifac); }
 
-void FARK_SPILSSETMASSEPSLIN(realtype *eplifac, int *ier) {
-  if (ARK_mass_ls == ARK_LS_ITERATIVE)
-    *ier = ARKSpilsSetMassEpsLin(ARK_arkodemem, *eplifac);
-  else
-    *ier = 1;
-  return;
-}
+void FARK_LSSETMASSEPSLIN(realtype *eplifac, int *ier)
+{ *ier = ARKStepSetMassEpsLin(ARK_arkodemem, *eplifac); }
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKode (the main integrator);
-   see farkode.h for further details */
+/* Fortran interface to C routine ARKStepEvolve (the main integrator)
+   and optional output routines ARKStepGet*; see farkode.h for
+   further details */
 void FARK_ARKODE(realtype *tout, realtype *t, realtype *y,
-		 int *itask, int *ier) {
+                 int *itask, int *ier) {
 
   /* attach user solution array to solver memory */
   N_VSetArrayPointer(y, F2C_ARKODE_vec);
 
-  /* call ARKode solver */
-  *ier = ARKode(ARK_arkodemem, *tout, F2C_ARKODE_vec, t, *itask);
+  /* call ARKStepEvolve solver */
+  *ier = ARKStepEvolve(ARK_arkodemem, *tout, F2C_ARKODE_vec, t, *itask);
 
   /* detach user solution array from solver memory */
   N_VSetArrayPointer(NULL, F2C_ARKODE_vec);
 
   /* Load optional outputs in iout & rout */
-  ARKodeGetWorkSpace(ARK_arkodemem,
-		     &ARK_iout[0],          /* LENRW   */
-		     &ARK_iout[1]);         /* LENIW   */
-  ARKodeGetIntegratorStats(ARK_arkodemem,
-			   &ARK_iout[2],    /* NST     */
-			   &ARK_iout[3],    /* NST_STB */
-			   &ARK_iout[4],    /* NST_ACC */
-			   &ARK_iout[5],    /* NST_ATT */
-			   &ARK_iout[6],    /* NFE     */
-			   &ARK_iout[7],    /* NFI     */
-			   &ARK_iout[8],    /* NSETUPS */
-			   &ARK_iout[9],    /* NETF    */
-			   &ARK_rout[0],    /* H0U     */
-			   &ARK_rout[1],    /* HU      */
-			   &ARK_rout[2],    /* HCUR    */
-			   &ARK_rout[3]);   /* TCUR    */
-  ARKodeGetTolScaleFactor(ARK_arkodemem,
-			  &ARK_rout[4]);    /* TOLSFAC */
-  ARKodeGetNonlinSolvStats(ARK_arkodemem,
-                           &ARK_iout[10],   /* NNI     */
-                           &ARK_iout[11]);  /* NCFN    */
-  
+  ARKStepGetWorkSpace(ARK_arkodemem,
+                      &ARK_iout[0],          /* LENRW   */
+                      &ARK_iout[1]);         /* LENIW   */
+  ARKStepGetStepStats(ARK_arkodemem,
+                      &ARK_iout[2],    /* NST     */
+                      &ARK_rout[0],    /* H0U     */
+                      &ARK_rout[1],    /* HU      */
+                      &ARK_rout[2],    /* HCUR    */
+                      &ARK_rout[3]);   /* TCUR    */
+  ARKStepGetTimestepperStats(ARK_arkodemem,
+                             &ARK_iout[3],    /* NST_STB */
+                             &ARK_iout[4],    /* NST_ACC */
+                             &ARK_iout[5],    /* NST_ATT */
+                             &ARK_iout[6],    /* NFE     */
+                             &ARK_iout[7],    /* NFI     */
+                             &ARK_iout[8],    /* NSETUPS */
+                             &ARK_iout[9]);   /* NETF    */
+  ARKStepGetTolScaleFactor(ARK_arkodemem,
+                           &ARK_rout[4]);    /* TOLSFAC */
+  ARKStepGetNonlinSolvStats(ARK_arkodemem,
+                            &ARK_iout[10],   /* NNI     */
+                            &ARK_iout[11]);  /* NCFN    */
+
   /* If root finding is on, load those outputs as well */
   if (ARK_nrtfn != 0)
-    ARKodeGetNumGEvals(ARK_arkodemem, &ARK_iout[12]);  /* NGE */
+    ARKStepGetNumGEvals(ARK_arkodemem, &ARK_iout[12]);  /* NGE */
 
   /* Attach linear solver outputs */
-  switch(ARK_ls) {
-  case ARK_LS_DIRECT:
-    ARKDlsGetWorkSpace(ARK_arkodemem, &ARK_iout[13], &ARK_iout[14]);  /* LENRWLS, LENIWLS */
-    ARKDlsGetLastFlag(ARK_arkodemem, &ARK_iout[15]);                  /* LSTF  */
-    ARKDlsGetNumRhsEvals(ARK_arkodemem, &ARK_iout[16]);               /* NFELS */
-    ARKDlsGetNumJacEvals(ARK_arkodemem, &ARK_iout[17]);               /* NJE   */
-    break;
-  case ARK_LS_ITERATIVE:
-    ARKSpilsGetWorkSpace(ARK_arkodemem, &ARK_iout[13], &ARK_iout[14]); /* LENRWLS, LENIWLS */
-    ARKSpilsGetLastFlag(ARK_arkodemem, &ARK_iout[15]);                 /* LSTF  */
-    ARKSpilsGetNumRhsEvals(ARK_arkodemem, &ARK_iout[16]);              /* NFELS */
-    ARKSpilsGetNumJtimesEvals(ARK_arkodemem, &ARK_iout[17]);           /* NJTV  */
-    ARKSpilsGetNumPrecEvals(ARK_arkodemem, &ARK_iout[18]);             /* NPE   */
-    ARKSpilsGetNumPrecSolves(ARK_arkodemem, &ARK_iout[19]);            /* NPS   */
-    ARKSpilsGetNumLinIters(ARK_arkodemem, &ARK_iout[20]);              /* NLI   */
-    ARKSpilsGetNumConvFails(ARK_arkodemem, &ARK_iout[21]);             /* NCFL  */
+  if (ARK_ls) {
+    ARKStepGetLinWorkSpace(ARK_arkodemem, &ARK_iout[13], &ARK_iout[14]); /* LENRWLS, LENIWLS */
+    ARKStepGetLastLinFlag(ARK_arkodemem,     &ARK_iout[15]);            /* LSTF  */
+    ARKStepGetNumLinRhsEvals(ARK_arkodemem,  &ARK_iout[16]);            /* NFELS */
+    ARKStepGetNumJacEvals(ARK_arkodemem,     &ARK_iout[17]);            /* NJE   */
+    ARKStepGetNumJTSetupEvals(ARK_arkodemem, &ARK_iout[18]);            /* NJTS  */
+    ARKStepGetNumJtimesEvals(ARK_arkodemem,  &ARK_iout[19]);            /* NJTV  */
+    ARKStepGetNumPrecEvals(ARK_arkodemem,    &ARK_iout[20]);            /* NPE   */
+    ARKStepGetNumPrecSolves(ARK_arkodemem,   &ARK_iout[21]);            /* NPS   */
+    ARKStepGetNumLinIters(ARK_arkodemem,     &ARK_iout[22]);            /* NLI   */
+    ARKStepGetNumLinConvFails(ARK_arkodemem, &ARK_iout[23]);            /* NCFL  */
   }
-
+  
   /* Attach mass matrix linear solver outputs */
-  switch(ARK_mass_ls) {
-  case ARK_LS_DIRECT:
-    ARKDlsGetMassWorkSpace(ARK_arkodemem, &ARK_iout[22], &ARK_iout[23]);  /* LENRWMS, LENIWMS */
-    ARKDlsGetLastMassFlag(ARK_arkodemem, &ARK_iout[24]);                  /* LSTMF */
-    ARKDlsGetNumMassSetups(ARK_arkodemem, &ARK_iout[25]);                 /* NMSETUP */
-    ARKDlsGetNumMassSolves(ARK_arkodemem, &ARK_iout[26]);                 /* NMSOLVES */
-    ARKDlsGetNumMassMult(ARK_arkodemem, &ARK_iout[27]);                   /* NMMULTS */
-    break;
-  case ARK_LS_ITERATIVE:
-    ARKSpilsGetMassWorkSpace(ARK_arkodemem, &ARK_iout[22], &ARK_iout[23]); /* LENRWMS, LENIWMS */
-    ARKSpilsGetLastMassFlag(ARK_arkodemem, &ARK_iout[24]);                 /* LSTMF */
-    ARKSpilsGetNumMassPrecEvals(ARK_arkodemem, &ARK_iout[25]);             /* NMPE  */
-    ARKSpilsGetNumMassPrecSolves(ARK_arkodemem, &ARK_iout[26]);            /* NMPS  */
-    ARKSpilsGetNumMassIters(ARK_arkodemem, &ARK_iout[27]);                 /* NMLI  */
-    ARKSpilsGetNumMassConvFails(ARK_arkodemem, &ARK_iout[28]);             /* NMCFL */
+  if(ARK_mass_ls) {
+    ARKStepGetMassWorkSpace(ARK_arkodemem, &ARK_iout[24], &ARK_iout[25]); /* LENRWMS, LENIWMS */
+    ARKStepGetLastMassFlag(ARK_arkodemem,      &ARK_iout[26]);            /* LSTMF  */
+    ARKStepGetNumMassSetups(ARK_arkodemem,     &ARK_iout[27]);            /* NMSET  */
+    ARKStepGetNumMassSolves(ARK_arkodemem,     &ARK_iout[28]);            /* NMSOL  */
+    ARKStepGetNumMTSetups(ARK_arkodemem,       &ARK_iout[29]);            /* NMTSET */
+    ARKStepGetNumMassMult(ARK_arkodemem,       &ARK_iout[30]);            /* NMMUL  */
+    ARKStepGetNumMassPrecEvals(ARK_arkodemem,  &ARK_iout[31]);            /* NMPE   */
+    ARKStepGetNumMassPrecSolves(ARK_arkodemem, &ARK_iout[32]);            /* NMPS   */
+    ARKStepGetNumMassIters(ARK_arkodemem,      &ARK_iout[33]);            /* NMLI   */
+    ARKStepGetNumMassConvFails(ARK_arkodemem,  &ARK_iout[34]);            /* NMCFL  */
   }
   return;
 }
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeGetDky; see farkode.h
+/* Fortran interface to C routine ARKStepGetDky; see farkode.h
    for further details */
 void FARK_DKY(realtype *t, int *k, realtype *dky, int *ier) {
 
@@ -734,9 +727,9 @@ void FARK_DKY(realtype *t, int *k, realtype *dky, int *ier) {
   /* attach output data array to F2C_ARKODE_vec */
   N_VSetArrayPointer(dky, F2C_ARKODE_vec);
 
-  /* call ARKodeGetDky */
+  /* call ARKStepGetDky */
   *ier = 0;
-  *ier = ARKodeGetDky(ARK_arkodemem, *t, *k, F2C_ARKODE_vec);
+  *ier = ARKStepGetDky(ARK_arkodemem, *t, *k, F2C_ARKODE_vec);
 
   /* reattach F2C_ARKODE_vec to previous data array */
   N_VSetArrayPointer(f2c_data, F2C_ARKODE_vec);
@@ -745,7 +738,7 @@ void FARK_DKY(realtype *t, int *k, realtype *dky, int *ier) {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeGetErrWeights; see
+/* Fortran interface to C routine ARKStepGetErrWeights; see
    farkode.h for further details */
 void FARK_GETERRWEIGHTS(realtype *eweight, int *ier) {
 
@@ -755,9 +748,9 @@ void FARK_GETERRWEIGHTS(realtype *eweight, int *ier) {
   /* attach output data array to F2C_ARKODE_vec */
   N_VSetArrayPointer(eweight, F2C_ARKODE_vec);
 
-  /* call ARKodeGetErrWeights */
+  /* call ARKStepGetErrWeights */
   *ier = 0;
-  *ier = ARKodeGetErrWeights(ARK_arkodemem, F2C_ARKODE_vec);
+  *ier = ARKStepGetErrWeights(ARK_arkodemem, F2C_ARKODE_vec);
 
   /* reattach F2C_ARKODE_vec to previous data array */
   N_VSetArrayPointer(f2c_data, F2C_ARKODE_vec);
@@ -766,7 +759,7 @@ void FARK_GETERRWEIGHTS(realtype *eweight, int *ier) {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeGetResWeights; see 
+/* Fortran interface to C routine ARKStepGetResWeights; see
    farkode.h for further details */
 void FARK_GETRESWEIGHTS(realtype *rweight, int *ier) {
 
@@ -776,9 +769,9 @@ void FARK_GETRESWEIGHTS(realtype *rweight, int *ier) {
   /* attach output data array to F2C_ARKODE_vec */
   N_VSetArrayPointer(rweight, F2C_ARKODE_vec);
 
-  /* call ARKodeGetResWeights */
+  /* call ARKStepGetResWeights */
   *ier = 0;
-  *ier = ARKodeGetResWeights(ARK_arkodemem, F2C_ARKODE_vec);
+  *ier = ARKStepGetResWeights(ARK_arkodemem, F2C_ARKODE_vec);
 
   /* reattach F2C_ARKODE_vec to previous data array */
   N_VSetArrayPointer(f2c_data, F2C_ARKODE_vec);
@@ -787,7 +780,7 @@ void FARK_GETRESWEIGHTS(realtype *rweight, int *ier) {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeGetEstLocalErrors; see
+/* Fortran interface to C routine ARKStepGetEstLocalErrors; see
    farkode.h for further details */
 void FARK_GETESTLOCALERR(realtype *ele, int *ier) {
 
@@ -797,9 +790,9 @@ void FARK_GETESTLOCALERR(realtype *ele, int *ier) {
   /* attach output data array to F2C_ARKODE_vec */
   N_VSetArrayPointer(ele, F2C_ARKODE_vec);
 
-  /* call ARKodeGetEstLocalErrors */
+  /* call ARKStepGetEstLocalErrors */
   *ier = 0;
-  *ier = ARKodeGetEstLocalErrors(ARK_arkodemem, F2C_ARKODE_vec);
+  *ier = ARKStepGetEstLocalErrors(ARK_arkodemem, F2C_ARKODE_vec);
 
   /* reattach F2C_ARKODE_vec to previous data array */
   N_VSetArrayPointer(f2c_data, F2C_ARKODE_vec);
@@ -808,30 +801,21 @@ void FARK_GETESTLOCALERR(realtype *ele, int *ier) {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeFree; see farkode.h for
+/* Fortran interface to C routine ARKStepFree; see farkode.h for
    further details */
 void FARK_FREE() {
 
   ARKodeMem ark_mem;
   ark_mem = (ARKodeMem) ARK_arkodemem;
 
-  /* free DLS/SPILS interface */
-  if (ark_mem->ark_lfree)
-    ark_mem->ark_lfree(ark_mem);
-  ark_mem->ark_lmem = NULL;
-
-  /* free mass DLS/SPILS interface */
-  if (ark_mem->ark_mfree)
-    ark_mem->ark_mfree(ark_mem);
-  ark_mem->ark_mass_mem = NULL;
-
   /* free user_data structure */
-  if (ark_mem->ark_user_data)
-    free(ark_mem->ark_user_data);
-  ark_mem->ark_user_data = NULL;
+  if (ark_mem->user_data)
+    free(ark_mem->user_data);
+  ark_mem->user_data = NULL;
 
-  /* free main integrator memory structure */
-  ARKodeFree(&ARK_arkodemem);
+  /* free main integrator memory structure (internally
+     frees time step module, rootfinding, interpolation structures) */
+  ARKStepFree(&ARK_arkodemem);
 
   /* free interface vector / matrices / linear solvers */
   N_VSetArrayPointer(NULL, F2C_ARKODE_vec);
@@ -849,10 +833,10 @@ void FARK_FREE() {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKodeWriteParameters; see
+/* Fortran interface to C routineARKStepWriteParameters; see
    farkode.h for further details */
 void FARK_WRITEPARAMETERS(int *ier) {
-  *ier = ARKodeWriteParameters(ARK_arkodemem, stdout);
+  *ier += ARKStepWriteParameters(ARK_arkodemem, stdout);
   return;
 }
 
@@ -870,7 +854,7 @@ int FARKfe(realtype t, N_Vector y, N_Vector ydot, void *user_data) {
   ARK_userdata = (FARKUserData) user_data;
 
   FARK_EXP_FUN(&t, ydata, dydata, ARK_userdata->ipar,
-	       ARK_userdata->rpar, &ier);
+               ARK_userdata->rpar, &ier);
   return(ier);
 }
 
@@ -888,7 +872,7 @@ int FARKfi(realtype t, N_Vector y, N_Vector ydot, void *user_data) {
   ARK_userdata = (FARKUserData) user_data;
 
   FARK_IMP_FUN(&t, ydata, dydata, ARK_userdata->ipar,
-	       ARK_userdata->rpar, &ier);
+               ARK_userdata->rpar, &ier);
   return(ier);
 }
 
