@@ -1,21 +1,17 @@
 /*---------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds @ SMU
  *---------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2017, Southern Methodist University and 
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Southern Methodist University and Lawrence Livermore 
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence 
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  *---------------------------------------------------------------
- * Fortran/C interface routines for ARKODE/ARDLS, for the case
+ * Fortran/C interface routines for ARKODE/ARKLS, for the case
  * of a user-supplied sparse Jacobian routine.
  *--------------------------------------------------------------*/
 
@@ -23,7 +19,7 @@
 #include <stdlib.h>
 #include "farkode.h"
 #include "arkode_impl.h"
-#include <arkode/arkode_direct.h>
+#include <arkode/arkode_arkstep.h>
 #include <sunmatrix/sunmatrix_sparse.h>
 
 /*=============================================================*/
@@ -36,10 +32,10 @@ extern "C" {
 
  
   extern void FARK_SPJAC(realtype *T, realtype *Y, 
-			 realtype *FY, long int *N, 
+                         realtype *FY, long int *N, 
                          long int *NNZ, realtype *JDATA, 
                          sunindextype *JRVALS, sunindextype *JCPTRS, 
-			 realtype *H,  long int *IPAR,
+                         realtype *H,  long int *IPAR,
                          realtype *RPAR, realtype *V1,
                          realtype *V2, realtype *V3,
                          int *ier);
@@ -50,7 +46,7 @@ extern "C" {
 
 /*=============================================================*/
 
-/* Fortran interface to C routine ARKDlsSetJacFn; see 
+/* Fortran interface to C routine ARKStepSetJacFn; see 
    farkode.h for further information */
 void FARK_SPARSESETJAC(int *ier)
 {
@@ -60,7 +56,7 @@ void FARK_SPARSESETJAC(int *ier)
                   "Sparse Fortran users must configure SUNDIALS with 64-bit integers.");
   *ier = 1;
 #else  
-  *ier = ARKDlsSetJacFn(ARK_arkodemem, FARKSparseJac);
+  *ier = ARKStepSetJacFn(ARK_arkodemem, FARKSparseJac);
 #endif
 }
 
@@ -69,8 +65,8 @@ void FARK_SPARSESETJAC(int *ier)
 /* C interface to user-supplied Fortran routine FARKSPJAC; see 
    farkode.h for additional information  */
 int FARKSparseJac(realtype t, N_Vector y, N_Vector fy, 
-		  SUNMatrix J, void *user_data, N_Vector vtemp1, 
-		  N_Vector vtemp2, N_Vector vtemp3)
+                  SUNMatrix J, void *user_data, N_Vector vtemp1, 
+                  N_Vector vtemp2, N_Vector vtemp3)
 {
   int ier;
   realtype *ydata, *fydata, *v1data, *v2data, *v3data, *Jdata;
@@ -79,7 +75,7 @@ int FARKSparseJac(realtype t, N_Vector y, N_Vector fy,
   sunindextype *indexvals, *indexptrs; 
   FARKUserData ARK_userdata;
 
-  ARKodeGetLastStep(ARK_arkodemem, &h);
+  ARKStepGetLastStep(ARK_arkodemem, &h);
   ydata   = N_VGetArrayPointer(y);
   fydata  = N_VGetArrayPointer(fy);
   v1data  = N_VGetArrayPointer(vtemp1);
