@@ -3,19 +3,15 @@
  * Programmer(s): Daniel R. Reynolds and Ting Yan @ SMU
  *    Alan C. Hindmarsh, Radu Serban and Aaron Collier @ LLNL
  * -----------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2017, Southern Methodist University and 
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Southern Methodist University and Lawrence Livermore 
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence 
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  * This is the header file for FCVODE, the Fortran interface to
  * the CVODE package.                                            
@@ -67,19 +63,20 @@
  *   FCVREINIT                  CVReInit
  *   FCVSETIIN                  CVodeSet* (integer arguments)
  *   FCVSETRIN                  CVodeSet* (real arguments)
+ *   FCVSETVIN                  CVodeSet* (vector arguments)
  *   FCVEWTSET                  CVodeWFtolerances
  *
- *   FCVDLSINIT                 CVDlsSetLinearSolver
- *   FCVDENSESETJAC             CVDlsSetJacFn
- *   FCVBANDSETJAC              CVDlsSetJacFn
- *   FCVSPARSESETJAC            CVDlsSetJacFn
+ *   FCVLSINIT                  CVodeSetLinearSolver
+ *   FCVLSSETEPSLIN             CVodeSetEpsLin
+ *   FCVLSSETJAC                CVodeSetJacTimes
+ *   FCVLSSETPREC               CVodeSetPreconditioner
+ *   FCVDENSESETJAC             CVodeSetJacFn
+ *   FCVBANDSETJAC              CVodeSetJacFn
+ *   FCVSPARSESETJAC            CVodeSetJacFn
  *
  *   FCVDIAG                    CVDiag
  *
- *   FCVSPILSINIT               CVSpilsSetLinearSolver
- *   FCVSPILSSETEPSLIN          CVSpilsSetEpsLin
- *   FCVSPILSSETJAC             CVSpilsSetJacTimes
- *   FCVSPILSSETPREC            CVSpilsSetPreconditioner
+ *   FCVNLSINIT                 CVSetNonlinearSolver
  *
  *   FCVODE                     CVode, CVodeGet*, and CV*Get*
  *   FCVDKY                     CVodeGetDky
@@ -96,13 +93,13 @@
  *   Fortran:           Interface Fcn:           CVODE Type:
  *   -------------      ------------------       -----------------------
  *   FCVFUN             FCVf                     CVRhsFn
- *   FCVDJAC            FCVDenseJac              CVDlsJacFn
- *   FCVBJAC            FCVBandJac               CVDlsJacFn
- *   FCVSPJAC           FCVSparseJac             CVDlsJacFn
- *   FCVPSET            FCVPSet                  CVSpilsPrecSetupFn
- *   FCVPSOL            FCVPSol                  CVSpilsPrecSolveFn
- *   FCVJTSETUP         FCVJTSetup               CVSpilsJacTimesSetupFn
- *   FCVJTIMES          FCVJtimes                CVSpilsJacTimesVecFn
+ *   FCVDJAC            FCVDenseJac              CVLsJacFn
+ *   FCVBJAC            FCVBandJac               CVLsJacFn
+ *   FCVSPJAC           FCVSparseJac             CVLsJacFn
+ *   FCVPSET            FCVPSet                  CVLsPrecSetupFn
+ *   FCVPSOL            FCVPSol                  CVLsPrecSolveFn
+ *   FCVJTSETUP         FCVJTSetup               CVLsJacTimesSetupFn
+ *   FCVJTIMES          FCVJtimes                CVLsJacTimesVecFn
  *   FCVEWT             FCVEwtSet                CVEwtFn
  *   -------------      ------------------       -----------------------
  *
@@ -301,12 +298,12 @@
  * (2) Optional user-supplied Jacobian-vector product setup routine: 
  *   FCVJTSETUP
  *
- *   As an option when using the CVSpils iterative linear solver 
- *   interface, the user may supply a routine that computes the product of 
- *   the system Jacobian J = dfi(t,y)/dy and a given vector v, as well as 
- *   a routine to set up any user data structures in preparation for the 
- *   matrix-vector product.  If a 'setup' routine is supplied, it must 
- *   have the following form:
+ *   As an option when using the CVLS linear solver interface with a 
+ *   matrix-free linear solver, the user may supply a routine that computes 
+ *   the product of the system Jacobian J = dfi(t,y)/dy and a given vector v, 
+ *   as well as a routine to set up any user data structures in preparation 
+ *   for the matrix-vector product.  If a 'setup' routine is supplied, it 
+ *   must have the following form:
  *
  *       SUBROUTINE FCVJTSETUP(T, Y, FY, H, IPAR, RPAR, IER)
  *
@@ -359,9 +356,10 @@
  * (3) Optional user-supplied preconditioner setup/solve routines: FCVPSET 
  *   and FCVPSOL
  *
- *     As an option when using the CVSPILS linear solver interface, the 
- *     user may supply routines to setup and apply the preconditioner.  
- *     If supplied, these must have the following form:
+ *     As an option when using the CVLS linear solver interface and an 
+ *     iterative linear solver, the user may supply routines to setup and
+ *     apply the preconditioner.  If supplied, these must have the 
+ *     following form:
  *
  *       SUBROUTINE FCVPSET(T,Y,FY,JOK,JCUR,GAMMA,H,IPAR,RPAR,IER)
  *
@@ -452,12 +450,12 @@
  *                         FSUNSPTFQMRINIT / FSUNSUPERLUMTINIT /
  *                         FSUNSUPERLUMTSETORDERING,
  *                      FCVMALLOC,
- *                      FCVDLSINIT / FCVSPILSINIT,
+ *                      FCVLSINIT,
  *                      FCVREINIT
  *
  *   NOTE: the initialization order is important!  It *must* proceed as 
  *   shown: vector, matrix (if used), linear solver (if used), CVode, 
- *   CVDls/CVSpils, reinit.
+ *   CVLs, reinit.
  * 
  * (5.1s) To initialize the a vector specification for storing the solution 
  *   data, the user must make one of the following calls:
@@ -571,7 +569,7 @@
  * (5.4) To set various problem and solution parameters and allocate
  *   internal memory, make the following call:
  *
- *       CALL FCVMALLOC(T0, Y0, METH, ITMETH, IATOL, RTOL, ATOL,
+ *       CALL FCVMALLOC(T0, Y0, METH, IATOL, RTOL, ATOL,
  *      1               IOUT, ROUT, IPAR, RPAR, IER)
  *
  *   The arguments are:
@@ -580,9 +578,6 @@
  *      METH   = flag denoting basic integration method [int, input]:
  *                   1 = Adams (nonstiff), 
  *                   2 = BDF (stiff)
- *      ITMETH = flag denoting nonlinear iteration method [int, input]: 
- *                   1 = functional iteration, 
- *                   2 = Newton iter.
  *      IATOL  = flag denoting type for absolute tolerance ATOL [int, input]: 
  *                   1 = scalar, 
  *                   2 = array.
@@ -626,25 +621,14 @@
  *           UROUND  = ROUT( 6) from UNIT_ROUNDOFF
  *   See the CVODE manual for details. 
  *
- * (5.5) If a direct linear solver was created in step (5.3) then it must be 
+ * (5.5) If a linear solver was created in step (5.3) then it must be 
  *   attached to CVode.  If the user called any one of FSUNBANDLINSOLINIT, 
  *   FSUNDENSELINSOLINIT, FSUNKLUINIT, FSUNLAPACKBANDINIT, 
- *   FSUNLAPACKDENSEINIT, or FSUNSUPERLUMTINIT, then this must be 
- *   attached to the CVDLS interface using the command:
- *
- *       CALL FCVDLSINIT(IER)
- *
- *   The arguments are:
- *	IER  = return completion flag [int, output]:
- *                  0 = SUCCESS,
- *                 -1 = failure (see printed message for failure details).
- *
- * (5.5) If an iterative linear solver was created in step (5.3) then it must 
- *   be attached to CVode.  If the user called any one of FSUNPCGINIT, 
+ *   FSUNLAPACKDENSEINIT, FSUNSUPERLUMTINIT, FSUNPCGINIT, 
  *   FSUNSPBCGSINIT, FSUNSPFGMRINIT, FSUNSPGMRINIT, or FSUNSPTFQMRINIT, 
- *   then this must be attached to the CVSPILS interface using the command:
+ *   then this must be attached to the CVLS interface using the command:
  *
- *       CALL FCVSPILSINIT(IER)
+ *       CALL FCVLSINIT(IER)
  *
  *   The arguments are:
  *	IER  = return completion flag [int, output]:
@@ -673,7 +657,7 @@
  *
  * (5.7) If the user program includes the FCVBJAC routine for the 
  *   evaluation of the band approximation to the Jacobian, then following 
- *   the call to FCVDLSINIT, the following call must be made 
+ *   the call to FCVLSINIT, the following call must be made 
  *
  *       CALL FCVBANDSETJAC(FLAG, IER)
  *
@@ -684,7 +668,7 @@
  * 
  *   If the user program includes the FCVDJAC routine for the evaluation 
  *   of the dense approximation to the Jacobian, then after the call to 
- *   FCVDLSINIT, the following call must be made 
+ *   FCVLSINIT, the following call must be made 
  *
  *       CALL FCVDENSESETJAC(FLAG, IER)
  *
@@ -696,7 +680,7 @@
  *   When using a sparse matrix and linear solver the user must provide the
  *   FCVSPJAC routine for the evaluation of the sparse approximation to 
  *   the Jacobian.  To indicate that this routine has been provided, after 
- *   the call to FCVDLSINIT, the following call must be made 
+ *   the call to FCVLSINIT, the following call must be made 
  *
  *       CALL FCVSPARSESETJAC(IER)
  *
@@ -704,10 +688,10 @@
  *
  * (5.8) If the user program includes the FCVJTSETUP and FCVJTIMES 
  *   routines for setup of a Jacobian-times-vector product (for use with 
- *   the CVSpils interface), then after creating the CVSpils interface, 
+ *   the CVLS interface), then after creating the CVLS interface, 
  *   the following call must be made:
  *
- *       CALL FCVSPILSSETJAC(FLAG, IER)
+ *       CALL FCVLSSETJAC(FLAG, IER)
  *
  *   with the int FLAG=1 to specify that FCVJTSETUP and FCVJTIMES are 
  *   provided and should be used; FLAG=0 specifies a reset to the internal 
@@ -716,9 +700,9 @@
  * 
  * (5.9) If the user program includes the FCVPSET and FCVPSOL routines 
  *   for supplying a preconditioner to an iterative linear solver, then 
- *   after creating the CVSpils interface, the following call must be made
+ *   after creating the CVLS interface, the following call must be made
  *
- *       CALL FCVSPILSSETPREC(FLAG, IER)
+ *       CALL FCVLSSETPREC(FLAG, IER)
  *
  *   with the int FLAG=1.  If FLAG=0 then preconditioning with these 
  *   routines will be disabled. The return flag IER=0 if successful, 
@@ -726,7 +710,7 @@
  *
  * (5.10) If the user wishes to use one of CVode's built-in preconditioning 
  *   modules, FCVBP or FCVBBD, then that should be initialized after 
- *   creating the CVSpils interface using one of the calls
+ *   creating the CVLS interface using one of the calls
  *
  *       CALL FCVBPINIT(NEQ, MU, ML, IER)
  *       CALL FCVBBDINIT(NLOCAL, MUDQ, MLDQ, MU, ML, DQRELY, IER)
@@ -744,7 +728,7 @@
  *       CALL FCVREINIT(T0, Y0, IATOL, RTOL, ATOL, IER)
  *
  *   The arguments have the same names and meanings as those of FCVMALLOC,
- *   except that METH and ITMETH have been omitted from the argument list 
+ *   except that METH has been omitted from the argument list
  *   (being unchanged for the new problem).  
  *   FCVREINIT performs the same initializations as FCVMALLOC, but does no memory 
  *   allocation, using instead the existing internal memory created by the
@@ -786,28 +770,31 @@
  *   be one of the following: INIT_STEP, MAX_STEP, MIN_STEP, STOP_TIME,
  *   NLCONV_COEF.  The int return flag IER is 0 if successful, and <0 otherwise.
  *
+ * (5.15) To set the vector of constraints, make the following call:
+ *
+ *      CALL CVSETVIN(KEY, ARRAY, IER)
+ *
+ *    where ARRAY is an array of realtype and the quoted character string
+ *    KEY is CONSTR_VEC.  The int return flag IER is 0 if successful, and
+ *    nonzero otherwise.
+ * 
  * -----------------------------------------------------------------------------
  *
- * (6) Optional outputs from DLS and SPILS linear solvers (stored in the 
+ * (6) Optional outputs from CVLS linear solvers (stored in the 
  *   IOUT array that was passed to FCVMALLOC)
  *
- *   Optional outputs specific to the CVDLS interface:
- *        LENRWLS  = IOUT(13) from CVDlsGetWorkSpace (realtype space)
- *        LENIWLS  = IOUT(14) from CVDlsGetWorkSpace (integer space)
- *        LSTF     = IOUT(15) from CVDlsGetLastFlag
- *        NFELS    = IOUT(16) from CVDlsGetNumRhsEvals
- *        NJED     = IOUT(17) from CVDlsGetNumJacEvals
- *
- *   Optional outputs specific to the CVSPILS interface:
- *        LENRWLS  = IOUT(13) from CVSpilsGetWorkSpace
- *        LENIWLS  = IOUT(14) from CVSpilsGetWorkSpace
- *        LSTF     = IOUT(15) from CVSpilsGetLastFlag
- *        NFELS    = IOUT(16) from CVSpilsGetNumRhsEvals
- *        NJTV     = IOUT(17) from CVSpilsGetNumJtimesEvals
- *        NPE      = IOUT(18) from CVSpilsGetNumPrecEvals
- *        NPS      = IOUT(19) from CVSpilsGetNumPrecSolves
- *        NLI      = IOUT(20) from CVSpilsGetNumLinIters
- *        NCFL     = IOUT(21) from CVSpilsGetNumConvFails
+ *   Optional outputs specific to the CVLS interface:
+ *        LENRWLS  = IOUT(13) from CVodeGetLinWorkSpace (realtype space)
+ *        LENIWLS  = IOUT(14) from CVodeGetLinWorkSpace (integer space)
+ *        LSTF     = IOUT(15) from CVodeGetLastLinFlag
+ *        NFELS    = IOUT(16) from CVodeGetNumLinRhsEvals
+ *        NJE      = IOUT(17) from CVodeGetNumJacEvals
+ *        NJTS     = IOUT(18) from CVodeGetNumJTSetupEvals
+ *        NJTV     = IOUT(19) from CVodeGetNumJtimesEvals
+ *        NPE      = IOUT(20) from CVodeGetNumPrecEvals
+ *        NPS      = IOUT(21) from CVodeGetNumPrecSolves
+ *        NLI      = IOUT(22) from CVodeGetNumLinIters
+ *        NCFL     = IOUT(23) from CVodeGetNumLinConvFails
  *
  *   Optional outputs specific to the DIAG case are:
  *        LENRWLS  = IOUT(13) from CVDiagGetWorkSpace
@@ -877,7 +864,7 @@
  * (10) Memory freeing: FCVFREE 
  *
  *   To free the internal memory created by the calls to FCVMALLOC, 
- *   FCVDLSINIT/FCVSPILSINIT and FNVINIT*, make the call
+ *   FCVLSINIT and FNVINIT*, make the call
  *
  *       CALL FCVFREE
  * 
@@ -906,14 +893,15 @@ extern "C" {
 #define FCV_REINIT         SUNDIALS_F77_FUNC(fcvreinit, FCVREINIT)
 #define FCV_SETIIN         SUNDIALS_F77_FUNC(fcvsetiin, FCVSETIIN)
 #define FCV_SETRIN         SUNDIALS_F77_FUNC(fcvsetrin, FCVSETRIN)
+#define FCV_SETVIN         SUNDIALS_F77_FUNC(fcvsetvin, FCVSETVIN)
 #define FCV_EWTSET         SUNDIALS_F77_FUNC(fcvewtset, FCVEWTSET)
-#define FCV_DLSINIT        SUNDIALS_F77_FUNC(fcvdlsinit, FCVDLSINIT)
+#define FCV_LSINIT         SUNDIALS_F77_FUNC(fcvlsinit, FCVLSINIT)
+#define FCV_LSSETJAC       SUNDIALS_F77_FUNC(fcvlssetjac, FCVLSSETJAC)
+#define FCV_LSSETPREC      SUNDIALS_F77_FUNC(fcvlssetprec, FCVLSSETPREC)
+#define FCV_LSSETEPSLIN    SUNDIALS_F77_FUNC(fcvlssetepslin, FCVLSSETEPSLIN)
 #define FCV_DENSESETJAC    SUNDIALS_F77_FUNC(fcvdensesetjac, FCVDENSESETJAC)
 #define FCV_BANDSETJAC     SUNDIALS_F77_FUNC(fcvbandsetjac, FCVBANDSETJAC)
 #define FCV_SPARSESETJAC   SUNDIALS_F77_FUNC(fcvsparsesetjac, FCVSPARSESETJAC)  
-#define FCV_SPILSINIT      SUNDIALS_F77_FUNC(fcvspilsinit, FCVSPILSINIT)
-#define FCV_SPILSSETJAC    SUNDIALS_F77_FUNC(fcvspilssetjac, FCVSPILSSETJAC)
-#define FCV_SPILSSETPREC   SUNDIALS_F77_FUNC(fcvspilssetprec, FCVSPILSSETPREC)
 #define FCV_DIAG           SUNDIALS_F77_FUNC(fcvdiag, FCVDIAG)
 #define FCV_CVODE          SUNDIALS_F77_FUNC(fcvode, FCVODE)
 #define FCV_DKY            SUNDIALS_F77_FUNC(fcvdky, FCVDKY)
@@ -929,6 +917,14 @@ extern "C" {
 #define FCV_EWT            SUNDIALS_F77_FUNC(fcvewt, FCVEWT)
 #define FCV_GETERRWEIGHTS  SUNDIALS_F77_FUNC(fcvgeterrweights, FCVGETERRWEIGHTS)
 #define FCV_GETESTLOCALERR SUNDIALS_F77_FUNC(fcvgetestlocalerr, FCVGETESTLOCALERR)
+#define FCV_NLSINIT        SUNDIALS_F77_FUNC(fcvnlsinit, FCVNLSINIT)
+
+/*---DEPRECATED---*/
+#define FCV_DLSINIT        SUNDIALS_F77_FUNC(fcvdlsinit, FCVDLSINIT)
+#define FCV_DLSSETJAC      SUNDIALS_F77_FUNC(fcvdlssetjac, FCVDLSSETJAC)
+#define FCV_SPILSINIT      SUNDIALS_F77_FUNC(fcvspilsinit, FCVSPILSINIT)
+#define FCV_SPILSSETPREC   SUNDIALS_F77_FUNC(fcvspilssetprec, FCVSPILSSETPREC)
+/*----------------*/
 
 #else
 
@@ -936,14 +932,15 @@ extern "C" {
 #define FCV_REINIT         fcvreinit_
 #define FCV_SETIIN         fcvsetiin_
 #define FCV_SETRIN         fcvsetrin_
+#define FCV_SETVIN         fcvsetvin_
 #define FCV_EWTSET         fcvewtset_
-#define FCV_DLSINIT        fcvdlsinit_
+#define FCV_LSINIT         fcvlsinit_
+#define FCV_LSSETJAC       fcvlssetjac_
+#define FCV_LSSETPREC      fcvlssetprec_
+#define FCV_LSSETEPSLIN    fcvlssetepslin_
 #define FCV_DENSESETJAC    fcvdensesetjac_
 #define FCV_BANDSETJAC     fcvbandsetjac_
 #define FCV_SPARSESETJAC   fcvsparsesetjac_
-#define FCV_SPILSINIT      fcvspilsinit_
-#define FCV_SPILSSETJAC    fcvspilssetjac_
-#define FCV_SPILSSETPREC   fcvspilssetprec_
 #define FCV_DIAG           fcvdiag_
 #define FCV_CVODE          fcvode_
 #define FCV_DKY            fcvdky_
@@ -959,7 +956,15 @@ extern "C" {
 #define FCV_EWT            fcvewt_
 #define FCV_GETERRWEIGHTS  fcvgeterrweights_
 #define FCV_GETESTLOCALERR fcvgetestlocalerr_
+#define FCV_NLSINIT        fcvnlsinit_
 
+/*---DEPRECATED---*/
+#define FCV_DLSINIT        fcvdlsinit_
+#define FCV_SPILSINIT      fcvspilsinit_
+#define FCV_SPILSINIT      fcvspilsinit_
+#define FCV_SPILSSETPREC   fcvspilssetprec_
+/*----------------*/
+  
 #endif
 
   /* Type for user data */
@@ -972,7 +977,7 @@ extern "C" {
   /* Prototypes of exported functions */
 
   void FCV_MALLOC(realtype *t0, realtype *y0,
-                  int *meth, int *itmeth, int *iatol,
+                  int *meth, int *iatol,
                   realtype *rtol, realtype *atol,
                   long int *iout, realtype *rout,
                   long int *ipar, realtype *rpar,
@@ -986,19 +991,29 @@ extern "C" {
 
   void FCV_SETRIN(char key_name[], realtype *rval, int *ier);
 
+  void FCV_SETVIN(char key_name[], realtype *vval, int *ier);
   void FCV_EWTSET(int *flag, int *ier);
 
-  void FCV_DLSINIT(int *ier);
+  void FCV_LSINIT(int *ier);
+  void FCV_LSSETJAC(int *flag, int *ier);
+  void FCV_LSSETPREC(int *flag, int *ier);
+  void FCV_LSSETEPSLIN(realtype *eplifac, int *ier);
   void FCV_DENSESETJAC(int *flag, int *ier);
   void FCV_BANDSETJAC(int *flag, int *ier);
   void FCV_SPARSESETJAC(int *ier);
 
+/*---DEPRECATED---*/
+  void FCV_DLSINIT(int *ier);
+  void FCV_DLSSETJAC(int *flag, int *ier);
   void FCV_SPILSINIT(int *ier);
-  void FCV_SPILSSETJAC(int *flag, int *ier);
   void FCV_SPILSSETPREC(int *flag, int *ier);
+  void FCV_SPILSSETEPSLIN(realtype *eplifac, int *ier);
+/*----------------*/
   
   void FCV_DIAG(int *ier);
 
+  void FCV_NLSINIT(int *ier);
+
   void FCV_CVODE(realtype *tout, realtype *t, realtype *y, int *itask, int *ier);
 
   void FCV_DKY(realtype *t, int *k, realtype *dky, int *ier);
@@ -1043,12 +1058,14 @@ extern "C" {
 
   void FCVNullMatrix();
   void FCVNullLinsol();
+  void FCVNullNonlinSol();
 
   /* Declarations for global variables shared amongst various routines */
 
-  extern N_Vector F2C_CVODE_vec;             /* defined in FNVECTOR module */
-  extern SUNMatrix F2C_CVODE_matrix;         /* defined in FSUNMATRIX module */
-  extern SUNLinearSolver F2C_CVODE_linsol;   /* defined in FSUNLINSOL module */
+  extern N_Vector F2C_CVODE_vec;                 /* defined in FNVECTOR module      */
+  extern SUNMatrix F2C_CVODE_matrix;             /* defined in FSUNMATRIX module    */
+  extern SUNLinearSolver F2C_CVODE_linsol;       /* defined in FSUNLINSOL module    */
+  extern SUNNonlinearSolver F2C_CVODE_nonlinsol; /* defined in FSUNNONLINSOL module */
 
   extern void *CV_cvodemem;        /* defined in fcvode.c */
   extern long int *CV_iout;        /* defined in fcvode.c */
@@ -1058,8 +1075,7 @@ extern "C" {
 
   /* Linear solver IDs */
 
-  enum { CV_LS_ITERATIVE = 0, CV_LS_DIRECT = 1,
-         CV_LS_DIAG = 2, CV_LS_CUSTOM = 3 };
+  enum { CV_LS_STD = 0, CV_LS_DIAG = 1 };
 
 #ifdef __cplusplus
 }
