@@ -5,15 +5,15 @@
  * -----------------------------------------------------------------
  * Programmer: Radu Serban @ LLNL
  * -----------------------------------------------------------------
- * LLNS Copyright Start
- * Copyright (c) 2014, Lawrence Livermore National Security
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Lawrence Livermore National Laboratory in part under 
- * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
- * Produced at the Lawrence Livermore National Laboratory.
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  * This is the implementation file for the optional input and output
  * functions for the adjoint module in the CVODES solver.
@@ -82,31 +82,33 @@ int CVodeSetAdjNoSensi(void *cvode_mem)
  * -----------------------------------------------------------------
  */
 
-int CVodeSetIterTypeB(void *cvode_mem, int which, int iterB)
+int CVodeSetNonlinearSolverB(void *cvode_mem, int which, SUNNonlinearSolver NLS)
 {
   CVodeMem cv_mem;
   CVadjMem ca_mem;
   CVodeBMem cvB_mem;
   void *cvodeB_mem;
-  int flag;
 
   /* Check if cvode_mem exists */
   if (cvode_mem == NULL) {
-    cvProcessError(NULL, CV_MEM_NULL, "CVODEA", "CVodeSetIterTypeB", MSGCV_NO_MEM);
+    cvProcessError(NULL, CV_MEM_NULL, "CVODEA",
+                   "CVodeSetNonlinearSolverB", MSGCV_NO_MEM);
     return(CV_MEM_NULL);
   }
   cv_mem = (CVodeMem) cvode_mem;
 
   /* Was ASA initialized? */
   if (cv_mem->cv_adjMallocDone == SUNFALSE) {
-    cvProcessError(cv_mem, CV_NO_ADJ, "CVODEA", "CVodeSetIterTypeB", MSGCV_NO_ADJ);
+    cvProcessError(cv_mem, CV_NO_ADJ, "CVODEA",
+                   "CVodeSetNonlinearSolverB", MSGCV_NO_ADJ);
     return(CV_NO_ADJ);
-  } 
+  }
   ca_mem = cv_mem->cv_adj_mem;
 
   /* Check which */
   if ( which >= ca_mem->ca_nbckpbs ) {
-    cvProcessError(cv_mem, CV_ILL_INPUT, "CVODEA", "CVodeSetIterTypeB", MSGCV_BAD_WHICH);
+    cvProcessError(cv_mem, CV_ILL_INPUT, "CVODEA",
+                   "CVodeSetNonlinearSolverB", MSGCV_BAD_WHICH);
     return(CV_ILL_INPUT);
   }
 
@@ -119,9 +121,7 @@ int CVodeSetIterTypeB(void *cvode_mem, int which, int iterB)
 
   cvodeB_mem = (void *) (cvB_mem->cv_mem);
 
-  flag = CVodeSetIterType(cvodeB_mem, iterB);
-  
-  return(flag);
+  return(CVodeSetNonlinearSolver(cvodeB_mem, NLS));
 }
 
 int CVodeSetUserDataB(void *cvode_mem, int which, void *user_dataB)
@@ -416,6 +416,46 @@ int CVodeSetMaxStepB(void *cvode_mem, int which, realtype hmaxB)
   return(flag);
 }
 
+int CVodeSetConstraintsB(void *cvode_mem, int which, N_Vector constraintsB)
+{
+  CVodeMem cv_mem;
+  CVadjMem ca_mem;
+  CVodeBMem cvB_mem;
+  void *cvodeB_mem;
+  int flag;
+
+  /* Is cvode_mem valid? */
+  if (cvode_mem == NULL) {
+    cvProcessError(NULL, CV_MEM_NULL, "CVODEA", "CVodeSetConstraintsB", MSGCV_NO_MEM);
+    return(CV_MEM_NULL);
+  }
+  cv_mem = (CVodeMem) cvode_mem;
+
+  /* Is ASA initialized? */
+  if (cv_mem->cv_adjMallocDone == SUNFALSE) {
+    cvProcessError(cv_mem, CV_NO_ADJ, "CVODEA", "CVodeSetConstraintsB", MSGCV_NO_ADJ);
+  }
+  ca_mem = cv_mem->cv_adj_mem;
+
+  /* Check the value of which */
+  if ( which >= ca_mem->ca_nbckpbs ) {
+    cvProcessError(cv_mem, CV_ILL_INPUT, "CVODEA", "CVodeSetConstraintsB", MSGCV_BAD_WHICH);
+    return(CV_ILL_INPUT);
+  }
+
+  /* Find the CVodeBMem entry in the linked list corresponding to 'which'. */
+  cvB_mem = ca_mem->cvB_mem;
+  while (cvB_mem != NULL) {
+    if ( which == cvB_mem->cv_index) break;
+    /* advance */
+    cvB_mem = cvB_mem->cv_next;
+  }
+  cvodeB_mem = (void *) cvB_mem->cv_mem;
+
+  flag = CVodeSetConstraints(cvodeB_mem, constraintsB);
+  return(flag);
+}
+
 /*
  * CVodeSetQuad*B
  *
@@ -570,6 +610,14 @@ int CVodeGetAdjCheckPointsInfo(void *cvode_mem, CVadjCheckPointRec *ckpnt)
 
 }
 
+
+/* 
+ * -----------------------------------------------------------------
+ * Undocumented Development User-Callable Functions
+ * -----------------------------------------------------------------
+ */
+
+
 /*
  * CVodeGetAdjDataPointHermite
  *
@@ -667,11 +715,6 @@ int CVodeGetAdjDataPointPolynomial(void *cvode_mem, int which,
   return(CV_SUCCESS);
 }
 
-/* 
- * -----------------------------------------------------------------
- * UNDOCUMENTED development user-callable functions
- * -----------------------------------------------------------------
- */
 
 /*
  * CVodeGetAdjCurrentCheckPoint
