@@ -2,21 +2,17 @@
  * Programmer(s): Daniel R. Reynolds @ SMU
  *                Aaron Collier @ LLNL
  *-----------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2017, Southern Methodist University and 
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Southern Methodist University and Lawrence Livermore 
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence 
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  *-----------------------------------------------------------------
- * Fortran/C interface routines for IDA/IDADLS, for the case
+ * Fortran/C interface routines for IDA/IDALS, for the case
  * of a user-supplied Jacobian approximation routine.
  *-----------------------------------------------------------------*/
 
@@ -26,7 +22,7 @@
 #include "fida.h"     /* actual function names, prototypes and global vars.*/
 #include "ida_impl.h" /* definition of IDAMem type                         */
 
-#include <ida/ida_direct.h>
+#include <ida/ida_ls.h>
 #include <sunmatrix/sunmatrix_dense.h>
 
 /*************************************************/
@@ -51,7 +47,7 @@ extern "C" {
 void FIDA_DENSESETJAC(int *flag, int *ier)
 {
   if (*flag == 0) {
-    *ier = IDADlsSetJacFn(IDA_idamem, NULL);
+    *ier = IDASetJacFn(IDA_idamem, NULL);
   } else {
     if (F2C_IDA_ewtvec == NULL) {
       F2C_IDA_ewtvec = N_VClone(F2C_IDA_vec);
@@ -60,7 +56,7 @@ void FIDA_DENSESETJAC(int *flag, int *ier)
         return;
       }
     }
-    *ier = IDADlsSetJacFn(IDA_idamem, FIDADenseJac);
+    *ier = IDASetJacFn(IDA_idamem, FIDADenseJac);
   }
   return;
 }
