@@ -2,15 +2,15 @@
  * Programmer(s): Allan Taylor, Alan Hindmarsh and
  *                Radu Serban @ LLNL
  * -----------------------------------------------------------------
- * LLNS Copyright Start
- * Copyright (c) 2014, Lawrence Livermore National Security
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Lawrence Livermore National Laboratory in part under 
- * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
- * Produced at the Lawrence Livermore National Laboratory.
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  * This file contains the interfaces between KINSOL and the
  * user-supplied Fortran routines FK_PSET and FK_PSOL.
@@ -30,7 +30,7 @@
 #include "fkinsol.h"
 #include "kinsol_impl.h"
 
-#include <kinsol/kinsol_spils.h>
+#include <kinsol/kinsol_ls.h>
 
 /*------------------------------------------------------------------
   prototype of the user-supplied fortran routine
@@ -53,19 +53,25 @@ extern void FK_PSOL(realtype* uudata,   realtype* uscaledata,
 #endif
 
 /*------------------------------------------------------------------
-  Function : FKIN_SPILSSETPREC
+  Function : FKIN_LSSETPREC
   ------------------------------------------------------------------*/
-void FKIN_SPILSSETPREC(int *flag, int *ier)
+void FKIN_LSSETPREC(int *flag, int *ier)
 {
   if ((*flag) == 0) {
-    *ier = KINSpilsSetPreconditioner(KIN_kinmem, NULL, NULL);
+    *ier = KINSetPreconditioner(KIN_kinmem, NULL, NULL);
   } else {
-    *ier = KINSpilsSetPreconditioner(KIN_kinmem, FKINPSet, FKINPSol);
+    *ier = KINSetPreconditioner(KIN_kinmem, FKINPSet, FKINPSol);
   }
 
   return;
 }
 
+/*------------------------------------------------------------------
+  Function : FKIN_SPILSSETPREC -- DEPRECATED
+  ------------------------------------------------------------------*/
+void FKIN_SPILSSETPREC(int *flag, int *ier)
+{ FKIN_LSSETPREC(flag,ier); }
+
 /*------------------------------------------------------------------
   Function : FKINPSet
   ------------------------------------------------------------------
